// Code generated by protoc-gen-go. DO NOT EDIT.
// source: repository-service.proto

package gitalypb

import (
	context "context"
	fmt "fmt"
	proto "github.com/golang/protobuf/proto"
	grpc "google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
	math "math"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

type WriteCommitGraphRequest_SplitStrategy int32

const (
	// SizeMultiple requires to use '--split --size-multiple=4' strategy to create/update commit graph.
	// https://git-scm.com/docs/git-commit-graph#Documentation/git-commit-graph.txt-emwriteem
	// It is a default, there is no need to explicitly set it in the request.
	WriteCommitGraphRequest_SizeMultiple WriteCommitGraphRequest_SplitStrategy = 0
)

var WriteCommitGraphRequest_SplitStrategy_name = map[int32]string{
	0: "SizeMultiple",
}

var WriteCommitGraphRequest_SplitStrategy_value = map[string]int32{
	"SizeMultiple": 0,
}

func (x WriteCommitGraphRequest_SplitStrategy) String() string {
	return proto.EnumName(WriteCommitGraphRequest_SplitStrategy_name, int32(x))
}

func (WriteCommitGraphRequest_SplitStrategy) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{10, 0}
}

type GetArchiveRequest_Format int32

const (
	GetArchiveRequest_ZIP     GetArchiveRequest_Format = 0
	GetArchiveRequest_TAR     GetArchiveRequest_Format = 1
	GetArchiveRequest_TAR_GZ  GetArchiveRequest_Format = 2
	GetArchiveRequest_TAR_BZ2 GetArchiveRequest_Format = 3
)

var GetArchiveRequest_Format_name = map[int32]string{
	0: "ZIP",
	1: "TAR",
	2: "TAR_GZ",
	3: "TAR_BZ2",
}

var GetArchiveRequest_Format_value = map[string]int32{
	"ZIP":     0,
	"TAR":     1,
	"TAR_GZ":  2,
	"TAR_BZ2": 3,
}

func (x GetArchiveRequest_Format) String() string {
	return proto.EnumName(GetArchiveRequest_Format_name, int32(x))
}

func (GetArchiveRequest_Format) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{22, 0}
}

type GetRawChangesResponse_RawChange_Operation int32

const (
	GetRawChangesResponse_RawChange_UNKNOWN      GetRawChangesResponse_RawChange_Operation = 0
	GetRawChangesResponse_RawChange_ADDED        GetRawChangesResponse_RawChange_Operation = 1
	GetRawChangesResponse_RawChange_COPIED       GetRawChangesResponse_RawChange_Operation = 2
	GetRawChangesResponse_RawChange_DELETED      GetRawChangesResponse_RawChange_Operation = 3
	GetRawChangesResponse_RawChange_MODIFIED     GetRawChangesResponse_RawChange_Operation = 4
	GetRawChangesResponse_RawChange_RENAMED      GetRawChangesResponse_RawChange_Operation = 5
	GetRawChangesResponse_RawChange_TYPE_CHANGED GetRawChangesResponse_RawChange_Operation = 6
)

var GetRawChangesResponse_RawChange_Operation_name = map[int32]string{
	0: "UNKNOWN",
	1: "ADDED",
	2: "COPIED",
	3: "DELETED",
	4: "MODIFIED",
	5: "RENAMED",
	6: "TYPE_CHANGED",
}

var GetRawChangesResponse_RawChange_Operation_value = map[string]int32{
	"UNKNOWN":      0,
	"ADDED":        1,
	"COPIED":       2,
	"DELETED":      3,
	"MODIFIED":     4,
	"RENAMED":      5,
	"TYPE_CHANGED": 6,
}

func (x GetRawChangesResponse_RawChange_Operation) String() string {
	return proto.EnumName(GetRawChangesResponse_RawChange_Operation_name, int32(x))
}

func (GetRawChangesResponse_RawChange_Operation) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{67, 0, 0}
}

type RepositoryExistsRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *RepositoryExistsRequest) Reset()         { *m = RepositoryExistsRequest{} }
func (m *RepositoryExistsRequest) String() string { return proto.CompactTextString(m) }
func (*RepositoryExistsRequest) ProtoMessage()    {}
func (*RepositoryExistsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{0}
}

func (m *RepositoryExistsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RepositoryExistsRequest.Unmarshal(m, b)
}
func (m *RepositoryExistsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RepositoryExistsRequest.Marshal(b, m, deterministic)
}
func (m *RepositoryExistsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RepositoryExistsRequest.Merge(m, src)
}
func (m *RepositoryExistsRequest) XXX_Size() int {
	return xxx_messageInfo_RepositoryExistsRequest.Size(m)
}
func (m *RepositoryExistsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_RepositoryExistsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_RepositoryExistsRequest proto.InternalMessageInfo

func (m *RepositoryExistsRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type RepositoryExistsResponse struct {
	Exists               bool     `protobuf:"varint,1,opt,name=exists,proto3" json:"exists,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *RepositoryExistsResponse) Reset()         { *m = RepositoryExistsResponse{} }
func (m *RepositoryExistsResponse) String() string { return proto.CompactTextString(m) }
func (*RepositoryExistsResponse) ProtoMessage()    {}
func (*RepositoryExistsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{1}
}

func (m *RepositoryExistsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RepositoryExistsResponse.Unmarshal(m, b)
}
func (m *RepositoryExistsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RepositoryExistsResponse.Marshal(b, m, deterministic)
}
func (m *RepositoryExistsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RepositoryExistsResponse.Merge(m, src)
}
func (m *RepositoryExistsResponse) XXX_Size() int {
	return xxx_messageInfo_RepositoryExistsResponse.Size(m)
}
func (m *RepositoryExistsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_RepositoryExistsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_RepositoryExistsResponse proto.InternalMessageInfo

func (m *RepositoryExistsResponse) GetExists() bool {
	if m != nil {
		return m.Exists
	}
	return false
}

type RepackIncrementalRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *RepackIncrementalRequest) Reset()         { *m = RepackIncrementalRequest{} }
func (m *RepackIncrementalRequest) String() string { return proto.CompactTextString(m) }
func (*RepackIncrementalRequest) ProtoMessage()    {}
func (*RepackIncrementalRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{2}
}

func (m *RepackIncrementalRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RepackIncrementalRequest.Unmarshal(m, b)
}
func (m *RepackIncrementalRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RepackIncrementalRequest.Marshal(b, m, deterministic)
}
func (m *RepackIncrementalRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RepackIncrementalRequest.Merge(m, src)
}
func (m *RepackIncrementalRequest) XXX_Size() int {
	return xxx_messageInfo_RepackIncrementalRequest.Size(m)
}
func (m *RepackIncrementalRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_RepackIncrementalRequest.DiscardUnknown(m)
}

var xxx_messageInfo_RepackIncrementalRequest proto.InternalMessageInfo

func (m *RepackIncrementalRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type RepackIncrementalResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *RepackIncrementalResponse) Reset()         { *m = RepackIncrementalResponse{} }
func (m *RepackIncrementalResponse) String() string { return proto.CompactTextString(m) }
func (*RepackIncrementalResponse) ProtoMessage()    {}
func (*RepackIncrementalResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{3}
}

func (m *RepackIncrementalResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RepackIncrementalResponse.Unmarshal(m, b)
}
func (m *RepackIncrementalResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RepackIncrementalResponse.Marshal(b, m, deterministic)
}
func (m *RepackIncrementalResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RepackIncrementalResponse.Merge(m, src)
}
func (m *RepackIncrementalResponse) XXX_Size() int {
	return xxx_messageInfo_RepackIncrementalResponse.Size(m)
}
func (m *RepackIncrementalResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_RepackIncrementalResponse.DiscardUnknown(m)
}

var xxx_messageInfo_RepackIncrementalResponse proto.InternalMessageInfo

type RepackFullRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	CreateBitmap         bool        `protobuf:"varint,2,opt,name=create_bitmap,json=createBitmap,proto3" json:"create_bitmap,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *RepackFullRequest) Reset()         { *m = RepackFullRequest{} }
func (m *RepackFullRequest) String() string { return proto.CompactTextString(m) }
func (*RepackFullRequest) ProtoMessage()    {}
func (*RepackFullRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{4}
}

func (m *RepackFullRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RepackFullRequest.Unmarshal(m, b)
}
func (m *RepackFullRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RepackFullRequest.Marshal(b, m, deterministic)
}
func (m *RepackFullRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RepackFullRequest.Merge(m, src)
}
func (m *RepackFullRequest) XXX_Size() int {
	return xxx_messageInfo_RepackFullRequest.Size(m)
}
func (m *RepackFullRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_RepackFullRequest.DiscardUnknown(m)
}

var xxx_messageInfo_RepackFullRequest proto.InternalMessageInfo

func (m *RepackFullRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *RepackFullRequest) GetCreateBitmap() bool {
	if m != nil {
		return m.CreateBitmap
	}
	return false
}

type RepackFullResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *RepackFullResponse) Reset()         { *m = RepackFullResponse{} }
func (m *RepackFullResponse) String() string { return proto.CompactTextString(m) }
func (*RepackFullResponse) ProtoMessage()    {}
func (*RepackFullResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{5}
}

func (m *RepackFullResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RepackFullResponse.Unmarshal(m, b)
}
func (m *RepackFullResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RepackFullResponse.Marshal(b, m, deterministic)
}
func (m *RepackFullResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RepackFullResponse.Merge(m, src)
}
func (m *RepackFullResponse) XXX_Size() int {
	return xxx_messageInfo_RepackFullResponse.Size(m)
}
func (m *RepackFullResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_RepackFullResponse.DiscardUnknown(m)
}

var xxx_messageInfo_RepackFullResponse proto.InternalMessageInfo

type MidxRepackRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *MidxRepackRequest) Reset()         { *m = MidxRepackRequest{} }
func (m *MidxRepackRequest) String() string { return proto.CompactTextString(m) }
func (*MidxRepackRequest) ProtoMessage()    {}
func (*MidxRepackRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{6}
}

func (m *MidxRepackRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MidxRepackRequest.Unmarshal(m, b)
}
func (m *MidxRepackRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MidxRepackRequest.Marshal(b, m, deterministic)
}
func (m *MidxRepackRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MidxRepackRequest.Merge(m, src)
}
func (m *MidxRepackRequest) XXX_Size() int {
	return xxx_messageInfo_MidxRepackRequest.Size(m)
}
func (m *MidxRepackRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_MidxRepackRequest.DiscardUnknown(m)
}

var xxx_messageInfo_MidxRepackRequest proto.InternalMessageInfo

func (m *MidxRepackRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type MidxRepackResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MidxRepackResponse) Reset()         { *m = MidxRepackResponse{} }
func (m *MidxRepackResponse) String() string { return proto.CompactTextString(m) }
func (*MidxRepackResponse) ProtoMessage()    {}
func (*MidxRepackResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{7}
}

func (m *MidxRepackResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MidxRepackResponse.Unmarshal(m, b)
}
func (m *MidxRepackResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MidxRepackResponse.Marshal(b, m, deterministic)
}
func (m *MidxRepackResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MidxRepackResponse.Merge(m, src)
}
func (m *MidxRepackResponse) XXX_Size() int {
	return xxx_messageInfo_MidxRepackResponse.Size(m)
}
func (m *MidxRepackResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_MidxRepackResponse.DiscardUnknown(m)
}

var xxx_messageInfo_MidxRepackResponse proto.InternalMessageInfo

type GarbageCollectRequest struct {
	Repository   *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	CreateBitmap bool        `protobuf:"varint,2,opt,name=create_bitmap,json=createBitmap,proto3" json:"create_bitmap,omitempty"`
	// If set to 'true' the 'gc' will be triggered with '--prune=24.hours.ago' flag.
	// This will remove dangling objects from the object storage that were not modified in the last 24 hours.
	// If 'false' provided the 'gc' will rely on the default expiration period (2 weeks).
	// The window of 24 hours exists because of possible concurrent operations running on the same
	// storage and removal of the objects may cause races and fail concurrent operations.
	Prune                bool     `protobuf:"varint,3,opt,name=prune,proto3" json:"prune,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GarbageCollectRequest) Reset()         { *m = GarbageCollectRequest{} }
func (m *GarbageCollectRequest) String() string { return proto.CompactTextString(m) }
func (*GarbageCollectRequest) ProtoMessage()    {}
func (*GarbageCollectRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{8}
}

func (m *GarbageCollectRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GarbageCollectRequest.Unmarshal(m, b)
}
func (m *GarbageCollectRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GarbageCollectRequest.Marshal(b, m, deterministic)
}
func (m *GarbageCollectRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GarbageCollectRequest.Merge(m, src)
}
func (m *GarbageCollectRequest) XXX_Size() int {
	return xxx_messageInfo_GarbageCollectRequest.Size(m)
}
func (m *GarbageCollectRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GarbageCollectRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GarbageCollectRequest proto.InternalMessageInfo

func (m *GarbageCollectRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *GarbageCollectRequest) GetCreateBitmap() bool {
	if m != nil {
		return m.CreateBitmap
	}
	return false
}

func (m *GarbageCollectRequest) GetPrune() bool {
	if m != nil {
		return m.Prune
	}
	return false
}

type GarbageCollectResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GarbageCollectResponse) Reset()         { *m = GarbageCollectResponse{} }
func (m *GarbageCollectResponse) String() string { return proto.CompactTextString(m) }
func (*GarbageCollectResponse) ProtoMessage()    {}
func (*GarbageCollectResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{9}
}

func (m *GarbageCollectResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GarbageCollectResponse.Unmarshal(m, b)
}
func (m *GarbageCollectResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GarbageCollectResponse.Marshal(b, m, deterministic)
}
func (m *GarbageCollectResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GarbageCollectResponse.Merge(m, src)
}
func (m *GarbageCollectResponse) XXX_Size() int {
	return xxx_messageInfo_GarbageCollectResponse.Size(m)
}
func (m *GarbageCollectResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GarbageCollectResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GarbageCollectResponse proto.InternalMessageInfo

type WriteCommitGraphRequest struct {
	Repository *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	// SplitStrategy is a strategy used to create/update commit graph.
	SplitStrategy        WriteCommitGraphRequest_SplitStrategy `protobuf:"varint,2,opt,name=splitStrategy,proto3,enum=gitaly.WriteCommitGraphRequest_SplitStrategy" json:"splitStrategy,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                              `json:"-"`
	XXX_unrecognized     []byte                                `json:"-"`
	XXX_sizecache        int32                                 `json:"-"`
}

func (m *WriteCommitGraphRequest) Reset()         { *m = WriteCommitGraphRequest{} }
func (m *WriteCommitGraphRequest) String() string { return proto.CompactTextString(m) }
func (*WriteCommitGraphRequest) ProtoMessage()    {}
func (*WriteCommitGraphRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{10}
}

func (m *WriteCommitGraphRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_WriteCommitGraphRequest.Unmarshal(m, b)
}
func (m *WriteCommitGraphRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_WriteCommitGraphRequest.Marshal(b, m, deterministic)
}
func (m *WriteCommitGraphRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_WriteCommitGraphRequest.Merge(m, src)
}
func (m *WriteCommitGraphRequest) XXX_Size() int {
	return xxx_messageInfo_WriteCommitGraphRequest.Size(m)
}
func (m *WriteCommitGraphRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_WriteCommitGraphRequest.DiscardUnknown(m)
}

var xxx_messageInfo_WriteCommitGraphRequest proto.InternalMessageInfo

func (m *WriteCommitGraphRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *WriteCommitGraphRequest) GetSplitStrategy() WriteCommitGraphRequest_SplitStrategy {
	if m != nil {
		return m.SplitStrategy
	}
	return WriteCommitGraphRequest_SizeMultiple
}

type WriteCommitGraphResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *WriteCommitGraphResponse) Reset()         { *m = WriteCommitGraphResponse{} }
func (m *WriteCommitGraphResponse) String() string { return proto.CompactTextString(m) }
func (*WriteCommitGraphResponse) ProtoMessage()    {}
func (*WriteCommitGraphResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{11}
}

func (m *WriteCommitGraphResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_WriteCommitGraphResponse.Unmarshal(m, b)
}
func (m *WriteCommitGraphResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_WriteCommitGraphResponse.Marshal(b, m, deterministic)
}
func (m *WriteCommitGraphResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_WriteCommitGraphResponse.Merge(m, src)
}
func (m *WriteCommitGraphResponse) XXX_Size() int {
	return xxx_messageInfo_WriteCommitGraphResponse.Size(m)
}
func (m *WriteCommitGraphResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_WriteCommitGraphResponse.DiscardUnknown(m)
}

var xxx_messageInfo_WriteCommitGraphResponse proto.InternalMessageInfo

type CleanupRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CleanupRequest) Reset()         { *m = CleanupRequest{} }
func (m *CleanupRequest) String() string { return proto.CompactTextString(m) }
func (*CleanupRequest) ProtoMessage()    {}
func (*CleanupRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{12}
}

func (m *CleanupRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CleanupRequest.Unmarshal(m, b)
}
func (m *CleanupRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CleanupRequest.Marshal(b, m, deterministic)
}
func (m *CleanupRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CleanupRequest.Merge(m, src)
}
func (m *CleanupRequest) XXX_Size() int {
	return xxx_messageInfo_CleanupRequest.Size(m)
}
func (m *CleanupRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CleanupRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CleanupRequest proto.InternalMessageInfo

func (m *CleanupRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type CleanupResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CleanupResponse) Reset()         { *m = CleanupResponse{} }
func (m *CleanupResponse) String() string { return proto.CompactTextString(m) }
func (*CleanupResponse) ProtoMessage()    {}
func (*CleanupResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{13}
}

func (m *CleanupResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CleanupResponse.Unmarshal(m, b)
}
func (m *CleanupResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CleanupResponse.Marshal(b, m, deterministic)
}
func (m *CleanupResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CleanupResponse.Merge(m, src)
}
func (m *CleanupResponse) XXX_Size() int {
	return xxx_messageInfo_CleanupResponse.Size(m)
}
func (m *CleanupResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CleanupResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CleanupResponse proto.InternalMessageInfo

type RepositorySizeRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *RepositorySizeRequest) Reset()         { *m = RepositorySizeRequest{} }
func (m *RepositorySizeRequest) String() string { return proto.CompactTextString(m) }
func (*RepositorySizeRequest) ProtoMessage()    {}
func (*RepositorySizeRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{14}
}

func (m *RepositorySizeRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RepositorySizeRequest.Unmarshal(m, b)
}
func (m *RepositorySizeRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RepositorySizeRequest.Marshal(b, m, deterministic)
}
func (m *RepositorySizeRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RepositorySizeRequest.Merge(m, src)
}
func (m *RepositorySizeRequest) XXX_Size() int {
	return xxx_messageInfo_RepositorySizeRequest.Size(m)
}
func (m *RepositorySizeRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_RepositorySizeRequest.DiscardUnknown(m)
}

var xxx_messageInfo_RepositorySizeRequest proto.InternalMessageInfo

func (m *RepositorySizeRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type RepositorySizeResponse struct {
	// Repository size in kilobytes
	Size                 int64    `protobuf:"varint,1,opt,name=size,proto3" json:"size,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *RepositorySizeResponse) Reset()         { *m = RepositorySizeResponse{} }
func (m *RepositorySizeResponse) String() string { return proto.CompactTextString(m) }
func (*RepositorySizeResponse) ProtoMessage()    {}
func (*RepositorySizeResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{15}
}

func (m *RepositorySizeResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RepositorySizeResponse.Unmarshal(m, b)
}
func (m *RepositorySizeResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RepositorySizeResponse.Marshal(b, m, deterministic)
}
func (m *RepositorySizeResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RepositorySizeResponse.Merge(m, src)
}
func (m *RepositorySizeResponse) XXX_Size() int {
	return xxx_messageInfo_RepositorySizeResponse.Size(m)
}
func (m *RepositorySizeResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_RepositorySizeResponse.DiscardUnknown(m)
}

var xxx_messageInfo_RepositorySizeResponse proto.InternalMessageInfo

func (m *RepositorySizeResponse) GetSize() int64 {
	if m != nil {
		return m.Size
	}
	return 0
}

type ApplyGitattributesRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Revision             []byte      `protobuf:"bytes,2,opt,name=revision,proto3" json:"revision,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *ApplyGitattributesRequest) Reset()         { *m = ApplyGitattributesRequest{} }
func (m *ApplyGitattributesRequest) String() string { return proto.CompactTextString(m) }
func (*ApplyGitattributesRequest) ProtoMessage()    {}
func (*ApplyGitattributesRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{16}
}

func (m *ApplyGitattributesRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ApplyGitattributesRequest.Unmarshal(m, b)
}
func (m *ApplyGitattributesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ApplyGitattributesRequest.Marshal(b, m, deterministic)
}
func (m *ApplyGitattributesRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ApplyGitattributesRequest.Merge(m, src)
}
func (m *ApplyGitattributesRequest) XXX_Size() int {
	return xxx_messageInfo_ApplyGitattributesRequest.Size(m)
}
func (m *ApplyGitattributesRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ApplyGitattributesRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ApplyGitattributesRequest proto.InternalMessageInfo

func (m *ApplyGitattributesRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *ApplyGitattributesRequest) GetRevision() []byte {
	if m != nil {
		return m.Revision
	}
	return nil
}

type ApplyGitattributesResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ApplyGitattributesResponse) Reset()         { *m = ApplyGitattributesResponse{} }
func (m *ApplyGitattributesResponse) String() string { return proto.CompactTextString(m) }
func (*ApplyGitattributesResponse) ProtoMessage()    {}
func (*ApplyGitattributesResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{17}
}

func (m *ApplyGitattributesResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ApplyGitattributesResponse.Unmarshal(m, b)
}
func (m *ApplyGitattributesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ApplyGitattributesResponse.Marshal(b, m, deterministic)
}
func (m *ApplyGitattributesResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ApplyGitattributesResponse.Merge(m, src)
}
func (m *ApplyGitattributesResponse) XXX_Size() int {
	return xxx_messageInfo_ApplyGitattributesResponse.Size(m)
}
func (m *ApplyGitattributesResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ApplyGitattributesResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ApplyGitattributesResponse proto.InternalMessageInfo

type FetchRemoteRequest struct {
	Repository *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	// remote is the name of the remote that shall be fetched. This remote must
	// exist in the repository's configuration already. This parameter is
	// deprecated in favor of remote_params.
	Remote string `protobuf:"bytes,2,opt,name=remote,proto3" json:"remote,omitempty"`
	// force determines if references should be force-updated in case they have
	// diverged.
	Force bool `protobuf:"varint,3,opt,name=force,proto3" json:"force,omitempty"`
	// no_tags determines whether tags should be fetched.
	NoTags bool `protobuf:"varint,4,opt,name=no_tags,json=noTags,proto3" json:"no_tags,omitempty"`
	// timeout specifies a timeout for the fetch.
	Timeout    int32  `protobuf:"varint,5,opt,name=timeout,proto3" json:"timeout,omitempty"`
	SshKey     string `protobuf:"bytes,6,opt,name=ssh_key,json=sshKey,proto3" json:"ssh_key,omitempty"`
	KnownHosts string `protobuf:"bytes,7,opt,name=known_hosts,json=knownHosts,proto3" json:"known_hosts,omitempty"`
	// no_prune will the fetch to not prune remote references which do not exist
	// in the remote repository anymore.
	NoPrune bool `protobuf:"varint,9,opt,name=no_prune,json=noPrune,proto3" json:"no_prune,omitempty"`
	// remote_params specifies the remote repository which should be fetched
	// from.
	RemoteParams *Remote `protobuf:"bytes,10,opt,name=remote_params,json=remoteParams,proto3" json:"remote_params,omitempty"`
	// If check_tags_changed is true, the FetchRemote RPC will check whether any
	// tags were modified, returning the result in the tags_changed field of
	// FetchRemoteResponse
	CheckTagsChanged     bool     `protobuf:"varint,11,opt,name=check_tags_changed,json=checkTagsChanged,proto3" json:"check_tags_changed,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FetchRemoteRequest) Reset()         { *m = FetchRemoteRequest{} }
func (m *FetchRemoteRequest) String() string { return proto.CompactTextString(m) }
func (*FetchRemoteRequest) ProtoMessage()    {}
func (*FetchRemoteRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{18}
}

func (m *FetchRemoteRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FetchRemoteRequest.Unmarshal(m, b)
}
func (m *FetchRemoteRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FetchRemoteRequest.Marshal(b, m, deterministic)
}
func (m *FetchRemoteRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FetchRemoteRequest.Merge(m, src)
}
func (m *FetchRemoteRequest) XXX_Size() int {
	return xxx_messageInfo_FetchRemoteRequest.Size(m)
}
func (m *FetchRemoteRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_FetchRemoteRequest.DiscardUnknown(m)
}

var xxx_messageInfo_FetchRemoteRequest proto.InternalMessageInfo

func (m *FetchRemoteRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *FetchRemoteRequest) GetRemote() string {
	if m != nil {
		return m.Remote
	}
	return ""
}

func (m *FetchRemoteRequest) GetForce() bool {
	if m != nil {
		return m.Force
	}
	return false
}

func (m *FetchRemoteRequest) GetNoTags() bool {
	if m != nil {
		return m.NoTags
	}
	return false
}

func (m *FetchRemoteRequest) GetTimeout() int32 {
	if m != nil {
		return m.Timeout
	}
	return 0
}

func (m *FetchRemoteRequest) GetSshKey() string {
	if m != nil {
		return m.SshKey
	}
	return ""
}

func (m *FetchRemoteRequest) GetKnownHosts() string {
	if m != nil {
		return m.KnownHosts
	}
	return ""
}

func (m *FetchRemoteRequest) GetNoPrune() bool {
	if m != nil {
		return m.NoPrune
	}
	return false
}

func (m *FetchRemoteRequest) GetRemoteParams() *Remote {
	if m != nil {
		return m.RemoteParams
	}
	return nil
}

func (m *FetchRemoteRequest) GetCheckTagsChanged() bool {
	if m != nil {
		return m.CheckTagsChanged
	}
	return false
}

type FetchRemoteResponse struct {
	// If check_tags_changed was set in the FetchRemoteRequest, the FetchRemote
	// RPC will return false when no tags were changed, and true if tags were
	// changed or answer cannot be determined.
	TagsChanged          bool     `protobuf:"varint,1,opt,name=tags_changed,json=tagsChanged,proto3" json:"tags_changed,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FetchRemoteResponse) Reset()         { *m = FetchRemoteResponse{} }
func (m *FetchRemoteResponse) String() string { return proto.CompactTextString(m) }
func (*FetchRemoteResponse) ProtoMessage()    {}
func (*FetchRemoteResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{19}
}

func (m *FetchRemoteResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FetchRemoteResponse.Unmarshal(m, b)
}
func (m *FetchRemoteResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FetchRemoteResponse.Marshal(b, m, deterministic)
}
func (m *FetchRemoteResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FetchRemoteResponse.Merge(m, src)
}
func (m *FetchRemoteResponse) XXX_Size() int {
	return xxx_messageInfo_FetchRemoteResponse.Size(m)
}
func (m *FetchRemoteResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_FetchRemoteResponse.DiscardUnknown(m)
}

var xxx_messageInfo_FetchRemoteResponse proto.InternalMessageInfo

func (m *FetchRemoteResponse) GetTagsChanged() bool {
	if m != nil {
		return m.TagsChanged
	}
	return false
}

type CreateRepositoryRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CreateRepositoryRequest) Reset()         { *m = CreateRepositoryRequest{} }
func (m *CreateRepositoryRequest) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryRequest) ProtoMessage()    {}
func (*CreateRepositoryRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{20}
}

func (m *CreateRepositoryRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateRepositoryRequest.Unmarshal(m, b)
}
func (m *CreateRepositoryRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateRepositoryRequest.Marshal(b, m, deterministic)
}
func (m *CreateRepositoryRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateRepositoryRequest.Merge(m, src)
}
func (m *CreateRepositoryRequest) XXX_Size() int {
	return xxx_messageInfo_CreateRepositoryRequest.Size(m)
}
func (m *CreateRepositoryRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateRepositoryRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateRepositoryRequest proto.InternalMessageInfo

func (m *CreateRepositoryRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type CreateRepositoryResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CreateRepositoryResponse) Reset()         { *m = CreateRepositoryResponse{} }
func (m *CreateRepositoryResponse) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryResponse) ProtoMessage()    {}
func (*CreateRepositoryResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{21}
}

func (m *CreateRepositoryResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateRepositoryResponse.Unmarshal(m, b)
}
func (m *CreateRepositoryResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateRepositoryResponse.Marshal(b, m, deterministic)
}
func (m *CreateRepositoryResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateRepositoryResponse.Merge(m, src)
}
func (m *CreateRepositoryResponse) XXX_Size() int {
	return xxx_messageInfo_CreateRepositoryResponse.Size(m)
}
func (m *CreateRepositoryResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateRepositoryResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CreateRepositoryResponse proto.InternalMessageInfo

type GetArchiveRequest struct {
	Repository *Repository              `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	CommitId   string                   `protobuf:"bytes,2,opt,name=commit_id,json=commitId,proto3" json:"commit_id,omitempty"`
	Prefix     string                   `protobuf:"bytes,3,opt,name=prefix,proto3" json:"prefix,omitempty"`
	Format     GetArchiveRequest_Format `protobuf:"varint,4,opt,name=format,proto3,enum=gitaly.GetArchiveRequest_Format" json:"format,omitempty"`
	Path       []byte                   `protobuf:"bytes,5,opt,name=path,proto3" json:"path,omitempty"`
	Exclude    [][]byte                 `protobuf:"bytes,6,rep,name=exclude,proto3" json:"exclude,omitempty"`
	// If `elide_path` is true and `path` refers to a subdirectory, that
	// subdirectory will be elided from archive entries. For example, if `dir`
	// contains `README.md`, with `elide_path = false` the corresponding entry
	// will be `dir/README.md`; with `elide_path = true`, the entry will be
	// `README.md`. `elide_path` has no effect if `path` refers to the repository
	// root. `elide_path = true` is not supported if `path` refers to a file.
	ElidePath            bool     `protobuf:"varint,7,opt,name=elide_path,json=elidePath,proto3" json:"elide_path,omitempty"`
	IncludeLfsBlobs      bool     `protobuf:"varint,8,opt,name=include_lfs_blobs,json=includeLfsBlobs,proto3" json:"include_lfs_blobs,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetArchiveRequest) Reset()         { *m = GetArchiveRequest{} }
func (m *GetArchiveRequest) String() string { return proto.CompactTextString(m) }
func (*GetArchiveRequest) ProtoMessage()    {}
func (*GetArchiveRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{22}
}

func (m *GetArchiveRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetArchiveRequest.Unmarshal(m, b)
}
func (m *GetArchiveRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetArchiveRequest.Marshal(b, m, deterministic)
}
func (m *GetArchiveRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetArchiveRequest.Merge(m, src)
}
func (m *GetArchiveRequest) XXX_Size() int {
	return xxx_messageInfo_GetArchiveRequest.Size(m)
}
func (m *GetArchiveRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetArchiveRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetArchiveRequest proto.InternalMessageInfo

func (m *GetArchiveRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *GetArchiveRequest) GetCommitId() string {
	if m != nil {
		return m.CommitId
	}
	return ""
}

func (m *GetArchiveRequest) GetPrefix() string {
	if m != nil {
		return m.Prefix
	}
	return ""
}

func (m *GetArchiveRequest) GetFormat() GetArchiveRequest_Format {
	if m != nil {
		return m.Format
	}
	return GetArchiveRequest_ZIP
}

func (m *GetArchiveRequest) GetPath() []byte {
	if m != nil {
		return m.Path
	}
	return nil
}

func (m *GetArchiveRequest) GetExclude() [][]byte {
	if m != nil {
		return m.Exclude
	}
	return nil
}

func (m *GetArchiveRequest) GetElidePath() bool {
	if m != nil {
		return m.ElidePath
	}
	return false
}

func (m *GetArchiveRequest) GetIncludeLfsBlobs() bool {
	if m != nil {
		return m.IncludeLfsBlobs
	}
	return false
}

type GetArchiveResponse struct {
	Data                 []byte   `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetArchiveResponse) Reset()         { *m = GetArchiveResponse{} }
func (m *GetArchiveResponse) String() string { return proto.CompactTextString(m) }
func (*GetArchiveResponse) ProtoMessage()    {}
func (*GetArchiveResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{23}
}

func (m *GetArchiveResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetArchiveResponse.Unmarshal(m, b)
}
func (m *GetArchiveResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetArchiveResponse.Marshal(b, m, deterministic)
}
func (m *GetArchiveResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetArchiveResponse.Merge(m, src)
}
func (m *GetArchiveResponse) XXX_Size() int {
	return xxx_messageInfo_GetArchiveResponse.Size(m)
}
func (m *GetArchiveResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GetArchiveResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GetArchiveResponse proto.InternalMessageInfo

func (m *GetArchiveResponse) GetData() []byte {
	if m != nil {
		return m.Data
	}
	return nil
}

type HasLocalBranchesRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *HasLocalBranchesRequest) Reset()         { *m = HasLocalBranchesRequest{} }
func (m *HasLocalBranchesRequest) String() string { return proto.CompactTextString(m) }
func (*HasLocalBranchesRequest) ProtoMessage()    {}
func (*HasLocalBranchesRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{24}
}

func (m *HasLocalBranchesRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_HasLocalBranchesRequest.Unmarshal(m, b)
}
func (m *HasLocalBranchesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_HasLocalBranchesRequest.Marshal(b, m, deterministic)
}
func (m *HasLocalBranchesRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_HasLocalBranchesRequest.Merge(m, src)
}
func (m *HasLocalBranchesRequest) XXX_Size() int {
	return xxx_messageInfo_HasLocalBranchesRequest.Size(m)
}
func (m *HasLocalBranchesRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_HasLocalBranchesRequest.DiscardUnknown(m)
}

var xxx_messageInfo_HasLocalBranchesRequest proto.InternalMessageInfo

func (m *HasLocalBranchesRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type HasLocalBranchesResponse struct {
	Value                bool     `protobuf:"varint,1,opt,name=value,proto3" json:"value,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *HasLocalBranchesResponse) Reset()         { *m = HasLocalBranchesResponse{} }
func (m *HasLocalBranchesResponse) String() string { return proto.CompactTextString(m) }
func (*HasLocalBranchesResponse) ProtoMessage()    {}
func (*HasLocalBranchesResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{25}
}

func (m *HasLocalBranchesResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_HasLocalBranchesResponse.Unmarshal(m, b)
}
func (m *HasLocalBranchesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_HasLocalBranchesResponse.Marshal(b, m, deterministic)
}
func (m *HasLocalBranchesResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_HasLocalBranchesResponse.Merge(m, src)
}
func (m *HasLocalBranchesResponse) XXX_Size() int {
	return xxx_messageInfo_HasLocalBranchesResponse.Size(m)
}
func (m *HasLocalBranchesResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_HasLocalBranchesResponse.DiscardUnknown(m)
}

var xxx_messageInfo_HasLocalBranchesResponse proto.InternalMessageInfo

func (m *HasLocalBranchesResponse) GetValue() bool {
	if m != nil {
		return m.Value
	}
	return false
}

type FetchSourceBranchRequest struct {
	// Repository into which the reference shall be fetched. After a successful
	// call, it should contain the target reference which points to the same
	// commit as the source repository's source branch.
	Repository *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	// Repository from which to fetch the source branch from.
	SourceRepository *Repository `protobuf:"bytes,2,opt,name=source_repository,json=sourceRepository,proto3" json:"source_repository,omitempty"`
	// Name of the branch in the source repository which should be fetched.
	SourceBranch []byte `protobuf:"bytes,3,opt,name=source_branch,json=sourceBranch,proto3" json:"source_branch,omitempty"`
	// Name of the reference which shall be newly created in the target
	// repository.
	TargetRef            []byte   `protobuf:"bytes,4,opt,name=target_ref,json=targetRef,proto3" json:"target_ref,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FetchSourceBranchRequest) Reset()         { *m = FetchSourceBranchRequest{} }
func (m *FetchSourceBranchRequest) String() string { return proto.CompactTextString(m) }
func (*FetchSourceBranchRequest) ProtoMessage()    {}
func (*FetchSourceBranchRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{26}
}

func (m *FetchSourceBranchRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FetchSourceBranchRequest.Unmarshal(m, b)
}
func (m *FetchSourceBranchRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FetchSourceBranchRequest.Marshal(b, m, deterministic)
}
func (m *FetchSourceBranchRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FetchSourceBranchRequest.Merge(m, src)
}
func (m *FetchSourceBranchRequest) XXX_Size() int {
	return xxx_messageInfo_FetchSourceBranchRequest.Size(m)
}
func (m *FetchSourceBranchRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_FetchSourceBranchRequest.DiscardUnknown(m)
}

var xxx_messageInfo_FetchSourceBranchRequest proto.InternalMessageInfo

func (m *FetchSourceBranchRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *FetchSourceBranchRequest) GetSourceRepository() *Repository {
	if m != nil {
		return m.SourceRepository
	}
	return nil
}

func (m *FetchSourceBranchRequest) GetSourceBranch() []byte {
	if m != nil {
		return m.SourceBranch
	}
	return nil
}

func (m *FetchSourceBranchRequest) GetTargetRef() []byte {
	if m != nil {
		return m.TargetRef
	}
	return nil
}

type FetchSourceBranchResponse struct {
	// True if the source branch was successfully fetched into the target
	// repository, false if resolving the remote reference or fetching it failed.
	Result               bool     `protobuf:"varint,1,opt,name=result,proto3" json:"result,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FetchSourceBranchResponse) Reset()         { *m = FetchSourceBranchResponse{} }
func (m *FetchSourceBranchResponse) String() string { return proto.CompactTextString(m) }
func (*FetchSourceBranchResponse) ProtoMessage()    {}
func (*FetchSourceBranchResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{27}
}

func (m *FetchSourceBranchResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FetchSourceBranchResponse.Unmarshal(m, b)
}
func (m *FetchSourceBranchResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FetchSourceBranchResponse.Marshal(b, m, deterministic)
}
func (m *FetchSourceBranchResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FetchSourceBranchResponse.Merge(m, src)
}
func (m *FetchSourceBranchResponse) XXX_Size() int {
	return xxx_messageInfo_FetchSourceBranchResponse.Size(m)
}
func (m *FetchSourceBranchResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_FetchSourceBranchResponse.DiscardUnknown(m)
}

var xxx_messageInfo_FetchSourceBranchResponse proto.InternalMessageInfo

func (m *FetchSourceBranchResponse) GetResult() bool {
	if m != nil {
		return m.Result
	}
	return false
}

type FsckRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *FsckRequest) Reset()         { *m = FsckRequest{} }
func (m *FsckRequest) String() string { return proto.CompactTextString(m) }
func (*FsckRequest) ProtoMessage()    {}
func (*FsckRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{28}
}

func (m *FsckRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FsckRequest.Unmarshal(m, b)
}
func (m *FsckRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FsckRequest.Marshal(b, m, deterministic)
}
func (m *FsckRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FsckRequest.Merge(m, src)
}
func (m *FsckRequest) XXX_Size() int {
	return xxx_messageInfo_FsckRequest.Size(m)
}
func (m *FsckRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_FsckRequest.DiscardUnknown(m)
}

var xxx_messageInfo_FsckRequest proto.InternalMessageInfo

func (m *FsckRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type FsckResponse struct {
	Error                []byte   `protobuf:"bytes,1,opt,name=error,proto3" json:"error,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FsckResponse) Reset()         { *m = FsckResponse{} }
func (m *FsckResponse) String() string { return proto.CompactTextString(m) }
func (*FsckResponse) ProtoMessage()    {}
func (*FsckResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{29}
}

func (m *FsckResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FsckResponse.Unmarshal(m, b)
}
func (m *FsckResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FsckResponse.Marshal(b, m, deterministic)
}
func (m *FsckResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FsckResponse.Merge(m, src)
}
func (m *FsckResponse) XXX_Size() int {
	return xxx_messageInfo_FsckResponse.Size(m)
}
func (m *FsckResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_FsckResponse.DiscardUnknown(m)
}

var xxx_messageInfo_FsckResponse proto.InternalMessageInfo

func (m *FsckResponse) GetError() []byte {
	if m != nil {
		return m.Error
	}
	return nil
}

type WriteRefRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Ref                  []byte      `protobuf:"bytes,2,opt,name=ref,proto3" json:"ref,omitempty"`
	Revision             []byte      `protobuf:"bytes,3,opt,name=revision,proto3" json:"revision,omitempty"`
	OldRevision          []byte      `protobuf:"bytes,4,opt,name=old_revision,json=oldRevision,proto3" json:"old_revision,omitempty"`
	Force                bool        `protobuf:"varint,5,opt,name=force,proto3" json:"force,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *WriteRefRequest) Reset()         { *m = WriteRefRequest{} }
func (m *WriteRefRequest) String() string { return proto.CompactTextString(m) }
func (*WriteRefRequest) ProtoMessage()    {}
func (*WriteRefRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{30}
}

func (m *WriteRefRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_WriteRefRequest.Unmarshal(m, b)
}
func (m *WriteRefRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_WriteRefRequest.Marshal(b, m, deterministic)
}
func (m *WriteRefRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_WriteRefRequest.Merge(m, src)
}
func (m *WriteRefRequest) XXX_Size() int {
	return xxx_messageInfo_WriteRefRequest.Size(m)
}
func (m *WriteRefRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_WriteRefRequest.DiscardUnknown(m)
}

var xxx_messageInfo_WriteRefRequest proto.InternalMessageInfo

func (m *WriteRefRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *WriteRefRequest) GetRef() []byte {
	if m != nil {
		return m.Ref
	}
	return nil
}

func (m *WriteRefRequest) GetRevision() []byte {
	if m != nil {
		return m.Revision
	}
	return nil
}

func (m *WriteRefRequest) GetOldRevision() []byte {
	if m != nil {
		return m.OldRevision
	}
	return nil
}

func (m *WriteRefRequest) GetForce() bool {
	if m != nil {
		return m.Force
	}
	return false
}

type WriteRefResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *WriteRefResponse) Reset()         { *m = WriteRefResponse{} }
func (m *WriteRefResponse) String() string { return proto.CompactTextString(m) }
func (*WriteRefResponse) ProtoMessage()    {}
func (*WriteRefResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{31}
}

func (m *WriteRefResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_WriteRefResponse.Unmarshal(m, b)
}
func (m *WriteRefResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_WriteRefResponse.Marshal(b, m, deterministic)
}
func (m *WriteRefResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_WriteRefResponse.Merge(m, src)
}
func (m *WriteRefResponse) XXX_Size() int {
	return xxx_messageInfo_WriteRefResponse.Size(m)
}
func (m *WriteRefResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_WriteRefResponse.DiscardUnknown(m)
}

var xxx_messageInfo_WriteRefResponse proto.InternalMessageInfo

type FindMergeBaseRequest struct {
	Repository *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	// We use a repeated field because rugged supports finding a base
	// for more than 2 revisions, so if we needed that in the future we don't
	// need to change the protocol.
	Revisions            [][]byte `protobuf:"bytes,2,rep,name=revisions,proto3" json:"revisions,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FindMergeBaseRequest) Reset()         { *m = FindMergeBaseRequest{} }
func (m *FindMergeBaseRequest) String() string { return proto.CompactTextString(m) }
func (*FindMergeBaseRequest) ProtoMessage()    {}
func (*FindMergeBaseRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{32}
}

func (m *FindMergeBaseRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FindMergeBaseRequest.Unmarshal(m, b)
}
func (m *FindMergeBaseRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FindMergeBaseRequest.Marshal(b, m, deterministic)
}
func (m *FindMergeBaseRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FindMergeBaseRequest.Merge(m, src)
}
func (m *FindMergeBaseRequest) XXX_Size() int {
	return xxx_messageInfo_FindMergeBaseRequest.Size(m)
}
func (m *FindMergeBaseRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_FindMergeBaseRequest.DiscardUnknown(m)
}

var xxx_messageInfo_FindMergeBaseRequest proto.InternalMessageInfo

func (m *FindMergeBaseRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *FindMergeBaseRequest) GetRevisions() [][]byte {
	if m != nil {
		return m.Revisions
	}
	return nil
}

type FindMergeBaseResponse struct {
	Base                 string   `protobuf:"bytes,1,opt,name=base,proto3" json:"base,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FindMergeBaseResponse) Reset()         { *m = FindMergeBaseResponse{} }
func (m *FindMergeBaseResponse) String() string { return proto.CompactTextString(m) }
func (*FindMergeBaseResponse) ProtoMessage()    {}
func (*FindMergeBaseResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{33}
}

func (m *FindMergeBaseResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FindMergeBaseResponse.Unmarshal(m, b)
}
func (m *FindMergeBaseResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FindMergeBaseResponse.Marshal(b, m, deterministic)
}
func (m *FindMergeBaseResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FindMergeBaseResponse.Merge(m, src)
}
func (m *FindMergeBaseResponse) XXX_Size() int {
	return xxx_messageInfo_FindMergeBaseResponse.Size(m)
}
func (m *FindMergeBaseResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_FindMergeBaseResponse.DiscardUnknown(m)
}

var xxx_messageInfo_FindMergeBaseResponse proto.InternalMessageInfo

func (m *FindMergeBaseResponse) GetBase() string {
	if m != nil {
		return m.Base
	}
	return ""
}

type CreateForkRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	SourceRepository     *Repository `protobuf:"bytes,2,opt,name=source_repository,json=sourceRepository,proto3" json:"source_repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CreateForkRequest) Reset()         { *m = CreateForkRequest{} }
func (m *CreateForkRequest) String() string { return proto.CompactTextString(m) }
func (*CreateForkRequest) ProtoMessage()    {}
func (*CreateForkRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{34}
}

func (m *CreateForkRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateForkRequest.Unmarshal(m, b)
}
func (m *CreateForkRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateForkRequest.Marshal(b, m, deterministic)
}
func (m *CreateForkRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateForkRequest.Merge(m, src)
}
func (m *CreateForkRequest) XXX_Size() int {
	return xxx_messageInfo_CreateForkRequest.Size(m)
}
func (m *CreateForkRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateForkRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateForkRequest proto.InternalMessageInfo

func (m *CreateForkRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *CreateForkRequest) GetSourceRepository() *Repository {
	if m != nil {
		return m.SourceRepository
	}
	return nil
}

type CreateForkResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CreateForkResponse) Reset()         { *m = CreateForkResponse{} }
func (m *CreateForkResponse) String() string { return proto.CompactTextString(m) }
func (*CreateForkResponse) ProtoMessage()    {}
func (*CreateForkResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{35}
}

func (m *CreateForkResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateForkResponse.Unmarshal(m, b)
}
func (m *CreateForkResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateForkResponse.Marshal(b, m, deterministic)
}
func (m *CreateForkResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateForkResponse.Merge(m, src)
}
func (m *CreateForkResponse) XXX_Size() int {
	return xxx_messageInfo_CreateForkResponse.Size(m)
}
func (m *CreateForkResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateForkResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CreateForkResponse proto.InternalMessageInfo

type IsRebaseInProgressRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	RebaseId             string      `protobuf:"bytes,2,opt,name=rebase_id,json=rebaseId,proto3" json:"rebase_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *IsRebaseInProgressRequest) Reset()         { *m = IsRebaseInProgressRequest{} }
func (m *IsRebaseInProgressRequest) String() string { return proto.CompactTextString(m) }
func (*IsRebaseInProgressRequest) ProtoMessage()    {}
func (*IsRebaseInProgressRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{36}
}

func (m *IsRebaseInProgressRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_IsRebaseInProgressRequest.Unmarshal(m, b)
}
func (m *IsRebaseInProgressRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_IsRebaseInProgressRequest.Marshal(b, m, deterministic)
}
func (m *IsRebaseInProgressRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_IsRebaseInProgressRequest.Merge(m, src)
}
func (m *IsRebaseInProgressRequest) XXX_Size() int {
	return xxx_messageInfo_IsRebaseInProgressRequest.Size(m)
}
func (m *IsRebaseInProgressRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_IsRebaseInProgressRequest.DiscardUnknown(m)
}

var xxx_messageInfo_IsRebaseInProgressRequest proto.InternalMessageInfo

func (m *IsRebaseInProgressRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *IsRebaseInProgressRequest) GetRebaseId() string {
	if m != nil {
		return m.RebaseId
	}
	return ""
}

type IsRebaseInProgressResponse struct {
	InProgress           bool     `protobuf:"varint,1,opt,name=in_progress,json=inProgress,proto3" json:"in_progress,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *IsRebaseInProgressResponse) Reset()         { *m = IsRebaseInProgressResponse{} }
func (m *IsRebaseInProgressResponse) String() string { return proto.CompactTextString(m) }
func (*IsRebaseInProgressResponse) ProtoMessage()    {}
func (*IsRebaseInProgressResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{37}
}

func (m *IsRebaseInProgressResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_IsRebaseInProgressResponse.Unmarshal(m, b)
}
func (m *IsRebaseInProgressResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_IsRebaseInProgressResponse.Marshal(b, m, deterministic)
}
func (m *IsRebaseInProgressResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_IsRebaseInProgressResponse.Merge(m, src)
}
func (m *IsRebaseInProgressResponse) XXX_Size() int {
	return xxx_messageInfo_IsRebaseInProgressResponse.Size(m)
}
func (m *IsRebaseInProgressResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_IsRebaseInProgressResponse.DiscardUnknown(m)
}

var xxx_messageInfo_IsRebaseInProgressResponse proto.InternalMessageInfo

func (m *IsRebaseInProgressResponse) GetInProgress() bool {
	if m != nil {
		return m.InProgress
	}
	return false
}

type IsSquashInProgressRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	SquashId             string      `protobuf:"bytes,2,opt,name=squash_id,json=squashId,proto3" json:"squash_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *IsSquashInProgressRequest) Reset()         { *m = IsSquashInProgressRequest{} }
func (m *IsSquashInProgressRequest) String() string { return proto.CompactTextString(m) }
func (*IsSquashInProgressRequest) ProtoMessage()    {}
func (*IsSquashInProgressRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{38}
}

func (m *IsSquashInProgressRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_IsSquashInProgressRequest.Unmarshal(m, b)
}
func (m *IsSquashInProgressRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_IsSquashInProgressRequest.Marshal(b, m, deterministic)
}
func (m *IsSquashInProgressRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_IsSquashInProgressRequest.Merge(m, src)
}
func (m *IsSquashInProgressRequest) XXX_Size() int {
	return xxx_messageInfo_IsSquashInProgressRequest.Size(m)
}
func (m *IsSquashInProgressRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_IsSquashInProgressRequest.DiscardUnknown(m)
}

var xxx_messageInfo_IsSquashInProgressRequest proto.InternalMessageInfo

func (m *IsSquashInProgressRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *IsSquashInProgressRequest) GetSquashId() string {
	if m != nil {
		return m.SquashId
	}
	return ""
}

type IsSquashInProgressResponse struct {
	InProgress           bool     `protobuf:"varint,1,opt,name=in_progress,json=inProgress,proto3" json:"in_progress,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *IsSquashInProgressResponse) Reset()         { *m = IsSquashInProgressResponse{} }
func (m *IsSquashInProgressResponse) String() string { return proto.CompactTextString(m) }
func (*IsSquashInProgressResponse) ProtoMessage()    {}
func (*IsSquashInProgressResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{39}
}

func (m *IsSquashInProgressResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_IsSquashInProgressResponse.Unmarshal(m, b)
}
func (m *IsSquashInProgressResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_IsSquashInProgressResponse.Marshal(b, m, deterministic)
}
func (m *IsSquashInProgressResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_IsSquashInProgressResponse.Merge(m, src)
}
func (m *IsSquashInProgressResponse) XXX_Size() int {
	return xxx_messageInfo_IsSquashInProgressResponse.Size(m)
}
func (m *IsSquashInProgressResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_IsSquashInProgressResponse.DiscardUnknown(m)
}

var xxx_messageInfo_IsSquashInProgressResponse proto.InternalMessageInfo

func (m *IsSquashInProgressResponse) GetInProgress() bool {
	if m != nil {
		return m.InProgress
	}
	return false
}

type CreateRepositoryFromURLRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Url                  string      `protobuf:"bytes,2,opt,name=url,proto3" json:"url,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CreateRepositoryFromURLRequest) Reset()         { *m = CreateRepositoryFromURLRequest{} }
func (m *CreateRepositoryFromURLRequest) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromURLRequest) ProtoMessage()    {}
func (*CreateRepositoryFromURLRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{40}
}

func (m *CreateRepositoryFromURLRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateRepositoryFromURLRequest.Unmarshal(m, b)
}
func (m *CreateRepositoryFromURLRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateRepositoryFromURLRequest.Marshal(b, m, deterministic)
}
func (m *CreateRepositoryFromURLRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateRepositoryFromURLRequest.Merge(m, src)
}
func (m *CreateRepositoryFromURLRequest) XXX_Size() int {
	return xxx_messageInfo_CreateRepositoryFromURLRequest.Size(m)
}
func (m *CreateRepositoryFromURLRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateRepositoryFromURLRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateRepositoryFromURLRequest proto.InternalMessageInfo

func (m *CreateRepositoryFromURLRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *CreateRepositoryFromURLRequest) GetUrl() string {
	if m != nil {
		return m.Url
	}
	return ""
}

type CreateRepositoryFromURLResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CreateRepositoryFromURLResponse) Reset()         { *m = CreateRepositoryFromURLResponse{} }
func (m *CreateRepositoryFromURLResponse) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromURLResponse) ProtoMessage()    {}
func (*CreateRepositoryFromURLResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{41}
}

func (m *CreateRepositoryFromURLResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateRepositoryFromURLResponse.Unmarshal(m, b)
}
func (m *CreateRepositoryFromURLResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateRepositoryFromURLResponse.Marshal(b, m, deterministic)
}
func (m *CreateRepositoryFromURLResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateRepositoryFromURLResponse.Merge(m, src)
}
func (m *CreateRepositoryFromURLResponse) XXX_Size() int {
	return xxx_messageInfo_CreateRepositoryFromURLResponse.Size(m)
}
func (m *CreateRepositoryFromURLResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateRepositoryFromURLResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CreateRepositoryFromURLResponse proto.InternalMessageInfo

type CreateBundleRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CreateBundleRequest) Reset()         { *m = CreateBundleRequest{} }
func (m *CreateBundleRequest) String() string { return proto.CompactTextString(m) }
func (*CreateBundleRequest) ProtoMessage()    {}
func (*CreateBundleRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{42}
}

func (m *CreateBundleRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateBundleRequest.Unmarshal(m, b)
}
func (m *CreateBundleRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateBundleRequest.Marshal(b, m, deterministic)
}
func (m *CreateBundleRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateBundleRequest.Merge(m, src)
}
func (m *CreateBundleRequest) XXX_Size() int {
	return xxx_messageInfo_CreateBundleRequest.Size(m)
}
func (m *CreateBundleRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateBundleRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateBundleRequest proto.InternalMessageInfo

func (m *CreateBundleRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type CreateBundleResponse struct {
	Data                 []byte   `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CreateBundleResponse) Reset()         { *m = CreateBundleResponse{} }
func (m *CreateBundleResponse) String() string { return proto.CompactTextString(m) }
func (*CreateBundleResponse) ProtoMessage()    {}
func (*CreateBundleResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{43}
}

func (m *CreateBundleResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateBundleResponse.Unmarshal(m, b)
}
func (m *CreateBundleResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateBundleResponse.Marshal(b, m, deterministic)
}
func (m *CreateBundleResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateBundleResponse.Merge(m, src)
}
func (m *CreateBundleResponse) XXX_Size() int {
	return xxx_messageInfo_CreateBundleResponse.Size(m)
}
func (m *CreateBundleResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateBundleResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CreateBundleResponse proto.InternalMessageInfo

func (m *CreateBundleResponse) GetData() []byte {
	if m != nil {
		return m.Data
	}
	return nil
}

// GetConfigRequest is a request for the GetConfig RPC.
type GetConfigRequest struct {
	// Repository is the repository from which the configuration should be read
	// from.
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *GetConfigRequest) Reset()         { *m = GetConfigRequest{} }
func (m *GetConfigRequest) String() string { return proto.CompactTextString(m) }
func (*GetConfigRequest) ProtoMessage()    {}
func (*GetConfigRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{44}
}

func (m *GetConfigRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetConfigRequest.Unmarshal(m, b)
}
func (m *GetConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetConfigRequest.Marshal(b, m, deterministic)
}
func (m *GetConfigRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetConfigRequest.Merge(m, src)
}
func (m *GetConfigRequest) XXX_Size() int {
	return xxx_messageInfo_GetConfigRequest.Size(m)
}
func (m *GetConfigRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetConfigRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetConfigRequest proto.InternalMessageInfo

func (m *GetConfigRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

// GetConfigResponse is a response for the GetConfig RPC.
type GetConfigResponse struct {
	// Data contains contents of the gitconfig.
	Data                 []byte   `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetConfigResponse) Reset()         { *m = GetConfigResponse{} }
func (m *GetConfigResponse) String() string { return proto.CompactTextString(m) }
func (*GetConfigResponse) ProtoMessage()    {}
func (*GetConfigResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{45}
}

func (m *GetConfigResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetConfigResponse.Unmarshal(m, b)
}
func (m *GetConfigResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetConfigResponse.Marshal(b, m, deterministic)
}
func (m *GetConfigResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetConfigResponse.Merge(m, src)
}
func (m *GetConfigResponse) XXX_Size() int {
	return xxx_messageInfo_GetConfigResponse.Size(m)
}
func (m *GetConfigResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GetConfigResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GetConfigResponse proto.InternalMessageInfo

func (m *GetConfigResponse) GetData() []byte {
	if m != nil {
		return m.Data
	}
	return nil
}

type SetConfigRequest struct {
	Repository           *Repository               `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Entries              []*SetConfigRequest_Entry `protobuf:"bytes,2,rep,name=entries,proto3" json:"entries,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                  `json:"-"`
	XXX_unrecognized     []byte                    `json:"-"`
	XXX_sizecache        int32                     `json:"-"`
}

func (m *SetConfigRequest) Reset()         { *m = SetConfigRequest{} }
func (m *SetConfigRequest) String() string { return proto.CompactTextString(m) }
func (*SetConfigRequest) ProtoMessage()    {}
func (*SetConfigRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{46}
}

func (m *SetConfigRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SetConfigRequest.Unmarshal(m, b)
}
func (m *SetConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SetConfigRequest.Marshal(b, m, deterministic)
}
func (m *SetConfigRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SetConfigRequest.Merge(m, src)
}
func (m *SetConfigRequest) XXX_Size() int {
	return xxx_messageInfo_SetConfigRequest.Size(m)
}
func (m *SetConfigRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_SetConfigRequest.DiscardUnknown(m)
}

var xxx_messageInfo_SetConfigRequest proto.InternalMessageInfo

func (m *SetConfigRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *SetConfigRequest) GetEntries() []*SetConfigRequest_Entry {
	if m != nil {
		return m.Entries
	}
	return nil
}

type SetConfigRequest_Entry struct {
	Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	// Types that are valid to be assigned to Value:
	//	*SetConfigRequest_Entry_ValueStr
	//	*SetConfigRequest_Entry_ValueInt32
	//	*SetConfigRequest_Entry_ValueBool
	Value                isSetConfigRequest_Entry_Value `protobuf_oneof:"value"`
	XXX_NoUnkeyedLiteral struct{}                       `json:"-"`
	XXX_unrecognized     []byte                         `json:"-"`
	XXX_sizecache        int32                          `json:"-"`
}

func (m *SetConfigRequest_Entry) Reset()         { *m = SetConfigRequest_Entry{} }
func (m *SetConfigRequest_Entry) String() string { return proto.CompactTextString(m) }
func (*SetConfigRequest_Entry) ProtoMessage()    {}
func (*SetConfigRequest_Entry) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{46, 0}
}

func (m *SetConfigRequest_Entry) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SetConfigRequest_Entry.Unmarshal(m, b)
}
func (m *SetConfigRequest_Entry) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SetConfigRequest_Entry.Marshal(b, m, deterministic)
}
func (m *SetConfigRequest_Entry) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SetConfigRequest_Entry.Merge(m, src)
}
func (m *SetConfigRequest_Entry) XXX_Size() int {
	return xxx_messageInfo_SetConfigRequest_Entry.Size(m)
}
func (m *SetConfigRequest_Entry) XXX_DiscardUnknown() {
	xxx_messageInfo_SetConfigRequest_Entry.DiscardUnknown(m)
}

var xxx_messageInfo_SetConfigRequest_Entry proto.InternalMessageInfo

func (m *SetConfigRequest_Entry) GetKey() string {
	if m != nil {
		return m.Key
	}
	return ""
}

type isSetConfigRequest_Entry_Value interface {
	isSetConfigRequest_Entry_Value()
}

type SetConfigRequest_Entry_ValueStr struct {
	ValueStr string `protobuf:"bytes,2,opt,name=value_str,json=valueStr,proto3,oneof"`
}

type SetConfigRequest_Entry_ValueInt32 struct {
	ValueInt32 int32 `protobuf:"varint,3,opt,name=value_int32,json=valueInt32,proto3,oneof"`
}

type SetConfigRequest_Entry_ValueBool struct {
	ValueBool bool `protobuf:"varint,4,opt,name=value_bool,json=valueBool,proto3,oneof"`
}

func (*SetConfigRequest_Entry_ValueStr) isSetConfigRequest_Entry_Value() {}

func (*SetConfigRequest_Entry_ValueInt32) isSetConfigRequest_Entry_Value() {}

func (*SetConfigRequest_Entry_ValueBool) isSetConfigRequest_Entry_Value() {}

func (m *SetConfigRequest_Entry) GetValue() isSetConfigRequest_Entry_Value {
	if m != nil {
		return m.Value
	}
	return nil
}

func (m *SetConfigRequest_Entry) GetValueStr() string {
	if x, ok := m.GetValue().(*SetConfigRequest_Entry_ValueStr); ok {
		return x.ValueStr
	}
	return ""
}

func (m *SetConfigRequest_Entry) GetValueInt32() int32 {
	if x, ok := m.GetValue().(*SetConfigRequest_Entry_ValueInt32); ok {
		return x.ValueInt32
	}
	return 0
}

func (m *SetConfigRequest_Entry) GetValueBool() bool {
	if x, ok := m.GetValue().(*SetConfigRequest_Entry_ValueBool); ok {
		return x.ValueBool
	}
	return false
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*SetConfigRequest_Entry) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*SetConfigRequest_Entry_ValueStr)(nil),
		(*SetConfigRequest_Entry_ValueInt32)(nil),
		(*SetConfigRequest_Entry_ValueBool)(nil),
	}
}

type SetConfigResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SetConfigResponse) Reset()         { *m = SetConfigResponse{} }
func (m *SetConfigResponse) String() string { return proto.CompactTextString(m) }
func (*SetConfigResponse) ProtoMessage()    {}
func (*SetConfigResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{47}
}

func (m *SetConfigResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SetConfigResponse.Unmarshal(m, b)
}
func (m *SetConfigResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SetConfigResponse.Marshal(b, m, deterministic)
}
func (m *SetConfigResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SetConfigResponse.Merge(m, src)
}
func (m *SetConfigResponse) XXX_Size() int {
	return xxx_messageInfo_SetConfigResponse.Size(m)
}
func (m *SetConfigResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_SetConfigResponse.DiscardUnknown(m)
}

var xxx_messageInfo_SetConfigResponse proto.InternalMessageInfo

type DeleteConfigRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Keys                 []string    `protobuf:"bytes,2,rep,name=keys,proto3" json:"keys,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *DeleteConfigRequest) Reset()         { *m = DeleteConfigRequest{} }
func (m *DeleteConfigRequest) String() string { return proto.CompactTextString(m) }
func (*DeleteConfigRequest) ProtoMessage()    {}
func (*DeleteConfigRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{48}
}

func (m *DeleteConfigRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DeleteConfigRequest.Unmarshal(m, b)
}
func (m *DeleteConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DeleteConfigRequest.Marshal(b, m, deterministic)
}
func (m *DeleteConfigRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DeleteConfigRequest.Merge(m, src)
}
func (m *DeleteConfigRequest) XXX_Size() int {
	return xxx_messageInfo_DeleteConfigRequest.Size(m)
}
func (m *DeleteConfigRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_DeleteConfigRequest.DiscardUnknown(m)
}

var xxx_messageInfo_DeleteConfigRequest proto.InternalMessageInfo

func (m *DeleteConfigRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *DeleteConfigRequest) GetKeys() []string {
	if m != nil {
		return m.Keys
	}
	return nil
}

type DeleteConfigResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *DeleteConfigResponse) Reset()         { *m = DeleteConfigResponse{} }
func (m *DeleteConfigResponse) String() string { return proto.CompactTextString(m) }
func (*DeleteConfigResponse) ProtoMessage()    {}
func (*DeleteConfigResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{49}
}

func (m *DeleteConfigResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DeleteConfigResponse.Unmarshal(m, b)
}
func (m *DeleteConfigResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DeleteConfigResponse.Marshal(b, m, deterministic)
}
func (m *DeleteConfigResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DeleteConfigResponse.Merge(m, src)
}
func (m *DeleteConfigResponse) XXX_Size() int {
	return xxx_messageInfo_DeleteConfigResponse.Size(m)
}
func (m *DeleteConfigResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_DeleteConfigResponse.DiscardUnknown(m)
}

var xxx_messageInfo_DeleteConfigResponse proto.InternalMessageInfo

type RestoreCustomHooksRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Data                 []byte      `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *RestoreCustomHooksRequest) Reset()         { *m = RestoreCustomHooksRequest{} }
func (m *RestoreCustomHooksRequest) String() string { return proto.CompactTextString(m) }
func (*RestoreCustomHooksRequest) ProtoMessage()    {}
func (*RestoreCustomHooksRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{50}
}

func (m *RestoreCustomHooksRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RestoreCustomHooksRequest.Unmarshal(m, b)
}
func (m *RestoreCustomHooksRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RestoreCustomHooksRequest.Marshal(b, m, deterministic)
}
func (m *RestoreCustomHooksRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RestoreCustomHooksRequest.Merge(m, src)
}
func (m *RestoreCustomHooksRequest) XXX_Size() int {
	return xxx_messageInfo_RestoreCustomHooksRequest.Size(m)
}
func (m *RestoreCustomHooksRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_RestoreCustomHooksRequest.DiscardUnknown(m)
}

var xxx_messageInfo_RestoreCustomHooksRequest proto.InternalMessageInfo

func (m *RestoreCustomHooksRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *RestoreCustomHooksRequest) GetData() []byte {
	if m != nil {
		return m.Data
	}
	return nil
}

type RestoreCustomHooksResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *RestoreCustomHooksResponse) Reset()         { *m = RestoreCustomHooksResponse{} }
func (m *RestoreCustomHooksResponse) String() string { return proto.CompactTextString(m) }
func (*RestoreCustomHooksResponse) ProtoMessage()    {}
func (*RestoreCustomHooksResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{51}
}

func (m *RestoreCustomHooksResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RestoreCustomHooksResponse.Unmarshal(m, b)
}
func (m *RestoreCustomHooksResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RestoreCustomHooksResponse.Marshal(b, m, deterministic)
}
func (m *RestoreCustomHooksResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RestoreCustomHooksResponse.Merge(m, src)
}
func (m *RestoreCustomHooksResponse) XXX_Size() int {
	return xxx_messageInfo_RestoreCustomHooksResponse.Size(m)
}
func (m *RestoreCustomHooksResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_RestoreCustomHooksResponse.DiscardUnknown(m)
}

var xxx_messageInfo_RestoreCustomHooksResponse proto.InternalMessageInfo

type BackupCustomHooksRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *BackupCustomHooksRequest) Reset()         { *m = BackupCustomHooksRequest{} }
func (m *BackupCustomHooksRequest) String() string { return proto.CompactTextString(m) }
func (*BackupCustomHooksRequest) ProtoMessage()    {}
func (*BackupCustomHooksRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{52}
}

func (m *BackupCustomHooksRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_BackupCustomHooksRequest.Unmarshal(m, b)
}
func (m *BackupCustomHooksRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_BackupCustomHooksRequest.Marshal(b, m, deterministic)
}
func (m *BackupCustomHooksRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_BackupCustomHooksRequest.Merge(m, src)
}
func (m *BackupCustomHooksRequest) XXX_Size() int {
	return xxx_messageInfo_BackupCustomHooksRequest.Size(m)
}
func (m *BackupCustomHooksRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_BackupCustomHooksRequest.DiscardUnknown(m)
}

var xxx_messageInfo_BackupCustomHooksRequest proto.InternalMessageInfo

func (m *BackupCustomHooksRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type BackupCustomHooksResponse struct {
	Data                 []byte   `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *BackupCustomHooksResponse) Reset()         { *m = BackupCustomHooksResponse{} }
func (m *BackupCustomHooksResponse) String() string { return proto.CompactTextString(m) }
func (*BackupCustomHooksResponse) ProtoMessage()    {}
func (*BackupCustomHooksResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{53}
}

func (m *BackupCustomHooksResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_BackupCustomHooksResponse.Unmarshal(m, b)
}
func (m *BackupCustomHooksResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_BackupCustomHooksResponse.Marshal(b, m, deterministic)
}
func (m *BackupCustomHooksResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_BackupCustomHooksResponse.Merge(m, src)
}
func (m *BackupCustomHooksResponse) XXX_Size() int {
	return xxx_messageInfo_BackupCustomHooksResponse.Size(m)
}
func (m *BackupCustomHooksResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_BackupCustomHooksResponse.DiscardUnknown(m)
}

var xxx_messageInfo_BackupCustomHooksResponse proto.InternalMessageInfo

func (m *BackupCustomHooksResponse) GetData() []byte {
	if m != nil {
		return m.Data
	}
	return nil
}

type CreateRepositoryFromBundleRequest struct {
	// Only available on the first message
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Data                 []byte      `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CreateRepositoryFromBundleRequest) Reset()         { *m = CreateRepositoryFromBundleRequest{} }
func (m *CreateRepositoryFromBundleRequest) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromBundleRequest) ProtoMessage()    {}
func (*CreateRepositoryFromBundleRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{54}
}

func (m *CreateRepositoryFromBundleRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateRepositoryFromBundleRequest.Unmarshal(m, b)
}
func (m *CreateRepositoryFromBundleRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateRepositoryFromBundleRequest.Marshal(b, m, deterministic)
}
func (m *CreateRepositoryFromBundleRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateRepositoryFromBundleRequest.Merge(m, src)
}
func (m *CreateRepositoryFromBundleRequest) XXX_Size() int {
	return xxx_messageInfo_CreateRepositoryFromBundleRequest.Size(m)
}
func (m *CreateRepositoryFromBundleRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateRepositoryFromBundleRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateRepositoryFromBundleRequest proto.InternalMessageInfo

func (m *CreateRepositoryFromBundleRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *CreateRepositoryFromBundleRequest) GetData() []byte {
	if m != nil {
		return m.Data
	}
	return nil
}

type CreateRepositoryFromBundleResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CreateRepositoryFromBundleResponse) Reset()         { *m = CreateRepositoryFromBundleResponse{} }
func (m *CreateRepositoryFromBundleResponse) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromBundleResponse) ProtoMessage()    {}
func (*CreateRepositoryFromBundleResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{55}
}

func (m *CreateRepositoryFromBundleResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateRepositoryFromBundleResponse.Unmarshal(m, b)
}
func (m *CreateRepositoryFromBundleResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateRepositoryFromBundleResponse.Marshal(b, m, deterministic)
}
func (m *CreateRepositoryFromBundleResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateRepositoryFromBundleResponse.Merge(m, src)
}
func (m *CreateRepositoryFromBundleResponse) XXX_Size() int {
	return xxx_messageInfo_CreateRepositoryFromBundleResponse.Size(m)
}
func (m *CreateRepositoryFromBundleResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateRepositoryFromBundleResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CreateRepositoryFromBundleResponse proto.InternalMessageInfo

type FindLicenseRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *FindLicenseRequest) Reset()         { *m = FindLicenseRequest{} }
func (m *FindLicenseRequest) String() string { return proto.CompactTextString(m) }
func (*FindLicenseRequest) ProtoMessage()    {}
func (*FindLicenseRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{56}
}

func (m *FindLicenseRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FindLicenseRequest.Unmarshal(m, b)
}
func (m *FindLicenseRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FindLicenseRequest.Marshal(b, m, deterministic)
}
func (m *FindLicenseRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FindLicenseRequest.Merge(m, src)
}
func (m *FindLicenseRequest) XXX_Size() int {
	return xxx_messageInfo_FindLicenseRequest.Size(m)
}
func (m *FindLicenseRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_FindLicenseRequest.DiscardUnknown(m)
}

var xxx_messageInfo_FindLicenseRequest proto.InternalMessageInfo

func (m *FindLicenseRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type FindLicenseResponse struct {
	LicenseShortName     string   `protobuf:"bytes,1,opt,name=license_short_name,json=licenseShortName,proto3" json:"license_short_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FindLicenseResponse) Reset()         { *m = FindLicenseResponse{} }
func (m *FindLicenseResponse) String() string { return proto.CompactTextString(m) }
func (*FindLicenseResponse) ProtoMessage()    {}
func (*FindLicenseResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{57}
}

func (m *FindLicenseResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FindLicenseResponse.Unmarshal(m, b)
}
func (m *FindLicenseResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FindLicenseResponse.Marshal(b, m, deterministic)
}
func (m *FindLicenseResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FindLicenseResponse.Merge(m, src)
}
func (m *FindLicenseResponse) XXX_Size() int {
	return xxx_messageInfo_FindLicenseResponse.Size(m)
}
func (m *FindLicenseResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_FindLicenseResponse.DiscardUnknown(m)
}

var xxx_messageInfo_FindLicenseResponse proto.InternalMessageInfo

func (m *FindLicenseResponse) GetLicenseShortName() string {
	if m != nil {
		return m.LicenseShortName
	}
	return ""
}

type GetInfoAttributesRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *GetInfoAttributesRequest) Reset()         { *m = GetInfoAttributesRequest{} }
func (m *GetInfoAttributesRequest) String() string { return proto.CompactTextString(m) }
func (*GetInfoAttributesRequest) ProtoMessage()    {}
func (*GetInfoAttributesRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{58}
}

func (m *GetInfoAttributesRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetInfoAttributesRequest.Unmarshal(m, b)
}
func (m *GetInfoAttributesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetInfoAttributesRequest.Marshal(b, m, deterministic)
}
func (m *GetInfoAttributesRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetInfoAttributesRequest.Merge(m, src)
}
func (m *GetInfoAttributesRequest) XXX_Size() int {
	return xxx_messageInfo_GetInfoAttributesRequest.Size(m)
}
func (m *GetInfoAttributesRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetInfoAttributesRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetInfoAttributesRequest proto.InternalMessageInfo

func (m *GetInfoAttributesRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type GetInfoAttributesResponse struct {
	Attributes           []byte   `protobuf:"bytes,1,opt,name=attributes,proto3" json:"attributes,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetInfoAttributesResponse) Reset()         { *m = GetInfoAttributesResponse{} }
func (m *GetInfoAttributesResponse) String() string { return proto.CompactTextString(m) }
func (*GetInfoAttributesResponse) ProtoMessage()    {}
func (*GetInfoAttributesResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{59}
}

func (m *GetInfoAttributesResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetInfoAttributesResponse.Unmarshal(m, b)
}
func (m *GetInfoAttributesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetInfoAttributesResponse.Marshal(b, m, deterministic)
}
func (m *GetInfoAttributesResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetInfoAttributesResponse.Merge(m, src)
}
func (m *GetInfoAttributesResponse) XXX_Size() int {
	return xxx_messageInfo_GetInfoAttributesResponse.Size(m)
}
func (m *GetInfoAttributesResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GetInfoAttributesResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GetInfoAttributesResponse proto.InternalMessageInfo

func (m *GetInfoAttributesResponse) GetAttributes() []byte {
	if m != nil {
		return m.Attributes
	}
	return nil
}

type CalculateChecksumRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CalculateChecksumRequest) Reset()         { *m = CalculateChecksumRequest{} }
func (m *CalculateChecksumRequest) String() string { return proto.CompactTextString(m) }
func (*CalculateChecksumRequest) ProtoMessage()    {}
func (*CalculateChecksumRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{60}
}

func (m *CalculateChecksumRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CalculateChecksumRequest.Unmarshal(m, b)
}
func (m *CalculateChecksumRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CalculateChecksumRequest.Marshal(b, m, deterministic)
}
func (m *CalculateChecksumRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CalculateChecksumRequest.Merge(m, src)
}
func (m *CalculateChecksumRequest) XXX_Size() int {
	return xxx_messageInfo_CalculateChecksumRequest.Size(m)
}
func (m *CalculateChecksumRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CalculateChecksumRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CalculateChecksumRequest proto.InternalMessageInfo

func (m *CalculateChecksumRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type CalculateChecksumResponse struct {
	Checksum             string   `protobuf:"bytes,1,opt,name=checksum,proto3" json:"checksum,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CalculateChecksumResponse) Reset()         { *m = CalculateChecksumResponse{} }
func (m *CalculateChecksumResponse) String() string { return proto.CompactTextString(m) }
func (*CalculateChecksumResponse) ProtoMessage()    {}
func (*CalculateChecksumResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{61}
}

func (m *CalculateChecksumResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CalculateChecksumResponse.Unmarshal(m, b)
}
func (m *CalculateChecksumResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CalculateChecksumResponse.Marshal(b, m, deterministic)
}
func (m *CalculateChecksumResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CalculateChecksumResponse.Merge(m, src)
}
func (m *CalculateChecksumResponse) XXX_Size() int {
	return xxx_messageInfo_CalculateChecksumResponse.Size(m)
}
func (m *CalculateChecksumResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CalculateChecksumResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CalculateChecksumResponse proto.InternalMessageInfo

func (m *CalculateChecksumResponse) GetChecksum() string {
	if m != nil {
		return m.Checksum
	}
	return ""
}

type GetSnapshotRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *GetSnapshotRequest) Reset()         { *m = GetSnapshotRequest{} }
func (m *GetSnapshotRequest) String() string { return proto.CompactTextString(m) }
func (*GetSnapshotRequest) ProtoMessage()    {}
func (*GetSnapshotRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{62}
}

func (m *GetSnapshotRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetSnapshotRequest.Unmarshal(m, b)
}
func (m *GetSnapshotRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetSnapshotRequest.Marshal(b, m, deterministic)
}
func (m *GetSnapshotRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetSnapshotRequest.Merge(m, src)
}
func (m *GetSnapshotRequest) XXX_Size() int {
	return xxx_messageInfo_GetSnapshotRequest.Size(m)
}
func (m *GetSnapshotRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetSnapshotRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetSnapshotRequest proto.InternalMessageInfo

func (m *GetSnapshotRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type GetSnapshotResponse struct {
	Data                 []byte   `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetSnapshotResponse) Reset()         { *m = GetSnapshotResponse{} }
func (m *GetSnapshotResponse) String() string { return proto.CompactTextString(m) }
func (*GetSnapshotResponse) ProtoMessage()    {}
func (*GetSnapshotResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{63}
}

func (m *GetSnapshotResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetSnapshotResponse.Unmarshal(m, b)
}
func (m *GetSnapshotResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetSnapshotResponse.Marshal(b, m, deterministic)
}
func (m *GetSnapshotResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetSnapshotResponse.Merge(m, src)
}
func (m *GetSnapshotResponse) XXX_Size() int {
	return xxx_messageInfo_GetSnapshotResponse.Size(m)
}
func (m *GetSnapshotResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GetSnapshotResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GetSnapshotResponse proto.InternalMessageInfo

func (m *GetSnapshotResponse) GetData() []byte {
	if m != nil {
		return m.Data
	}
	return nil
}

type CreateRepositoryFromSnapshotRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	HttpUrl              string      `protobuf:"bytes,2,opt,name=http_url,json=httpUrl,proto3" json:"http_url,omitempty"`
	HttpAuth             string      `protobuf:"bytes,3,opt,name=http_auth,json=httpAuth,proto3" json:"http_auth,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CreateRepositoryFromSnapshotRequest) Reset()         { *m = CreateRepositoryFromSnapshotRequest{} }
func (m *CreateRepositoryFromSnapshotRequest) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromSnapshotRequest) ProtoMessage()    {}
func (*CreateRepositoryFromSnapshotRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{64}
}

func (m *CreateRepositoryFromSnapshotRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateRepositoryFromSnapshotRequest.Unmarshal(m, b)
}
func (m *CreateRepositoryFromSnapshotRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateRepositoryFromSnapshotRequest.Marshal(b, m, deterministic)
}
func (m *CreateRepositoryFromSnapshotRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateRepositoryFromSnapshotRequest.Merge(m, src)
}
func (m *CreateRepositoryFromSnapshotRequest) XXX_Size() int {
	return xxx_messageInfo_CreateRepositoryFromSnapshotRequest.Size(m)
}
func (m *CreateRepositoryFromSnapshotRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateRepositoryFromSnapshotRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateRepositoryFromSnapshotRequest proto.InternalMessageInfo

func (m *CreateRepositoryFromSnapshotRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *CreateRepositoryFromSnapshotRequest) GetHttpUrl() string {
	if m != nil {
		return m.HttpUrl
	}
	return ""
}

func (m *CreateRepositoryFromSnapshotRequest) GetHttpAuth() string {
	if m != nil {
		return m.HttpAuth
	}
	return ""
}

type CreateRepositoryFromSnapshotResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CreateRepositoryFromSnapshotResponse) Reset()         { *m = CreateRepositoryFromSnapshotResponse{} }
func (m *CreateRepositoryFromSnapshotResponse) String() string { return proto.CompactTextString(m) }
func (*CreateRepositoryFromSnapshotResponse) ProtoMessage()    {}
func (*CreateRepositoryFromSnapshotResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{65}
}

func (m *CreateRepositoryFromSnapshotResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateRepositoryFromSnapshotResponse.Unmarshal(m, b)
}
func (m *CreateRepositoryFromSnapshotResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateRepositoryFromSnapshotResponse.Marshal(b, m, deterministic)
}
func (m *CreateRepositoryFromSnapshotResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateRepositoryFromSnapshotResponse.Merge(m, src)
}
func (m *CreateRepositoryFromSnapshotResponse) XXX_Size() int {
	return xxx_messageInfo_CreateRepositoryFromSnapshotResponse.Size(m)
}
func (m *CreateRepositoryFromSnapshotResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateRepositoryFromSnapshotResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CreateRepositoryFromSnapshotResponse proto.InternalMessageInfo

type GetRawChangesRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	FromRevision         string      `protobuf:"bytes,2,opt,name=from_revision,json=fromRevision,proto3" json:"from_revision,omitempty"`
	ToRevision           string      `protobuf:"bytes,3,opt,name=to_revision,json=toRevision,proto3" json:"to_revision,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *GetRawChangesRequest) Reset()         { *m = GetRawChangesRequest{} }
func (m *GetRawChangesRequest) String() string { return proto.CompactTextString(m) }
func (*GetRawChangesRequest) ProtoMessage()    {}
func (*GetRawChangesRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{66}
}

func (m *GetRawChangesRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetRawChangesRequest.Unmarshal(m, b)
}
func (m *GetRawChangesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetRawChangesRequest.Marshal(b, m, deterministic)
}
func (m *GetRawChangesRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetRawChangesRequest.Merge(m, src)
}
func (m *GetRawChangesRequest) XXX_Size() int {
	return xxx_messageInfo_GetRawChangesRequest.Size(m)
}
func (m *GetRawChangesRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetRawChangesRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetRawChangesRequest proto.InternalMessageInfo

func (m *GetRawChangesRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *GetRawChangesRequest) GetFromRevision() string {
	if m != nil {
		return m.FromRevision
	}
	return ""
}

func (m *GetRawChangesRequest) GetToRevision() string {
	if m != nil {
		return m.ToRevision
	}
	return ""
}

type GetRawChangesResponse struct {
	RawChanges           []*GetRawChangesResponse_RawChange `protobuf:"bytes,1,rep,name=raw_changes,json=rawChanges,proto3" json:"raw_changes,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                           `json:"-"`
	XXX_unrecognized     []byte                             `json:"-"`
	XXX_sizecache        int32                              `json:"-"`
}

func (m *GetRawChangesResponse) Reset()         { *m = GetRawChangesResponse{} }
func (m *GetRawChangesResponse) String() string { return proto.CompactTextString(m) }
func (*GetRawChangesResponse) ProtoMessage()    {}
func (*GetRawChangesResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{67}
}

func (m *GetRawChangesResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetRawChangesResponse.Unmarshal(m, b)
}
func (m *GetRawChangesResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetRawChangesResponse.Marshal(b, m, deterministic)
}
func (m *GetRawChangesResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetRawChangesResponse.Merge(m, src)
}
func (m *GetRawChangesResponse) XXX_Size() int {
	return xxx_messageInfo_GetRawChangesResponse.Size(m)
}
func (m *GetRawChangesResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GetRawChangesResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GetRawChangesResponse proto.InternalMessageInfo

func (m *GetRawChangesResponse) GetRawChanges() []*GetRawChangesResponse_RawChange {
	if m != nil {
		return m.RawChanges
	}
	return nil
}

type GetRawChangesResponse_RawChange struct {
	BlobId string `protobuf:"bytes,1,opt,name=blob_id,json=blobId,proto3" json:"blob_id,omitempty"`
	Size   int64  `protobuf:"varint,2,opt,name=size,proto3" json:"size,omitempty"`
	// use fields 9 and 10 in place of 3 and 4 (respectively)
	NewPath      string                                    `protobuf:"bytes,3,opt,name=new_path,json=newPath,proto3" json:"new_path,omitempty"` // Deprecated: Do not use.
	OldPath      string                                    `protobuf:"bytes,4,opt,name=old_path,json=oldPath,proto3" json:"old_path,omitempty"` // Deprecated: Do not use.
	Operation    GetRawChangesResponse_RawChange_Operation `protobuf:"varint,5,opt,name=operation,proto3,enum=gitaly.GetRawChangesResponse_RawChange_Operation" json:"operation,omitempty"`
	RawOperation string                                    `protobuf:"bytes,6,opt,name=raw_operation,json=rawOperation,proto3" json:"raw_operation,omitempty"`
	OldMode      int32                                     `protobuf:"varint,7,opt,name=old_mode,json=oldMode,proto3" json:"old_mode,omitempty"`
	NewMode      int32                                     `protobuf:"varint,8,opt,name=new_mode,json=newMode,proto3" json:"new_mode,omitempty"`
	// the following fields, 9 and 10, will eventually replace 3 and 4
	NewPathBytes         []byte   `protobuf:"bytes,9,opt,name=new_path_bytes,json=newPathBytes,proto3" json:"new_path_bytes,omitempty"`
	OldPathBytes         []byte   `protobuf:"bytes,10,opt,name=old_path_bytes,json=oldPathBytes,proto3" json:"old_path_bytes,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetRawChangesResponse_RawChange) Reset()         { *m = GetRawChangesResponse_RawChange{} }
func (m *GetRawChangesResponse_RawChange) String() string { return proto.CompactTextString(m) }
func (*GetRawChangesResponse_RawChange) ProtoMessage()    {}
func (*GetRawChangesResponse_RawChange) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{67, 0}
}

func (m *GetRawChangesResponse_RawChange) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetRawChangesResponse_RawChange.Unmarshal(m, b)
}
func (m *GetRawChangesResponse_RawChange) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetRawChangesResponse_RawChange.Marshal(b, m, deterministic)
}
func (m *GetRawChangesResponse_RawChange) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetRawChangesResponse_RawChange.Merge(m, src)
}
func (m *GetRawChangesResponse_RawChange) XXX_Size() int {
	return xxx_messageInfo_GetRawChangesResponse_RawChange.Size(m)
}
func (m *GetRawChangesResponse_RawChange) XXX_DiscardUnknown() {
	xxx_messageInfo_GetRawChangesResponse_RawChange.DiscardUnknown(m)
}

var xxx_messageInfo_GetRawChangesResponse_RawChange proto.InternalMessageInfo

func (m *GetRawChangesResponse_RawChange) GetBlobId() string {
	if m != nil {
		return m.BlobId
	}
	return ""
}

func (m *GetRawChangesResponse_RawChange) GetSize() int64 {
	if m != nil {
		return m.Size
	}
	return 0
}

// Deprecated: Do not use.
func (m *GetRawChangesResponse_RawChange) GetNewPath() string {
	if m != nil {
		return m.NewPath
	}
	return ""
}

// Deprecated: Do not use.
func (m *GetRawChangesResponse_RawChange) GetOldPath() string {
	if m != nil {
		return m.OldPath
	}
	return ""
}

func (m *GetRawChangesResponse_RawChange) GetOperation() GetRawChangesResponse_RawChange_Operation {
	if m != nil {
		return m.Operation
	}
	return GetRawChangesResponse_RawChange_UNKNOWN
}

func (m *GetRawChangesResponse_RawChange) GetRawOperation() string {
	if m != nil {
		return m.RawOperation
	}
	return ""
}

func (m *GetRawChangesResponse_RawChange) GetOldMode() int32 {
	if m != nil {
		return m.OldMode
	}
	return 0
}

func (m *GetRawChangesResponse_RawChange) GetNewMode() int32 {
	if m != nil {
		return m.NewMode
	}
	return 0
}

func (m *GetRawChangesResponse_RawChange) GetNewPathBytes() []byte {
	if m != nil {
		return m.NewPathBytes
	}
	return nil
}

func (m *GetRawChangesResponse_RawChange) GetOldPathBytes() []byte {
	if m != nil {
		return m.OldPathBytes
	}
	return nil
}

type SearchFilesByNameRequest struct {
	Repository *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Query      string      `protobuf:"bytes,2,opt,name=query,proto3" json:"query,omitempty"`
	Ref        []byte      `protobuf:"bytes,3,opt,name=ref,proto3" json:"ref,omitempty"`
	// If `filter` is specified and non-empty, it will be parsed as a regular
	// expression and used to filter the result set before it is transmitted. It is
	// parsed using Go's `regexp` package, which is closely related to PCRE,
	// excluding backreferences, atomic/possesive operators, and some other
	// features. It has a maximum length of 1000 bytes.
	Filter               string   `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SearchFilesByNameRequest) Reset()         { *m = SearchFilesByNameRequest{} }
func (m *SearchFilesByNameRequest) String() string { return proto.CompactTextString(m) }
func (*SearchFilesByNameRequest) ProtoMessage()    {}
func (*SearchFilesByNameRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{68}
}

func (m *SearchFilesByNameRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchFilesByNameRequest.Unmarshal(m, b)
}
func (m *SearchFilesByNameRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchFilesByNameRequest.Marshal(b, m, deterministic)
}
func (m *SearchFilesByNameRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchFilesByNameRequest.Merge(m, src)
}
func (m *SearchFilesByNameRequest) XXX_Size() int {
	return xxx_messageInfo_SearchFilesByNameRequest.Size(m)
}
func (m *SearchFilesByNameRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchFilesByNameRequest.DiscardUnknown(m)
}

var xxx_messageInfo_SearchFilesByNameRequest proto.InternalMessageInfo

func (m *SearchFilesByNameRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *SearchFilesByNameRequest) GetQuery() string {
	if m != nil {
		return m.Query
	}
	return ""
}

func (m *SearchFilesByNameRequest) GetRef() []byte {
	if m != nil {
		return m.Ref
	}
	return nil
}

func (m *SearchFilesByNameRequest) GetFilter() string {
	if m != nil {
		return m.Filter
	}
	return ""
}

type SearchFilesByNameResponse struct {
	Files                [][]byte `protobuf:"bytes,1,rep,name=files,proto3" json:"files,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SearchFilesByNameResponse) Reset()         { *m = SearchFilesByNameResponse{} }
func (m *SearchFilesByNameResponse) String() string { return proto.CompactTextString(m) }
func (*SearchFilesByNameResponse) ProtoMessage()    {}
func (*SearchFilesByNameResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{69}
}

func (m *SearchFilesByNameResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchFilesByNameResponse.Unmarshal(m, b)
}
func (m *SearchFilesByNameResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchFilesByNameResponse.Marshal(b, m, deterministic)
}
func (m *SearchFilesByNameResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchFilesByNameResponse.Merge(m, src)
}
func (m *SearchFilesByNameResponse) XXX_Size() int {
	return xxx_messageInfo_SearchFilesByNameResponse.Size(m)
}
func (m *SearchFilesByNameResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchFilesByNameResponse.DiscardUnknown(m)
}

var xxx_messageInfo_SearchFilesByNameResponse proto.InternalMessageInfo

func (m *SearchFilesByNameResponse) GetFiles() [][]byte {
	if m != nil {
		return m.Files
	}
	return nil
}

type SearchFilesByContentRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Query                string      `protobuf:"bytes,2,opt,name=query,proto3" json:"query,omitempty"`
	Ref                  []byte      `protobuf:"bytes,3,opt,name=ref,proto3" json:"ref,omitempty"`
	ChunkedResponse      bool        `protobuf:"varint,4,opt,name=chunked_response,json=chunkedResponse,proto3" json:"chunked_response,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *SearchFilesByContentRequest) Reset()         { *m = SearchFilesByContentRequest{} }
func (m *SearchFilesByContentRequest) String() string { return proto.CompactTextString(m) }
func (*SearchFilesByContentRequest) ProtoMessage()    {}
func (*SearchFilesByContentRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{70}
}

func (m *SearchFilesByContentRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchFilesByContentRequest.Unmarshal(m, b)
}
func (m *SearchFilesByContentRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchFilesByContentRequest.Marshal(b, m, deterministic)
}
func (m *SearchFilesByContentRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchFilesByContentRequest.Merge(m, src)
}
func (m *SearchFilesByContentRequest) XXX_Size() int {
	return xxx_messageInfo_SearchFilesByContentRequest.Size(m)
}
func (m *SearchFilesByContentRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchFilesByContentRequest.DiscardUnknown(m)
}

var xxx_messageInfo_SearchFilesByContentRequest proto.InternalMessageInfo

func (m *SearchFilesByContentRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *SearchFilesByContentRequest) GetQuery() string {
	if m != nil {
		return m.Query
	}
	return ""
}

func (m *SearchFilesByContentRequest) GetRef() []byte {
	if m != nil {
		return m.Ref
	}
	return nil
}

func (m *SearchFilesByContentRequest) GetChunkedResponse() bool {
	if m != nil {
		return m.ChunkedResponse
	}
	return false
}

type SearchFilesByContentResponse struct {
	Matches              [][]byte `protobuf:"bytes,1,rep,name=matches,proto3" json:"matches,omitempty"`
	MatchData            []byte   `protobuf:"bytes,2,opt,name=match_data,json=matchData,proto3" json:"match_data,omitempty"`
	EndOfMatch           bool     `protobuf:"varint,3,opt,name=end_of_match,json=endOfMatch,proto3" json:"end_of_match,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SearchFilesByContentResponse) Reset()         { *m = SearchFilesByContentResponse{} }
func (m *SearchFilesByContentResponse) String() string { return proto.CompactTextString(m) }
func (*SearchFilesByContentResponse) ProtoMessage()    {}
func (*SearchFilesByContentResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{71}
}

func (m *SearchFilesByContentResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchFilesByContentResponse.Unmarshal(m, b)
}
func (m *SearchFilesByContentResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchFilesByContentResponse.Marshal(b, m, deterministic)
}
func (m *SearchFilesByContentResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchFilesByContentResponse.Merge(m, src)
}
func (m *SearchFilesByContentResponse) XXX_Size() int {
	return xxx_messageInfo_SearchFilesByContentResponse.Size(m)
}
func (m *SearchFilesByContentResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchFilesByContentResponse.DiscardUnknown(m)
}

var xxx_messageInfo_SearchFilesByContentResponse proto.InternalMessageInfo

func (m *SearchFilesByContentResponse) GetMatches() [][]byte {
	if m != nil {
		return m.Matches
	}
	return nil
}

func (m *SearchFilesByContentResponse) GetMatchData() []byte {
	if m != nil {
		return m.MatchData
	}
	return nil
}

func (m *SearchFilesByContentResponse) GetEndOfMatch() bool {
	if m != nil {
		return m.EndOfMatch
	}
	return false
}

// Remote represents a git remote repository.
type Remote struct {
	// url is the URL of the remote repository.
	Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
	// http_authorization_header is the HTTP header which should be added to
	// the request in order to authenticate against the repository.
	HttpAuthorizationHeader string `protobuf:"bytes,3,opt,name=http_authorization_header,json=httpAuthorizationHeader,proto3" json:"http_authorization_header,omitempty"`
	// mirror_refmaps contains the refspecs which shall be fetched. Some special
	// refspecs are accepted:
	//
	// - "all_refs" gets translated to "+refs/*:refs/*", which mirrors all
	//   references of the source repository.
	// - "heads" gets translated to "+refs/heads/*:refs/heads/*", which mirrors
	//   all branches of the source repository.
	// - "tags" gets translated to "+refs/tags/*:refs/tags/*", which mirrors all
	//   tags of the source repository.
	//
	// If no refspecs are given, this defaults to "all_refs".
	MirrorRefmaps        []string `protobuf:"bytes,4,rep,name=mirror_refmaps,json=mirrorRefmaps,proto3" json:"mirror_refmaps,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *Remote) Reset()         { *m = Remote{} }
func (m *Remote) String() string { return proto.CompactTextString(m) }
func (*Remote) ProtoMessage()    {}
func (*Remote) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{72}
}

func (m *Remote) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Remote.Unmarshal(m, b)
}
func (m *Remote) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Remote.Marshal(b, m, deterministic)
}
func (m *Remote) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Remote.Merge(m, src)
}
func (m *Remote) XXX_Size() int {
	return xxx_messageInfo_Remote.Size(m)
}
func (m *Remote) XXX_DiscardUnknown() {
	xxx_messageInfo_Remote.DiscardUnknown(m)
}

var xxx_messageInfo_Remote proto.InternalMessageInfo

func (m *Remote) GetUrl() string {
	if m != nil {
		return m.Url
	}
	return ""
}

func (m *Remote) GetHttpAuthorizationHeader() string {
	if m != nil {
		return m.HttpAuthorizationHeader
	}
	return ""
}

func (m *Remote) GetMirrorRefmaps() []string {
	if m != nil {
		return m.MirrorRefmaps
	}
	return nil
}

type GetObjectDirectorySizeRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *GetObjectDirectorySizeRequest) Reset()         { *m = GetObjectDirectorySizeRequest{} }
func (m *GetObjectDirectorySizeRequest) String() string { return proto.CompactTextString(m) }
func (*GetObjectDirectorySizeRequest) ProtoMessage()    {}
func (*GetObjectDirectorySizeRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{73}
}

func (m *GetObjectDirectorySizeRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetObjectDirectorySizeRequest.Unmarshal(m, b)
}
func (m *GetObjectDirectorySizeRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetObjectDirectorySizeRequest.Marshal(b, m, deterministic)
}
func (m *GetObjectDirectorySizeRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetObjectDirectorySizeRequest.Merge(m, src)
}
func (m *GetObjectDirectorySizeRequest) XXX_Size() int {
	return xxx_messageInfo_GetObjectDirectorySizeRequest.Size(m)
}
func (m *GetObjectDirectorySizeRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetObjectDirectorySizeRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetObjectDirectorySizeRequest proto.InternalMessageInfo

func (m *GetObjectDirectorySizeRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type GetObjectDirectorySizeResponse struct {
	// Object directory size in kilobytes
	Size                 int64    `protobuf:"varint,1,opt,name=size,proto3" json:"size,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetObjectDirectorySizeResponse) Reset()         { *m = GetObjectDirectorySizeResponse{} }
func (m *GetObjectDirectorySizeResponse) String() string { return proto.CompactTextString(m) }
func (*GetObjectDirectorySizeResponse) ProtoMessage()    {}
func (*GetObjectDirectorySizeResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{74}
}

func (m *GetObjectDirectorySizeResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetObjectDirectorySizeResponse.Unmarshal(m, b)
}
func (m *GetObjectDirectorySizeResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetObjectDirectorySizeResponse.Marshal(b, m, deterministic)
}
func (m *GetObjectDirectorySizeResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetObjectDirectorySizeResponse.Merge(m, src)
}
func (m *GetObjectDirectorySizeResponse) XXX_Size() int {
	return xxx_messageInfo_GetObjectDirectorySizeResponse.Size(m)
}
func (m *GetObjectDirectorySizeResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GetObjectDirectorySizeResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GetObjectDirectorySizeResponse proto.InternalMessageInfo

func (m *GetObjectDirectorySizeResponse) GetSize() int64 {
	if m != nil {
		return m.Size
	}
	return 0
}

type CloneFromPoolRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Pool                 *ObjectPool `protobuf:"bytes,2,opt,name=pool,proto3" json:"pool,omitempty"`
	Remote               *Remote     `protobuf:"bytes,3,opt,name=remote,proto3" json:"remote,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CloneFromPoolRequest) Reset()         { *m = CloneFromPoolRequest{} }
func (m *CloneFromPoolRequest) String() string { return proto.CompactTextString(m) }
func (*CloneFromPoolRequest) ProtoMessage()    {}
func (*CloneFromPoolRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{75}
}

func (m *CloneFromPoolRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CloneFromPoolRequest.Unmarshal(m, b)
}
func (m *CloneFromPoolRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CloneFromPoolRequest.Marshal(b, m, deterministic)
}
func (m *CloneFromPoolRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CloneFromPoolRequest.Merge(m, src)
}
func (m *CloneFromPoolRequest) XXX_Size() int {
	return xxx_messageInfo_CloneFromPoolRequest.Size(m)
}
func (m *CloneFromPoolRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CloneFromPoolRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CloneFromPoolRequest proto.InternalMessageInfo

func (m *CloneFromPoolRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *CloneFromPoolRequest) GetPool() *ObjectPool {
	if m != nil {
		return m.Pool
	}
	return nil
}

func (m *CloneFromPoolRequest) GetRemote() *Remote {
	if m != nil {
		return m.Remote
	}
	return nil
}

type CloneFromPoolResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CloneFromPoolResponse) Reset()         { *m = CloneFromPoolResponse{} }
func (m *CloneFromPoolResponse) String() string { return proto.CompactTextString(m) }
func (*CloneFromPoolResponse) ProtoMessage()    {}
func (*CloneFromPoolResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{76}
}

func (m *CloneFromPoolResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CloneFromPoolResponse.Unmarshal(m, b)
}
func (m *CloneFromPoolResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CloneFromPoolResponse.Marshal(b, m, deterministic)
}
func (m *CloneFromPoolResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CloneFromPoolResponse.Merge(m, src)
}
func (m *CloneFromPoolResponse) XXX_Size() int {
	return xxx_messageInfo_CloneFromPoolResponse.Size(m)
}
func (m *CloneFromPoolResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CloneFromPoolResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CloneFromPoolResponse proto.InternalMessageInfo

type CloneFromPoolInternalRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Pool                 *ObjectPool `protobuf:"bytes,2,opt,name=pool,proto3" json:"pool,omitempty"`
	SourceRepository     *Repository `protobuf:"bytes,3,opt,name=source_repository,json=sourceRepository,proto3" json:"source_repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CloneFromPoolInternalRequest) Reset()         { *m = CloneFromPoolInternalRequest{} }
func (m *CloneFromPoolInternalRequest) String() string { return proto.CompactTextString(m) }
func (*CloneFromPoolInternalRequest) ProtoMessage()    {}
func (*CloneFromPoolInternalRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{77}
}

func (m *CloneFromPoolInternalRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CloneFromPoolInternalRequest.Unmarshal(m, b)
}
func (m *CloneFromPoolInternalRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CloneFromPoolInternalRequest.Marshal(b, m, deterministic)
}
func (m *CloneFromPoolInternalRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CloneFromPoolInternalRequest.Merge(m, src)
}
func (m *CloneFromPoolInternalRequest) XXX_Size() int {
	return xxx_messageInfo_CloneFromPoolInternalRequest.Size(m)
}
func (m *CloneFromPoolInternalRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CloneFromPoolInternalRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CloneFromPoolInternalRequest proto.InternalMessageInfo

func (m *CloneFromPoolInternalRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *CloneFromPoolInternalRequest) GetPool() *ObjectPool {
	if m != nil {
		return m.Pool
	}
	return nil
}

func (m *CloneFromPoolInternalRequest) GetSourceRepository() *Repository {
	if m != nil {
		return m.SourceRepository
	}
	return nil
}

type CloneFromPoolInternalResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CloneFromPoolInternalResponse) Reset()         { *m = CloneFromPoolInternalResponse{} }
func (m *CloneFromPoolInternalResponse) String() string { return proto.CompactTextString(m) }
func (*CloneFromPoolInternalResponse) ProtoMessage()    {}
func (*CloneFromPoolInternalResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{78}
}

func (m *CloneFromPoolInternalResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CloneFromPoolInternalResponse.Unmarshal(m, b)
}
func (m *CloneFromPoolInternalResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CloneFromPoolInternalResponse.Marshal(b, m, deterministic)
}
func (m *CloneFromPoolInternalResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CloneFromPoolInternalResponse.Merge(m, src)
}
func (m *CloneFromPoolInternalResponse) XXX_Size() int {
	return xxx_messageInfo_CloneFromPoolInternalResponse.Size(m)
}
func (m *CloneFromPoolInternalResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_CloneFromPoolInternalResponse.DiscardUnknown(m)
}

var xxx_messageInfo_CloneFromPoolInternalResponse proto.InternalMessageInfo

type RemoveRepositoryRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *RemoveRepositoryRequest) Reset()         { *m = RemoveRepositoryRequest{} }
func (m *RemoveRepositoryRequest) String() string { return proto.CompactTextString(m) }
func (*RemoveRepositoryRequest) ProtoMessage()    {}
func (*RemoveRepositoryRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{79}
}

func (m *RemoveRepositoryRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RemoveRepositoryRequest.Unmarshal(m, b)
}
func (m *RemoveRepositoryRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RemoveRepositoryRequest.Marshal(b, m, deterministic)
}
func (m *RemoveRepositoryRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RemoveRepositoryRequest.Merge(m, src)
}
func (m *RemoveRepositoryRequest) XXX_Size() int {
	return xxx_messageInfo_RemoveRepositoryRequest.Size(m)
}
func (m *RemoveRepositoryRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_RemoveRepositoryRequest.DiscardUnknown(m)
}

var xxx_messageInfo_RemoveRepositoryRequest proto.InternalMessageInfo

func (m *RemoveRepositoryRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type RemoveRepositoryResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *RemoveRepositoryResponse) Reset()         { *m = RemoveRepositoryResponse{} }
func (m *RemoveRepositoryResponse) String() string { return proto.CompactTextString(m) }
func (*RemoveRepositoryResponse) ProtoMessage()    {}
func (*RemoveRepositoryResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{80}
}

func (m *RemoveRepositoryResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RemoveRepositoryResponse.Unmarshal(m, b)
}
func (m *RemoveRepositoryResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RemoveRepositoryResponse.Marshal(b, m, deterministic)
}
func (m *RemoveRepositoryResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RemoveRepositoryResponse.Merge(m, src)
}
func (m *RemoveRepositoryResponse) XXX_Size() int {
	return xxx_messageInfo_RemoveRepositoryResponse.Size(m)
}
func (m *RemoveRepositoryResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_RemoveRepositoryResponse.DiscardUnknown(m)
}

var xxx_messageInfo_RemoveRepositoryResponse proto.InternalMessageInfo

type RenameRepositoryRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	RelativePath         string      `protobuf:"bytes,2,opt,name=relative_path,json=relativePath,proto3" json:"relative_path,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *RenameRepositoryRequest) Reset()         { *m = RenameRepositoryRequest{} }
func (m *RenameRepositoryRequest) String() string { return proto.CompactTextString(m) }
func (*RenameRepositoryRequest) ProtoMessage()    {}
func (*RenameRepositoryRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{81}
}

func (m *RenameRepositoryRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RenameRepositoryRequest.Unmarshal(m, b)
}
func (m *RenameRepositoryRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RenameRepositoryRequest.Marshal(b, m, deterministic)
}
func (m *RenameRepositoryRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RenameRepositoryRequest.Merge(m, src)
}
func (m *RenameRepositoryRequest) XXX_Size() int {
	return xxx_messageInfo_RenameRepositoryRequest.Size(m)
}
func (m *RenameRepositoryRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_RenameRepositoryRequest.DiscardUnknown(m)
}

var xxx_messageInfo_RenameRepositoryRequest proto.InternalMessageInfo

func (m *RenameRepositoryRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *RenameRepositoryRequest) GetRelativePath() string {
	if m != nil {
		return m.RelativePath
	}
	return ""
}

type RenameRepositoryResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *RenameRepositoryResponse) Reset()         { *m = RenameRepositoryResponse{} }
func (m *RenameRepositoryResponse) String() string { return proto.CompactTextString(m) }
func (*RenameRepositoryResponse) ProtoMessage()    {}
func (*RenameRepositoryResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{82}
}

func (m *RenameRepositoryResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RenameRepositoryResponse.Unmarshal(m, b)
}
func (m *RenameRepositoryResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RenameRepositoryResponse.Marshal(b, m, deterministic)
}
func (m *RenameRepositoryResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RenameRepositoryResponse.Merge(m, src)
}
func (m *RenameRepositoryResponse) XXX_Size() int {
	return xxx_messageInfo_RenameRepositoryResponse.Size(m)
}
func (m *RenameRepositoryResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_RenameRepositoryResponse.DiscardUnknown(m)
}

var xxx_messageInfo_RenameRepositoryResponse proto.InternalMessageInfo

type ReplicateRepositoryRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	Source               *Repository `protobuf:"bytes,2,opt,name=source,proto3" json:"source,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *ReplicateRepositoryRequest) Reset()         { *m = ReplicateRepositoryRequest{} }
func (m *ReplicateRepositoryRequest) String() string { return proto.CompactTextString(m) }
func (*ReplicateRepositoryRequest) ProtoMessage()    {}
func (*ReplicateRepositoryRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{83}
}

func (m *ReplicateRepositoryRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ReplicateRepositoryRequest.Unmarshal(m, b)
}
func (m *ReplicateRepositoryRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ReplicateRepositoryRequest.Marshal(b, m, deterministic)
}
func (m *ReplicateRepositoryRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ReplicateRepositoryRequest.Merge(m, src)
}
func (m *ReplicateRepositoryRequest) XXX_Size() int {
	return xxx_messageInfo_ReplicateRepositoryRequest.Size(m)
}
func (m *ReplicateRepositoryRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ReplicateRepositoryRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ReplicateRepositoryRequest proto.InternalMessageInfo

func (m *ReplicateRepositoryRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

func (m *ReplicateRepositoryRequest) GetSource() *Repository {
	if m != nil {
		return m.Source
	}
	return nil
}

type ReplicateRepositoryResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ReplicateRepositoryResponse) Reset()         { *m = ReplicateRepositoryResponse{} }
func (m *ReplicateRepositoryResponse) String() string { return proto.CompactTextString(m) }
func (*ReplicateRepositoryResponse) ProtoMessage()    {}
func (*ReplicateRepositoryResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{84}
}

func (m *ReplicateRepositoryResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ReplicateRepositoryResponse.Unmarshal(m, b)
}
func (m *ReplicateRepositoryResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ReplicateRepositoryResponse.Marshal(b, m, deterministic)
}
func (m *ReplicateRepositoryResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ReplicateRepositoryResponse.Merge(m, src)
}
func (m *ReplicateRepositoryResponse) XXX_Size() int {
	return xxx_messageInfo_ReplicateRepositoryResponse.Size(m)
}
func (m *ReplicateRepositoryResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ReplicateRepositoryResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ReplicateRepositoryResponse proto.InternalMessageInfo

type OptimizeRepositoryRequest struct {
	Repository           *Repository `protobuf:"bytes,1,opt,name=repository,proto3" json:"repository,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *OptimizeRepositoryRequest) Reset()         { *m = OptimizeRepositoryRequest{} }
func (m *OptimizeRepositoryRequest) String() string { return proto.CompactTextString(m) }
func (*OptimizeRepositoryRequest) ProtoMessage()    {}
func (*OptimizeRepositoryRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{85}
}

func (m *OptimizeRepositoryRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_OptimizeRepositoryRequest.Unmarshal(m, b)
}
func (m *OptimizeRepositoryRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_OptimizeRepositoryRequest.Marshal(b, m, deterministic)
}
func (m *OptimizeRepositoryRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_OptimizeRepositoryRequest.Merge(m, src)
}
func (m *OptimizeRepositoryRequest) XXX_Size() int {
	return xxx_messageInfo_OptimizeRepositoryRequest.Size(m)
}
func (m *OptimizeRepositoryRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_OptimizeRepositoryRequest.DiscardUnknown(m)
}

var xxx_messageInfo_OptimizeRepositoryRequest proto.InternalMessageInfo

func (m *OptimizeRepositoryRequest) GetRepository() *Repository {
	if m != nil {
		return m.Repository
	}
	return nil
}

type OptimizeRepositoryResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *OptimizeRepositoryResponse) Reset()         { *m = OptimizeRepositoryResponse{} }
func (m *OptimizeRepositoryResponse) String() string { return proto.CompactTextString(m) }
func (*OptimizeRepositoryResponse) ProtoMessage()    {}
func (*OptimizeRepositoryResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9b1768cf174c79b, []int{86}
}

func (m *OptimizeRepositoryResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_OptimizeRepositoryResponse.Unmarshal(m, b)
}
func (m *OptimizeRepositoryResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_OptimizeRepositoryResponse.Marshal(b, m, deterministic)
}
func (m *OptimizeRepositoryResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_OptimizeRepositoryResponse.Merge(m, src)
}
func (m *OptimizeRepositoryResponse) XXX_Size() int {
	return xxx_messageInfo_OptimizeRepositoryResponse.Size(m)
}
func (m *OptimizeRepositoryResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_OptimizeRepositoryResponse.DiscardUnknown(m)
}

var xxx_messageInfo_OptimizeRepositoryResponse proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("gitaly.WriteCommitGraphRequest_SplitStrategy", WriteCommitGraphRequest_SplitStrategy_name, WriteCommitGraphRequest_SplitStrategy_value)
	proto.RegisterEnum("gitaly.GetArchiveRequest_Format", GetArchiveRequest_Format_name, GetArchiveRequest_Format_value)
	proto.RegisterEnum("gitaly.GetRawChangesResponse_RawChange_Operation", GetRawChangesResponse_RawChange_Operation_name, GetRawChangesResponse_RawChange_Operation_value)
	proto.RegisterType((*RepositoryExistsRequest)(nil), "gitaly.RepositoryExistsRequest")
	proto.RegisterType((*RepositoryExistsResponse)(nil), "gitaly.RepositoryExistsResponse")
	proto.RegisterType((*RepackIncrementalRequest)(nil), "gitaly.RepackIncrementalRequest")
	proto.RegisterType((*RepackIncrementalResponse)(nil), "gitaly.RepackIncrementalResponse")
	proto.RegisterType((*RepackFullRequest)(nil), "gitaly.RepackFullRequest")
	proto.RegisterType((*RepackFullResponse)(nil), "gitaly.RepackFullResponse")
	proto.RegisterType((*MidxRepackRequest)(nil), "gitaly.MidxRepackRequest")
	proto.RegisterType((*MidxRepackResponse)(nil), "gitaly.MidxRepackResponse")
	proto.RegisterType((*GarbageCollectRequest)(nil), "gitaly.GarbageCollectRequest")
	proto.RegisterType((*GarbageCollectResponse)(nil), "gitaly.GarbageCollectResponse")
	proto.RegisterType((*WriteCommitGraphRequest)(nil), "gitaly.WriteCommitGraphRequest")
	proto.RegisterType((*WriteCommitGraphResponse)(nil), "gitaly.WriteCommitGraphResponse")
	proto.RegisterType((*CleanupRequest)(nil), "gitaly.CleanupRequest")
	proto.RegisterType((*CleanupResponse)(nil), "gitaly.CleanupResponse")
	proto.RegisterType((*RepositorySizeRequest)(nil), "gitaly.RepositorySizeRequest")
	proto.RegisterType((*RepositorySizeResponse)(nil), "gitaly.RepositorySizeResponse")
	proto.RegisterType((*ApplyGitattributesRequest)(nil), "gitaly.ApplyGitattributesRequest")
	proto.RegisterType((*ApplyGitattributesResponse)(nil), "gitaly.ApplyGitattributesResponse")
	proto.RegisterType((*FetchRemoteRequest)(nil), "gitaly.FetchRemoteRequest")
	proto.RegisterType((*FetchRemoteResponse)(nil), "gitaly.FetchRemoteResponse")
	proto.RegisterType((*CreateRepositoryRequest)(nil), "gitaly.CreateRepositoryRequest")
	proto.RegisterType((*CreateRepositoryResponse)(nil), "gitaly.CreateRepositoryResponse")
	proto.RegisterType((*GetArchiveRequest)(nil), "gitaly.GetArchiveRequest")
	proto.RegisterType((*GetArchiveResponse)(nil), "gitaly.GetArchiveResponse")
	proto.RegisterType((*HasLocalBranchesRequest)(nil), "gitaly.HasLocalBranchesRequest")
	proto.RegisterType((*HasLocalBranchesResponse)(nil), "gitaly.HasLocalBranchesResponse")
	proto.RegisterType((*FetchSourceBranchRequest)(nil), "gitaly.FetchSourceBranchRequest")
	proto.RegisterType((*FetchSourceBranchResponse)(nil), "gitaly.FetchSourceBranchResponse")
	proto.RegisterType((*FsckRequest)(nil), "gitaly.FsckRequest")
	proto.RegisterType((*FsckResponse)(nil), "gitaly.FsckResponse")
	proto.RegisterType((*WriteRefRequest)(nil), "gitaly.WriteRefRequest")
	proto.RegisterType((*WriteRefResponse)(nil), "gitaly.WriteRefResponse")
	proto.RegisterType((*FindMergeBaseRequest)(nil), "gitaly.FindMergeBaseRequest")
	proto.RegisterType((*FindMergeBaseResponse)(nil), "gitaly.FindMergeBaseResponse")
	proto.RegisterType((*CreateForkRequest)(nil), "gitaly.CreateForkRequest")
	proto.RegisterType((*CreateForkResponse)(nil), "gitaly.CreateForkResponse")
	proto.RegisterType((*IsRebaseInProgressRequest)(nil), "gitaly.IsRebaseInProgressRequest")
	proto.RegisterType((*IsRebaseInProgressResponse)(nil), "gitaly.IsRebaseInProgressResponse")
	proto.RegisterType((*IsSquashInProgressRequest)(nil), "gitaly.IsSquashInProgressRequest")
	proto.RegisterType((*IsSquashInProgressResponse)(nil), "gitaly.IsSquashInProgressResponse")
	proto.RegisterType((*CreateRepositoryFromURLRequest)(nil), "gitaly.CreateRepositoryFromURLRequest")
	proto.RegisterType((*CreateRepositoryFromURLResponse)(nil), "gitaly.CreateRepositoryFromURLResponse")
	proto.RegisterType((*CreateBundleRequest)(nil), "gitaly.CreateBundleRequest")
	proto.RegisterType((*CreateBundleResponse)(nil), "gitaly.CreateBundleResponse")
	proto.RegisterType((*GetConfigRequest)(nil), "gitaly.GetConfigRequest")
	proto.RegisterType((*GetConfigResponse)(nil), "gitaly.GetConfigResponse")
	proto.RegisterType((*SetConfigRequest)(nil), "gitaly.SetConfigRequest")
	proto.RegisterType((*SetConfigRequest_Entry)(nil), "gitaly.SetConfigRequest.Entry")
	proto.RegisterType((*SetConfigResponse)(nil), "gitaly.SetConfigResponse")
	proto.RegisterType((*DeleteConfigRequest)(nil), "gitaly.DeleteConfigRequest")
	proto.RegisterType((*DeleteConfigResponse)(nil), "gitaly.DeleteConfigResponse")
	proto.RegisterType((*RestoreCustomHooksRequest)(nil), "gitaly.RestoreCustomHooksRequest")
	proto.RegisterType((*RestoreCustomHooksResponse)(nil), "gitaly.RestoreCustomHooksResponse")
	proto.RegisterType((*BackupCustomHooksRequest)(nil), "gitaly.BackupCustomHooksRequest")
	proto.RegisterType((*BackupCustomHooksResponse)(nil), "gitaly.BackupCustomHooksResponse")
	proto.RegisterType((*CreateRepositoryFromBundleRequest)(nil), "gitaly.CreateRepositoryFromBundleRequest")
	proto.RegisterType((*CreateRepositoryFromBundleResponse)(nil), "gitaly.CreateRepositoryFromBundleResponse")
	proto.RegisterType((*FindLicenseRequest)(nil), "gitaly.FindLicenseRequest")
	proto.RegisterType((*FindLicenseResponse)(nil), "gitaly.FindLicenseResponse")
	proto.RegisterType((*GetInfoAttributesRequest)(nil), "gitaly.GetInfoAttributesRequest")
	proto.RegisterType((*GetInfoAttributesResponse)(nil), "gitaly.GetInfoAttributesResponse")
	proto.RegisterType((*CalculateChecksumRequest)(nil), "gitaly.CalculateChecksumRequest")
	proto.RegisterType((*CalculateChecksumResponse)(nil), "gitaly.CalculateChecksumResponse")
	proto.RegisterType((*GetSnapshotRequest)(nil), "gitaly.GetSnapshotRequest")
	proto.RegisterType((*GetSnapshotResponse)(nil), "gitaly.GetSnapshotResponse")
	proto.RegisterType((*CreateRepositoryFromSnapshotRequest)(nil), "gitaly.CreateRepositoryFromSnapshotRequest")
	proto.RegisterType((*CreateRepositoryFromSnapshotResponse)(nil), "gitaly.CreateRepositoryFromSnapshotResponse")
	proto.RegisterType((*GetRawChangesRequest)(nil), "gitaly.GetRawChangesRequest")
	proto.RegisterType((*GetRawChangesResponse)(nil), "gitaly.GetRawChangesResponse")
	proto.RegisterType((*GetRawChangesResponse_RawChange)(nil), "gitaly.GetRawChangesResponse.RawChange")
	proto.RegisterType((*SearchFilesByNameRequest)(nil), "gitaly.SearchFilesByNameRequest")
	proto.RegisterType((*SearchFilesByNameResponse)(nil), "gitaly.SearchFilesByNameResponse")
	proto.RegisterType((*SearchFilesByContentRequest)(nil), "gitaly.SearchFilesByContentRequest")
	proto.RegisterType((*SearchFilesByContentResponse)(nil), "gitaly.SearchFilesByContentResponse")
	proto.RegisterType((*Remote)(nil), "gitaly.Remote")
	proto.RegisterType((*GetObjectDirectorySizeRequest)(nil), "gitaly.GetObjectDirectorySizeRequest")
	proto.RegisterType((*GetObjectDirectorySizeResponse)(nil), "gitaly.GetObjectDirectorySizeResponse")
	proto.RegisterType((*CloneFromPoolRequest)(nil), "gitaly.CloneFromPoolRequest")
	proto.RegisterType((*CloneFromPoolResponse)(nil), "gitaly.CloneFromPoolResponse")
	proto.RegisterType((*CloneFromPoolInternalRequest)(nil), "gitaly.CloneFromPoolInternalRequest")
	proto.RegisterType((*CloneFromPoolInternalResponse)(nil), "gitaly.CloneFromPoolInternalResponse")
	proto.RegisterType((*RemoveRepositoryRequest)(nil), "gitaly.RemoveRepositoryRequest")
	proto.RegisterType((*RemoveRepositoryResponse)(nil), "gitaly.RemoveRepositoryResponse")
	proto.RegisterType((*RenameRepositoryRequest)(nil), "gitaly.RenameRepositoryRequest")
	proto.RegisterType((*RenameRepositoryResponse)(nil), "gitaly.RenameRepositoryResponse")
	proto.RegisterType((*ReplicateRepositoryRequest)(nil), "gitaly.ReplicateRepositoryRequest")
	proto.RegisterType((*ReplicateRepositoryResponse)(nil), "gitaly.ReplicateRepositoryResponse")
	proto.RegisterType((*OptimizeRepositoryRequest)(nil), "gitaly.OptimizeRepositoryRequest")
	proto.RegisterType((*OptimizeRepositoryResponse)(nil), "gitaly.OptimizeRepositoryResponse")
}

func init() { proto.RegisterFile("repository-service.proto", fileDescriptor_e9b1768cf174c79b) }

var fileDescriptor_e9b1768cf174c79b = []byte{
	// 3185 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xc4, 0x5a, 0x4b, 0x6f, 0x1b, 0xc9,
	0xf1, 0x37, 0xf5, 0xe0, 0xa3, 0x48, 0xd9, 0x54, 0x4b, 0xb6, 0xa8, 0xb1, 0x64, 0xd9, 0x63, 0xaf,
	0xd7, 0xeb, 0xf5, 0xca, 0xbb, 0xf2, 0x02, 0x7f, 0xff, 0x13, 0x04, 0x81, 0xa8, 0xb7, 0x6d, 0x3d,
	0x76, 0x28, 0x67, 0xb1, 0x06, 0x16, 0xdc, 0xe1, 0xb0, 0x29, 0x4e, 0x34, 0x9c, 0xa1, 0x7b, 0x9a,
	0x96, 0xb5, 0x40, 0x0e, 0x09, 0x90, 0x43, 0x80, 0x60, 0x4f, 0x41, 0x36, 0xc7, 0xdc, 0x02, 0xe4,
	0x13, 0xe4, 0x92, 0x43, 0x2e, 0xb9, 0xe4, 0x13, 0xec, 0x57, 0x08, 0x90, 0x2f, 0x90, 0x53, 0xd0,
	0x8f, 0x99, 0x9e, 0xe1, 0xcc, 0x70, 0x1d, 0x90, 0xd8, 0xdc, 0xa6, 0xab, 0xba, 0xab, 0xaa, 0xbb,
	0xab, 0xab, 0xbb, 0x7e, 0x35, 0x50, 0x23, 0xb8, 0xef, 0xf9, 0x36, 0xf5, 0xc8, 0xe5, 0x47, 0x3e,
	0x26, 0x6f, 0x6c, 0x0b, 0xaf, 0xf7, 0x89, 0x47, 0x3d, 0x94, 0x3f, 0xb3, 0xa9, 0xe9, 0x5c, 0x6a,
	0xe0, 0xd8, 0x2e, 0x15, 0x34, 0xad, 0xe2, 0x77, 0x4d, 0x82, 0xdb, 0xa2, 0xa5, 0x37, 0x60, 0xc9,
	0x08, 0x47, 0xef, 0xbc, 0xb5, 0x7d, 0xea, 0x1b, 0xf8, 0xf5, 0x00, 0xfb, 0x14, 0x3d, 0x05, 0x50,
	0x82, 0x6b, 0xb9, 0xdb, 0xb9, 0x07, 0xe5, 0x0d, 0xb4, 0x2e, 0x24, 0xae, 0xab, 0x41, 0xf5, 0x99,
	0x3f, 0xfc, 0xfd, 0x51, 0xce, 0x88, 0xf4, 0xd5, 0x37, 0xa0, 0x96, 0x14, 0xea, 0xf7, 0x3d, 0xd7,
	0xc7, 0xe8, 0x06, 0xe4, 0x31, 0xa7, 0x70, 0x89, 0x45, 0x43, 0xb6, 0xf4, 0x53, 0x3e, 0xc6, 0xb4,
	0xce, 0x0f, 0x5c, 0x8b, 0xe0, 0x1e, 0x76, 0xa9, 0xe9, 0x8c, 0x6f, 0xc9, 0x4d, 0x58, 0x4e, 0x91,
	0x2a, 0x4c, 0xd1, 0x09, 0xcc, 0x0b, 0xe6, 0xee, 0xc0, 0x19, 0x5f, 0x17, 0xba, 0x0b, 0x73, 0x16,
	0xc1, 0x26, 0xc5, 0xcd, 0x96, 0x4d, 0x7b, 0x66, 0xbf, 0x36, 0xc5, 0x27, 0x58, 0x11, 0xc4, 0x3a,
	0xa7, 0xe9, 0x8b, 0x80, 0xa2, 0x3a, 0xa5, 0x25, 0x87, 0x30, 0x7f, 0x68, 0xb7, 0xdf, 0x0a, 0xce,
	0xf8, 0xb3, 0x5e, 0x04, 0x14, 0x15, 0x27, 0x95, 0xfc, 0x36, 0x07, 0xd7, 0xf7, 0x4c, 0xd2, 0x32,
	0xcf, 0xf0, 0x96, 0xe7, 0x38, 0xd8, 0xa2, 0x3f, 0xcc, 0x9c, 0xd1, 0x22, 0xcc, 0xf6, 0xc9, 0xc0,
	0xc5, 0xb5, 0x69, 0xce, 0x14, 0x0d, 0xbd, 0x06, 0x37, 0x86, 0xad, 0x91, 0x86, 0xfe, 0x23, 0x07,
	0x4b, 0x9f, 0x13, 0x9b, 0xe2, 0x2d, 0xaf, 0xd7, 0xb3, 0xe9, 0x1e, 0x31, 0xfb, 0xdd, 0xf1, 0x4d,
	0x6d, 0xc0, 0x9c, 0xdf, 0x77, 0x6c, 0xda, 0xa0, 0xc4, 0xa4, 0xf8, 0xec, 0x92, 0x9b, 0x7a, 0x75,
	0xe3, 0xa3, 0x60, 0x70, 0x86, 0xc6, 0xf5, 0x46, 0x74, 0x90, 0x11, 0x97, 0xa1, 0xdf, 0x81, 0xb9,
	0x18, 0x1f, 0x55, 0xa1, 0xd2, 0xb0, 0xbf, 0xc6, 0x87, 0x03, 0x87, 0xda, 0x7d, 0x07, 0x57, 0xaf,
	0xe8, 0x1a, 0xd4, 0x92, 0xa2, 0xe5, 0x4c, 0x9f, 0xc1, 0xd5, 0x2d, 0x07, 0x9b, 0xee, 0xa0, 0x3f,
	0xfe, 0xa6, 0xcf, 0xc3, 0xb5, 0x50, 0x96, 0x14, 0xff, 0x19, 0x5c, 0x57, 0x43, 0x98, 0x59, 0xe3,
	0x6b, 0x79, 0x04, 0x37, 0x86, 0x45, 0xca, 0x83, 0x8d, 0x60, 0xc6, 0xb7, 0xbf, 0xc6, 0x5c, 0xda,
	0xb4, 0xc1, 0xbf, 0xf5, 0xd7, 0xb0, 0xbc, 0xd9, 0xef, 0x3b, 0x97, 0x7b, 0x36, 0x35, 0x29, 0x25,
	0x76, 0x6b, 0x40, 0xf1, 0xf8, 0xf1, 0x05, 0x69, 0x50, 0x24, 0xf8, 0x8d, 0xed, 0xdb, 0x9e, 0xcb,
	0x77, 0xb1, 0x62, 0x84, 0x6d, 0x7d, 0x05, 0xb4, 0x34, 0x95, 0x72, 0x45, 0xfe, 0x35, 0x05, 0x68,
	0x17, 0x53, 0xab, 0x6b, 0xe0, 0x9e, 0x47, 0xc7, 0x5f, 0x0f, 0x16, 0xce, 0x08, 0x17, 0xc5, 0x0d,
	0x29, 0x19, 0xb2, 0xc5, 0x7c, 0xbe, 0xe3, 0x11, 0x2b, 0xf4, 0x79, 0xde, 0x40, 0x4b, 0x50, 0x70,
	0xbd, 0x26, 0x35, 0xcf, 0xfc, 0xda, 0x8c, 0x88, 0x7e, 0xae, 0x77, 0x6a, 0x9e, 0xf9, 0xa8, 0x06,
	0x05, 0x6a, 0xf7, 0xb0, 0x37, 0xa0, 0xb5, 0xd9, 0xdb, 0xb9, 0x07, 0xb3, 0x46, 0xd0, 0x64, 0x43,
	0x7c, 0xbf, 0xdb, 0x3c, 0xc7, 0x97, 0xb5, 0xbc, 0xd0, 0xe0, 0xfb, 0xdd, 0xe7, 0xf8, 0x12, 0xad,
	0x41, 0xf9, 0xdc, 0xf5, 0x2e, 0xdc, 0x66, 0xd7, 0x63, 0xd1, 0xb4, 0xc0, 0x99, 0xc0, 0x49, 0xfb,
	0x8c, 0x82, 0x96, 0xa1, 0xe8, 0x7a, 0x4d, 0x71, 0xf2, 0x4a, 0x5c, 0x5b, 0xc1, 0xf5, 0x4e, 0x58,
	0x13, 0x3d, 0x81, 0x39, 0x61, 0x67, 0xb3, 0x6f, 0x12, 0xb3, 0xe7, 0xd7, 0x80, 0x4f, 0xf9, 0xaa,
	0x9a, 0x32, 0x5f, 0x9d, 0x8a, 0xe8, 0x74, 0xc2, 0xfb, 0xa0, 0x47, 0x80, 0xac, 0x2e, 0xb6, 0xce,
	0xb9, 0xfd, 0x4d, 0xab, 0x6b, 0xba, 0x67, 0xb8, 0x5d, 0x2b, 0x73, 0xc9, 0x55, 0xce, 0x61, 0x53,
	0xd9, 0x12, 0xf4, 0x67, 0x33, 0xc5, 0x62, 0xb5, 0xa4, 0x3f, 0x85, 0x85, 0xd8, 0x72, 0x4b, 0x5f,
	0xb9, 0x03, 0x95, 0x98, 0x10, 0x71, 0x15, 0x94, 0xa9, 0x1a, 0xcf, 0x2e, 0xa6, 0x2d, 0x1e, 0x44,
	0xd4, 0xf2, 0x8f, 0xef, 0xbd, 0x1a, 0xd4, 0x92, 0x42, 0xa5, 0x6b, 0xfc, 0x73, 0x0a, 0xe6, 0xf7,
	0x30, 0xdd, 0x24, 0x56, 0xd7, 0x7e, 0x33, 0x01, 0xcf, 0xb8, 0x09, 0x25, 0x8b, 0x1f, 0xf9, 0xa6,
	0xdd, 0x96, 0xce, 0x51, 0x14, 0x84, 0x83, 0x36, 0x73, 0x9b, 0x3e, 0xc1, 0x1d, 0xfb, 0x2d, 0xf7,
	0x8f, 0x92, 0x21, 0x5b, 0xe8, 0x29, 0xe4, 0x3b, 0x1e, 0xe9, 0x99, 0x94, 0xfb, 0xc7, 0xd5, 0x8d,
	0xdb, 0x81, 0xaa, 0x84, 0x65, 0xeb, 0xbb, 0xbc, 0x9f, 0x21, 0xfb, 0xb3, 0xe3, 0xd7, 0x37, 0x69,
	0x97, 0xbb, 0x4f, 0xc5, 0xe0, 0xdf, 0xcc, 0xab, 0xf0, 0x5b, 0xcb, 0x19, 0xb4, 0x71, 0x2d, 0x7f,
	0x7b, 0xfa, 0x41, 0xc5, 0x08, 0x9a, 0x68, 0x15, 0x00, 0x3b, 0x76, 0x9b, 0xed, 0x3f, 0xed, 0x72,
	0xdf, 0x29, 0x1a, 0x25, 0x4e, 0x39, 0x61, 0x03, 0x1f, 0xc2, 0xbc, 0xed, 0xf2, 0x9e, 0x4d, 0xa7,
	0xe3, 0x37, 0x5b, 0x8e, 0xd7, 0xf2, 0x6b, 0x45, 0xde, 0xeb, 0x9a, 0x64, 0xbc, 0xe8, 0xf8, 0x75,
	0x46, 0xd6, 0x9f, 0x40, 0x5e, 0x98, 0x82, 0x0a, 0x30, 0xfd, 0xea, 0xe0, 0xa4, 0x7a, 0x85, 0x7d,
	0x9c, 0x6e, 0x1a, 0xd5, 0x1c, 0x02, 0xc8, 0x9f, 0x6e, 0x1a, 0xcd, 0xbd, 0x57, 0xd5, 0x29, 0x54,
	0x86, 0x02, 0xfb, 0xae, 0xbf, 0xda, 0xa8, 0x4e, 0xeb, 0x0f, 0x00, 0x45, 0x67, 0xa4, 0x42, 0x48,
	0xdb, 0xa4, 0x26, 0x5f, 0xe6, 0x8a, 0xc1, 0xbf, 0x99, 0x1f, 0xec, 0x9b, 0xfe, 0x0b, 0xcf, 0x32,
	0x9d, 0x3a, 0x31, 0x5d, 0xab, 0x3b, 0x81, 0x00, 0xa2, 0x7f, 0x0c, 0xb5, 0xa4, 0x50, 0x69, 0xc4,
	0x22, 0xcc, 0xbe, 0x31, 0x9d, 0x01, 0x96, 0x4e, 0x29, 0x1a, 0xfa, 0x77, 0x39, 0xa8, 0x71, 0x4f,
	0x6e, 0x78, 0x03, 0x62, 0x61, 0x31, 0x6a, 0x7c, 0x27, 0xf9, 0x29, 0xcc, 0xfb, 0x5c, 0x60, 0x33,
	0x22, 0x60, 0x2a, 0x4b, 0x80, 0x51, 0x15, 0x9d, 0x8d, 0xd8, 0x05, 0x2c, 0x05, 0xb4, 0xb8, 0x49,
	0xdc, 0x9f, 0x2a, 0x46, 0xc5, 0x8f, 0x98, 0xc9, 0x76, 0x9b, 0x9a, 0xe4, 0x0c, 0xd3, 0x26, 0xc1,
	0x1d, 0xee, 0x59, 0x15, 0xa3, 0x24, 0x28, 0x06, 0xee, 0xe8, 0x4f, 0x60, 0x39, 0x65, 0x6a, 0xea,
	0xbd, 0x46, 0xb0, 0x3f, 0x70, 0x68, 0xf0, 0x5e, 0x13, 0x2d, 0x7d, 0x0f, 0xca, 0xbb, 0xfe, 0x24,
	0x1e, 0x2b, 0xf7, 0xa0, 0x22, 0x04, 0xa9, 0xf5, 0xc7, 0x84, 0x78, 0x44, 0x7a, 0x81, 0x68, 0xe8,
	0x7f, 0xc9, 0xc1, 0x35, 0x7e, 0x8d, 0x1a, 0xb8, 0x33, 0xfe, 0xb2, 0x57, 0x61, 0x9a, 0xad, 0x84,
	0xb8, 0x3b, 0xd8, 0x67, 0xec, 0x4a, 0x99, 0x8e, 0x5f, 0x29, 0x2c, 0x5a, 0x79, 0x4e, 0xbb, 0x19,
	0xf2, 0xc5, 0x02, 0x96, 0x3d, 0xa7, 0x6d, 0x04, 0x5d, 0xc2, 0x70, 0x3f, 0x1b, 0x09, 0xf7, 0xcf,
	0x66, 0x8a, 0xf9, 0x6a, 0x41, 0xaf, 0x41, 0x55, 0x59, 0x2e, 0x26, 0xf9, 0x6c, 0xa6, 0x98, 0xab,
	0x4e, 0xe9, 0x2e, 0x2c, 0xee, 0xda, 0x6e, 0xfb, 0x10, 0x93, 0x33, 0x5c, 0x37, 0xfd, 0x09, 0x04,
	0x9d, 0x15, 0x28, 0x05, 0x66, 0xfa, 0xb5, 0x29, 0x7e, 0xe6, 0x15, 0x41, 0xff, 0x10, 0xae, 0x0f,
	0xe9, 0x53, 0x07, 0xaf, 0x65, 0xfa, 0xc2, 0xe5, 0x4b, 0x06, 0xff, 0xd6, 0xbf, 0xc9, 0xc1, 0xbc,
	0x08, 0x96, 0xbb, 0x1e, 0x39, 0xff, 0xdf, 0xbb, 0x3a, 0x7b, 0xd5, 0x46, 0xed, 0x09, 0x1f, 0xf1,
	0xcb, 0x07, 0xbe, 0x81, 0x99, 0xc9, 0x07, 0xee, 0x09, 0xf1, 0xce, 0x08, 0xf6, 0xfd, 0x89, 0x44,
	0x6f, 0xc2, 0x85, 0x46, 0xa2, 0xb7, 0x20, 0x1c, 0xb4, 0xf5, 0x9f, 0x80, 0x96, 0xa6, 0x53, 0x2e,
	0xe6, 0x1a, 0x94, 0x6d, 0xb7, 0xd9, 0x97, 0x64, 0x79, 0x6c, 0xc0, 0x0e, 0x3b, 0x0a, 0x93, 0x1b,
	0xaf, 0x07, 0xa6, 0xdf, 0x9d, 0xb0, 0xc9, 0x3e, 0x17, 0x1a, 0x31, 0x59, 0x10, 0x02, 0x93, 0x93,
	0x3a, 0xdf, 0xd5, 0x64, 0x07, 0x6e, 0x0d, 0x5f, 0x9c, 0xbb, 0xc4, 0xeb, 0xbd, 0x34, 0x5e, 0x4c,
	0xe4, 0x30, 0x0e, 0x88, 0x23, 0x2d, 0x66, 0x9f, 0xfa, 0x1d, 0x58, 0xcb, 0xd4, 0x26, 0xb7, 0xfd,
	0x18, 0x16, 0x44, 0x97, 0xfa, 0xc0, 0x6d, 0x3b, 0x13, 0x78, 0xd8, 0x3e, 0x84, 0xc5, 0xb8, 0xc0,
	0x11, 0x77, 0xd2, 0x0b, 0xa8, 0xee, 0x61, 0xba, 0xe5, 0xb9, 0x1d, 0xfb, 0x6c, 0x7c, 0xcd, 0xef,
	0xf3, 0x77, 0x47, 0x20, 0x6d, 0x84, 0xda, 0x6f, 0xa6, 0xa0, 0xda, 0x98, 0x98, 0x5e, 0xf4, 0x14,
	0x0a, 0xd8, 0xa5, 0xc4, 0xc6, 0x22, 0x52, 0x94, 0x37, 0x6e, 0x05, 0xc3, 0x86, 0x95, 0xac, 0xef,
	0xb8, 0x94, 0x5c, 0x1a, 0x41, 0x77, 0xed, 0xd7, 0x39, 0x98, 0xe5, 0x24, 0xb6, 0x77, 0xec, 0x65,
	0x2a, 0xe2, 0x06, 0xfb, 0x44, 0xab, 0x50, 0xe2, 0x37, 0x66, 0xd3, 0xa7, 0x44, 0xec, 0xe9, 0xfe,
	0x15, 0xa3, 0xc8, 0x49, 0x0d, 0x4a, 0xd0, 0x1d, 0x28, 0x0b, 0xb6, 0xed, 0xd2, 0x27, 0x1b, 0x3c,
	0xd4, 0xce, 0xee, 0x5f, 0x31, 0x80, 0x13, 0x0f, 0x18, 0x0d, 0xad, 0x81, 0x68, 0x35, 0x5b, 0x9e,
	0xe7, 0x88, 0x77, 0xf2, 0xfe, 0x15, 0x43, 0x48, 0xad, 0x7b, 0x9e, 0x53, 0x2f, 0xc8, 0x1b, 0x5a,
	0x5f, 0x80, 0xf9, 0xc6, 0xf0, 0xca, 0xe9, 0x16, 0x2c, 0x6c, 0x63, 0x07, 0xb3, 0x84, 0x6b, 0x32,
	0xeb, 0x84, 0x60, 0xe6, 0x1c, 0x5f, 0x8a, 0x45, 0x2a, 0x19, 0xfc, 0x5b, 0xbf, 0x01, 0x8b, 0x71,
	0x25, 0x52, 0xb9, 0x0d, 0xcb, 0x06, 0xf6, 0xa9, 0x47, 0xf0, 0xd6, 0xc0, 0xa7, 0x5e, 0x6f, 0xdf,
	0xf3, 0xce, 0xfd, 0x89, 0x98, 0xc0, 0xbd, 0x61, 0x2a, 0xe2, 0x0d, 0x2b, 0xa0, 0xa5, 0xa9, 0x92,
	0x86, 0x9c, 0x42, 0xad, 0x6e, 0x5a, 0xe7, 0x83, 0xfe, 0x24, 0xed, 0xd0, 0x1f, 0xc3, 0x72, 0x8a,
	0xd4, 0x11, 0x2e, 0xfb, 0x1a, 0xee, 0xa4, 0x9d, 0xe4, 0x09, 0x1d, 0xda, 0xd4, 0x75, 0xb9, 0x07,
	0xfa, 0x28, 0x95, 0x72, 0x7d, 0x8e, 0x00, 0xb1, 0xab, 0xf0, 0x85, 0x6d, 0x61, 0x77, 0x02, 0x17,
	0xaf, 0xbe, 0x05, 0x0b, 0x31, 0x79, 0x72, 0x4d, 0x1e, 0x01, 0x72, 0x04, 0xa9, 0xe9, 0x77, 0x3d,
	0x42, 0x9b, 0xae, 0xd9, 0x0b, 0xae, 0xd9, 0xaa, 0xe4, 0x34, 0x18, 0xe3, 0xc8, 0xec, 0xf1, 0x4d,
	0xdb, 0xc3, 0xf4, 0xc0, 0xed, 0x78, 0x9b, 0x93, 0xcb, 0x96, 0xf5, 0x1f, 0xc3, 0x72, 0x8a, 0x54,
	0x69, 0xe0, 0x2d, 0x00, 0x95, 0x26, 0xcb, 0xad, 0x8b, 0x50, 0x98, 0x49, 0x5b, 0xa6, 0x63, 0x0d,
	0x1c, 0x93, 0xe2, 0x2d, 0x96, 0xe3, 0xf9, 0x83, 0xde, 0xf8, 0x26, 0xfd, 0x1f, 0x2c, 0xa7, 0x48,
	0x95, 0x26, 0x69, 0x50, 0xb4, 0x24, 0x4d, 0xae, 0x54, 0xd8, 0x66, 0xdb, 0xb6, 0x87, 0x69, 0xc3,
	0x35, 0xfb, 0x7e, 0xd7, 0x1b, 0x1f, 0xbf, 0xd2, 0x3f, 0x80, 0x85, 0x98, 0xbc, 0x11, 0xae, 0xfc,
	0x6d, 0x0e, 0xee, 0xa6, 0x39, 0xd6, 0xc4, 0x8c, 0x61, 0x09, 0x7b, 0x97, 0xd2, 0x7e, 0x53, 0xdd,
	0x86, 0x05, 0xd6, 0x7e, 0x49, 0x1c, 0x76, 0xb7, 0x73, 0x96, 0x39, 0xa0, 0x5d, 0x99, 0x32, 0xf2,
	0xbe, 0x9b, 0x03, 0xda, 0xd5, 0xef, 0xc3, 0xbd, 0xd1, 0x86, 0x49, 0x9f, 0xff, 0x7d, 0x0e, 0x16,
	0xf7, 0x30, 0x35, 0xcc, 0x0b, 0x91, 0x64, 0xfb, 0x13, 0xc1, 0xff, 0x3a, 0xc4, 0xeb, 0x35, 0x63,
	0x70, 0x4c, 0xc9, 0xa8, 0x30, 0x62, 0xf8, 0x38, 0x5e, 0x83, 0x32, 0xf5, 0x9a, 0xb1, 0xe7, 0x75,
	0xc9, 0x00, 0xea, 0x05, 0x1d, 0xf4, 0xbf, 0xce, 0xc0, 0xf5, 0x21, 0xc3, 0xe4, 0x46, 0xec, 0x43,
	0x99, 0x98, 0x17, 0x12, 0x27, 0x60, 0xfe, 0xc9, 0xee, 0xa9, 0xf7, 0x23, 0x49, 0x71, 0x72, 0xcc,
	0x7a, 0x48, 0x32, 0x80, 0x84, 0x5c, 0xed, 0xbb, 0x69, 0x28, 0x85, 0x1c, 0xb4, 0x04, 0x05, 0x96,
	0xd4, 0xb2, 0x97, 0x92, 0x70, 0xb1, 0x3c, 0x6b, 0x1e, 0xb4, 0x43, 0x14, 0x6b, 0x4a, 0xa1, 0x58,
	0x68, 0x15, 0x8a, 0x2e, 0xbe, 0x10, 0xa9, 0x32, 0x37, 0xbe, 0x3e, 0x55, 0xcb, 0x19, 0x05, 0x17,
	0x5f, 0xf0, 0x64, 0x79, 0x15, 0x8a, 0x2c, 0x3d, 0xe0, 0xec, 0x19, 0xc5, 0xf6, 0x9c, 0x36, 0x67,
	0x1f, 0x43, 0xc9, 0xeb, 0x63, 0x62, 0x52, 0x36, 0xf7, 0x59, 0x9e, 0xd5, 0x7f, 0xf2, 0x8e, 0x13,
	0x58, 0x3f, 0x0e, 0x06, 0x1a, 0x4a, 0x06, 0x5b, 0x73, 0xb6, 0x26, 0x4a, 0xa8, 0xc0, 0x85, 0x2a,
	0xc4, 0xbc, 0x08, 0xfb, 0x33, 0x5f, 0x62, 0x46, 0xf5, 0xbc, 0x36, 0xe6, 0xe9, 0xfd, 0x2c, 0x37,
	0xe8, 0xd0, 0x6b, 0x63, 0x8e, 0x0b, 0xe1, 0x0b, 0xc1, 0x2a, 0x0a, 0x96, 0x8b, 0x2f, 0x38, 0xeb,
	0x1e, 0x5c, 0x0d, 0x66, 0xda, 0x6c, 0x5d, 0xb2, 0x88, 0x50, 0x12, 0xe9, 0xa4, 0x9c, 0x6b, 0x9d,
	0xd1, 0x58, 0xaf, 0x60, 0xc2, 0xb2, 0x17, 0x88, 0x5e, 0x72, 0xca, 0xbc, 0x97, 0x6e, 0x43, 0x49,
	0x99, 0x53, 0x86, 0xc2, 0xcb, 0xa3, 0xe7, 0x47, 0xc7, 0x9f, 0x1f, 0x55, 0xaf, 0xa0, 0x12, 0xcc,
	0x6e, 0x6e, 0x6f, 0xef, 0x6c, 0x0b, 0x80, 0x60, 0xeb, 0xf8, 0xe4, 0x60, 0x67, 0x5b, 0x00, 0x04,
	0xdb, 0x3b, 0x2f, 0x76, 0x4e, 0x77, 0xb6, 0xab, 0xd3, 0xa8, 0x02, 0xc5, 0xc3, 0xe3, 0xed, 0x83,
	0x5d, 0xc6, 0x9a, 0x61, 0x2c, 0x63, 0xe7, 0x68, 0xf3, 0x70, 0x67, 0xbb, 0x3a, 0x8b, 0xaa, 0x50,
	0x39, 0xfd, 0xe2, 0x64, 0xa7, 0xb9, 0xb5, 0xbf, 0x79, 0xb4, 0xb7, 0xb3, 0x5d, 0xcd, 0xeb, 0xbf,
	0xcb, 0x41, 0xad, 0x81, 0x4d, 0x62, 0x75, 0x77, 0x6d, 0x07, 0xfb, 0xf5, 0x4b, 0x16, 0x4d, 0xc7,
	0x77, 0xee, 0x45, 0x98, 0x7d, 0x3d, 0xc0, 0x32, 0x4b, 0x29, 0x19, 0xa2, 0x11, 0xe4, 0x8e, 0xd3,
	0x2a, 0x77, 0xbc, 0x01, 0xf9, 0x8e, 0xed, 0x50, 0x4c, 0xc4, 0xf6, 0x1b, 0xb2, 0xa5, 0x7f, 0x02,
	0xcb, 0x29, 0x56, 0xa9, 0x34, 0xb7, 0xc3, 0xc8, 0xdc, 0xa7, 0x2b, 0x86, 0x68, 0xe8, 0x7f, 0xce,
	0xc1, 0xcd, 0xd8, 0x98, 0x2d, 0xcf, 0xa5, 0xd8, 0xa5, 0x3f, 0xdc, 0x64, 0x3e, 0x80, 0xaa, 0xd5,
	0x1d, 0xb8, 0xe7, 0x98, 0x25, 0xbc, 0xc2, 0x56, 0x89, 0x55, 0x5e, 0x93, 0xf4, 0x30, 0x9e, 0x5c,
	0xc2, 0x4a, 0xba, 0xad, 0x72, 0x8a, 0x35, 0x28, 0xf4, 0x4c, 0x6a, 0x75, 0xc3, 0x49, 0x06, 0x4d,
	0xb4, 0x0a, 0xc0, 0x3f, 0x9b, 0x91, 0xdb, 0xbb, 0xc4, 0x29, 0xdb, 0x26, 0x35, 0xd1, 0x6d, 0xa8,
	0x60, 0xb7, 0xdd, 0xf4, 0x3a, 0x4d, 0x4e, 0x93, 0x18, 0x2a, 0x60, 0xb7, 0x7d, 0xdc, 0x39, 0x64,
	0x14, 0xfd, 0x37, 0x39, 0xc8, 0x0b, 0x4c, 0x31, 0x48, 0x1f, 0x72, 0x61, 0xfa, 0x80, 0x7e, 0x04,
	0xcb, 0x61, 0xb0, 0xf4, 0x88, 0xfd, 0x35, 0x77, 0xc1, 0x66, 0x17, 0x9b, 0x6d, 0x4c, 0x64, 0xf4,
	0x59, 0x0a, 0x82, 0x67, 0xc8, 0xdf, 0xe7, 0x6c, 0xf4, 0x1e, 0x5c, 0xed, 0xd9, 0x84, 0x78, 0xa4,
	0x49, 0x70, 0xa7, 0x67, 0xf6, 0xfd, 0xda, 0x0c, 0x7f, 0xf6, 0xcd, 0x09, 0xaa, 0x21, 0x88, 0xcf,
	0x66, 0x8a, 0x53, 0xd5, 0x69, 0x63, 0x86, 0xdd, 0xe6, 0xfa, 0x17, 0xb0, 0xba, 0x87, 0xe9, 0x71,
	0xeb, 0xe7, 0xd8, 0xa2, 0xdb, 0x36, 0xc1, 0xd6, 0xe4, 0xd0, 0xf6, 0x4f, 0xe1, 0x56, 0x96, 0xe8,
	0x11, 0xa8, 0xfb, 0x1f, 0x73, 0xb0, 0xb8, 0xe5, 0x78, 0x2e, 0x66, 0xb7, 0xc0, 0x89, 0xe7, 0x4d,
	0xa0, 0xb6, 0x75, 0x1f, 0x66, 0xfa, 0xec, 0x35, 0x3e, 0x94, 0xaf, 0x0b, 0xcb, 0xb8, 0x0a, 0xce,
	0x47, 0xf7, 0x43, 0x38, 0x7c, 0x3a, 0x15, 0x51, 0x96, 0x5c, 0x7d, 0x09, 0xae, 0x0f, 0x59, 0x28,
	0x7d, 0xea, 0x6f, 0x39, 0x58, 0x89, 0x71, 0x0e, 0x5c, 0x8a, 0x89, 0x6b, 0xfe, 0x80, 0x73, 0x48,
	0x05, 0x2a, 0xa6, 0xff, 0x0b, 0xa0, 0x62, 0x0d, 0x56, 0x33, 0xa6, 0x20, 0x27, 0xc9, 0x8b, 0xae,
	0x3d, 0xef, 0xcd, 0xa4, 0xb1, 0xed, 0xa4, 0x50, 0xa9, 0xf0, 0x2d, 0x53, 0xe8, 0xf2, 0xf0, 0x33,
	0x31, 0x85, 0xfc, 0x1e, 0xc2, 0x8e, 0x49, 0xed, 0x37, 0x12, 0x46, 0x96, 0x77, 0x7f, 0x40, 0x64,
	0x57, 0x81, 0xb0, 0x6a, 0x58, 0xb3, 0xb4, 0xea, 0x57, 0x39, 0x96, 0xc2, 0xf4, 0x1d, 0xdb, 0x9a,
	0x2c, 0xcc, 0x8f, 0x1e, 0x42, 0x5e, 0x6c, 0xca, 0x08, 0x7c, 0x49, 0xf6, 0xd0, 0x57, 0xe1, 0x66,
	0xaa, 0x0d, 0xd2, 0xc6, 0x97, 0xb0, 0x7c, 0xdc, 0xa7, 0x76, 0x8f, 0x9f, 0xb9, 0xc9, 0x6d, 0xd6,
	0x0a, 0x68, 0x69, 0x62, 0x85, 0xd2, 0x8d, 0x3f, 0xad, 0xf1, 0xca, 0x74, 0x50, 0x65, 0x13, 0x25,
	0x7d, 0xf4, 0x25, 0x54, 0x87, 0xab, 0xea, 0x68, 0x2d, 0xa9, 0x2d, 0x56, 0xc4, 0xd7, 0x6e, 0x67,
	0x77, 0x90, 0x33, 0xcc, 0xff, 0xfb, 0xdb, 0x07, 0x53, 0xc5, 0x29, 0xf4, 0x55, 0x50, 0x0d, 0x8f,
	0x94, 0xca, 0x51, 0x74, 0x78, 0x6a, 0x6d, 0x5e, 0xbb, 0x33, 0xa2, 0x47, 0x4c, 0x43, 0x0e, 0x3d,
	0x07, 0x50, 0xb5, 0x6f, 0xb4, 0x1c, 0x1f, 0x18, 0xa9, 0xc1, 0x6b, 0x5a, 0x1a, 0x2b, 0x29, 0x4c,
	0xd5, 0xb8, 0x95, 0xb0, 0x44, 0x19, 0x5d, 0x09, 0x4b, 0x29, 0x89, 0x07, 0xc2, 0x3e, 0x87, 0xab,
	0xf1, 0x5a, 0x34, 0x5a, 0x0d, 0x9f, 0x68, 0x69, 0x15, 0x73, 0xed, 0x56, 0x16, 0x7b, 0x48, 0xf0,
	0x97, 0x12, 0xfb, 0x8d, 0x14, 0x7f, 0xd5, 0x9e, 0x65, 0x54, 0x9c, 0xd5, 0x9e, 0x65, 0xd6, 0x8d,
	0x23, 0x76, 0xc7, 0xab, 0xb1, 0xca, 0xee, 0xd4, 0xc2, 0xaf, 0xb2, 0x3b, 0xbd, 0x88, 0x1b, 0x3a,
	0x83, 0x05, 0x28, 0x59, 0x45, 0x45, 0xe1, 0x5e, 0x67, 0x16, 0x75, 0x35, 0x7d, 0x54, 0x97, 0x21,
	0xeb, 0x8f, 0xa0, 0x1c, 0x29, 0x0e, 0xa2, 0x70, 0xa3, 0x92, 0x05, 0x5a, 0xed, 0x66, 0x2a, 0x2f,
	0xb9, 0xd8, 0xc3, 0x79, 0x90, 0x5a, 0xec, 0x8c, 0x62, 0xa2, 0x5a, 0xec, 0xcc, 0xc2, 0x60, 0x20,
	0xfe, 0x10, 0x40, 0xd5, 0xac, 0x94, 0xc7, 0x25, 0x2a, 0x73, 0xca, 0xe3, 0x92, 0x25, 0xae, 0x60,
	0x81, 0x3f, 0xe6, 0xd6, 0x0e, 0xd7, 0xa0, 0x94, 0xb5, 0x19, 0x25, 0x2f, 0x65, 0x6d, 0x56, 0xf9,
	0x2a, 0x7a, 0x9c, 0x13, 0x45, 0x1d, 0x75, 0x9c, 0xb3, 0x4a, 0x59, 0xea, 0x38, 0x67, 0x56, 0x84,
	0xc2, 0xf5, 0xf8, 0x7f, 0x98, 0xd9, 0xf5, 0xad, 0x73, 0xb4, 0x10, 0x0e, 0x51, 0xf5, 0x20, 0x6d,
	0x31, 0x4e, 0x1c, 0x32, 0x6e, 0x07, 0x8a, 0x41, 0x49, 0x04, 0x2d, 0xc5, 0xbc, 0x5d, 0x95, 0x77,
	0xb4, 0x5a, 0x92, 0x31, 0x64, 0xc1, 0x29, 0xcc, 0xc5, 0xea, 0x19, 0x68, 0x25, 0xd4, 0x9a, 0x52,
	0x56, 0xd1, 0x56, 0x33, 0xb8, 0x43, 0xc6, 0x3d, 0x07, 0x50, 0x75, 0x06, 0xb5, 0xcf, 0x89, 0x5a,
	0x88, 0xda, 0xe7, 0x94, 0xb2, 0x44, 0x60, 0xa2, 0x05, 0x28, 0x59, 0x2a, 0x50, 0x07, 0x29, 0xb3,
	0x74, 0xa1, 0x0e, 0x52, 0x76, 0xa5, 0x21, 0x7a, 0x5a, 0x93, 0xe0, 0x7e, 0x54, 0x49, 0x46, 0xb1,
	0x21, 0xaa, 0x24, 0xab, 0x36, 0x10, 0x2a, 0x21, 0xc9, 0x82, 0xbc, 0x04, 0xe5, 0xd1, 0xfd, 0xac,
	0x33, 0x14, 0xaf, 0x11, 0x68, 0xef, 0x7f, 0x6f, 0xbf, 0xa1, 0xd5, 0x6b, 0x40, 0x25, 0x0a, 0xca,
	0xa3, 0x9b, 0x71, 0x01, 0x31, 0x18, 0x51, 0x5b, 0x49, 0x67, 0x26, 0x0e, 0xde, 0x2f, 0x40, 0xcb,
	0x06, 0x08, 0xd1, 0x07, 0xa3, 0x6c, 0x8c, 0x2b, 0x7c, 0xf8, 0x2e, 0x5d, 0xe3, 0x33, 0x7a, 0x90,
	0x43, 0xcf, 0xa0, 0x14, 0xc2, 0xfd, 0xa8, 0x16, 0x09, 0x15, 0x31, 0xbc, 0x5a, 0x5b, 0x4e, 0xe1,
	0x24, 0xa6, 0xb2, 0x0f, 0xa5, 0x46, 0x52, 0x56, 0x23, 0x53, 0x56, 0x23, 0x43, 0x56, 0x0e, 0x7d,
	0x06, 0x95, 0x28, 0xa0, 0xad, 0x56, 0x3a, 0x05, 0x4b, 0x57, 0x2b, 0x9d, 0x8a, 0x81, 0x47, 0xc3,
	0xbb, 0x82, 0x44, 0x23, 0xe1, 0x3d, 0x81, 0xbb, 0x46, 0xc2, 0x7b, 0x12, 0x43, 0x0d, 0x1d, 0xb0,
	0xc5, 0xeb, 0x24, 0x71, 0x1c, 0x13, 0x45, 0x7f, 0x90, 0x48, 0x05, 0x4e, 0x55, 0x44, 0xcb, 0x04,
	0x41, 0x23, 0x0b, 0xfa, 0x15, 0xcc, 0x27, 0x80, 0x49, 0xa5, 0x23, 0x0b, 0x09, 0x55, 0x3a, 0x32,
	0x51, 0xcd, 0x70, 0x16, 0x75, 0x28, 0xc8, 0xdf, 0xb4, 0xd0, 0x8d, 0x70, 0x54, 0xec, 0x1f, 0x30,
	0x6d, 0x29, 0x41, 0x1f, 0x5a, 0xd9, 0x13, 0x28, 0x47, 0x50, 0x4b, 0x14, 0xbd, 0x6f, 0x86, 0xd0,
	0x48, 0xb5, 0xb2, 0x29, 0x30, 0x67, 0x64, 0xde, 0xbf, 0x64, 0x69, 0xd7, 0x08, 0x0c, 0x11, 0x7d,
	0x38, 0xca, 0xd7, 0x87, 0x95, 0x3e, 0x7a, 0xb7, 0xce, 0x43, 0xb3, 0xfa, 0x19, 0xcc, 0xc5, 0xf0,
	0x30, 0x15, 0xcd, 0xd3, 0x40, 0x4b, 0x15, 0xcd, 0x53, 0x41, 0xb4, 0xc8, 0xdc, 0xce, 0x61, 0x31,
	0x0d, 0xa6, 0x40, 0x77, 0xd5, 0xa9, 0xc8, 0x04, 0x5c, 0xb4, 0x7b, 0xa3, 0x3b, 0x25, 0x94, 0xb5,
	0x60, 0x3e, 0x81, 0xf9, 0x28, 0x07, 0xca, 0x02, 0xa9, 0x94, 0x03, 0x65, 0x02, 0x46, 0x11, 0x1d,
	0x18, 0x50, 0xb2, 0xf2, 0x83, 0x22, 0x0f, 0xf1, 0x8c, 0x02, 0x94, 0x0a, 0xf7, 0x23, 0x0a, 0x47,
	0x2a, 0x50, 0xb5, 0x60, 0x3e, 0x51, 0xec, 0x51, 0x53, 0xc9, 0xaa, 0x2e, 0xa9, 0xa9, 0x64, 0x56,
	0x8a, 0x22, 0x53, 0xf1, 0xe0, 0x46, 0x3a, 0xc0, 0x81, 0xde, 0x8b, 0x6c, 0x6f, 0x36, 0xb6, 0xa2,
	0xdd, 0xff, 0xbe, 0x6e, 0x43, 0xc7, 0xef, 0x14, 0xe6, 0x62, 0xb9, 0xb9, 0x72, 0xb2, 0x34, 0xc4,
	0x44, 0x39, 0x59, 0x3a, 0x5a, 0x11, 0xb8, 0xae, 0x33, 0x04, 0x67, 0x04, 0x19, 0x3f, 0xba, 0x97,
	0x3a, 0x7e, 0x08, 0xd3, 0xd0, 0xde, 0xfb, 0x9e, 0x5e, 0xc9, 0x77, 0xee, 0x70, 0xa6, 0x1f, 0x4d,
	0x04, 0x53, 0x81, 0x85, 0x68, 0x22, 0x98, 0x01, 0x12, 0xc4, 0xc4, 0xc7, 0x53, 0xf6, 0xa8, 0xf8,
	0x54, 0x18, 0x21, 0x2a, 0x3e, 0x23, 0xdb, 0x0f, 0xc4, 0x77, 0x60, 0x21, 0x25, 0xe1, 0x46, 0x11,
	0xdf, 0xcc, 0x42, 0x04, 0xb4, 0xbb, 0x23, 0xfb, 0x24, 0x5f, 0x5e, 0xc9, 0x14, 0x5b, 0x9d, 0x92,
	0xcc, 0xac, 0x5e, 0x9d, 0x92, 0xec, 0x0c, 0x3d, 0x50, 0x52, 0xff, 0xf4, 0xd5, 0xc6, 0x99, 0x4d,
	0x1d, 0xb3, 0xb5, 0x6e, 0x79, 0xbd, 0xc7, 0xe2, 0xf3, 0x23, 0x8f, 0x9c, 0x3d, 0x16, 0x22, 0x1e,
	0xbf, 0xf9, 0xe4, 0xd3, 0xc7, 0xfc, 0x47, 0xfb, 0xc7, 0x67, 0x9e, 0xa4, 0xf5, 0x5b, 0xad, 0x3c,
	0x27, 0x3d, 0xf9, 0x4f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x24, 0x49, 0x14, 0x33, 0xb9, 0x2f, 0x00,
	0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// RepositoryServiceClient is the client API for RepositoryService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type RepositoryServiceClient interface {
	RepositoryExists(ctx context.Context, in *RepositoryExistsRequest, opts ...grpc.CallOption) (*RepositoryExistsResponse, error)
	RepackIncremental(ctx context.Context, in *RepackIncrementalRequest, opts ...grpc.CallOption) (*RepackIncrementalResponse, error)
	RepackFull(ctx context.Context, in *RepackFullRequest, opts ...grpc.CallOption) (*RepackFullResponse, error)
	MidxRepack(ctx context.Context, in *MidxRepackRequest, opts ...grpc.CallOption) (*MidxRepackResponse, error)
	GarbageCollect(ctx context.Context, in *GarbageCollectRequest, opts ...grpc.CallOption) (*GarbageCollectResponse, error)
	WriteCommitGraph(ctx context.Context, in *WriteCommitGraphRequest, opts ...grpc.CallOption) (*WriteCommitGraphResponse, error)
	RepositorySize(ctx context.Context, in *RepositorySizeRequest, opts ...grpc.CallOption) (*RepositorySizeResponse, error)
	ApplyGitattributes(ctx context.Context, in *ApplyGitattributesRequest, opts ...grpc.CallOption) (*ApplyGitattributesResponse, error)
	// FetchRemote fetches references from a remote repository into the local
	// repository.
	FetchRemote(ctx context.Context, in *FetchRemoteRequest, opts ...grpc.CallOption) (*FetchRemoteResponse, error)
	CreateRepository(ctx context.Context, in *CreateRepositoryRequest, opts ...grpc.CallOption) (*CreateRepositoryResponse, error)
	GetArchive(ctx context.Context, in *GetArchiveRequest, opts ...grpc.CallOption) (RepositoryService_GetArchiveClient, error)
	HasLocalBranches(ctx context.Context, in *HasLocalBranchesRequest, opts ...grpc.CallOption) (*HasLocalBranchesResponse, error)
	// FetchSourceBranch fetches a branch from a second (potentially remote)
	// repository into the given repository.
	FetchSourceBranch(ctx context.Context, in *FetchSourceBranchRequest, opts ...grpc.CallOption) (*FetchSourceBranchResponse, error)
	Fsck(ctx context.Context, in *FsckRequest, opts ...grpc.CallOption) (*FsckResponse, error)
	WriteRef(ctx context.Context, in *WriteRefRequest, opts ...grpc.CallOption) (*WriteRefResponse, error)
	FindMergeBase(ctx context.Context, in *FindMergeBaseRequest, opts ...grpc.CallOption) (*FindMergeBaseResponse, error)
	CreateFork(ctx context.Context, in *CreateForkRequest, opts ...grpc.CallOption) (*CreateForkResponse, error)
	IsRebaseInProgress(ctx context.Context, in *IsRebaseInProgressRequest, opts ...grpc.CallOption) (*IsRebaseInProgressResponse, error)
	IsSquashInProgress(ctx context.Context, in *IsSquashInProgressRequest, opts ...grpc.CallOption) (*IsSquashInProgressResponse, error)
	CreateRepositoryFromURL(ctx context.Context, in *CreateRepositoryFromURLRequest, opts ...grpc.CallOption) (*CreateRepositoryFromURLResponse, error)
	CreateBundle(ctx context.Context, in *CreateBundleRequest, opts ...grpc.CallOption) (RepositoryService_CreateBundleClient, error)
	CreateRepositoryFromBundle(ctx context.Context, opts ...grpc.CallOption) (RepositoryService_CreateRepositoryFromBundleClient, error)
	// GetConfig reads the target repository's gitconfig and streams its contents
	// back. Returns a NotFound error in case no gitconfig was found.
	GetConfig(ctx context.Context, in *GetConfigRequest, opts ...grpc.CallOption) (RepositoryService_GetConfigClient, error)
	SetConfig(ctx context.Context, in *SetConfigRequest, opts ...grpc.CallOption) (*SetConfigResponse, error)
	DeleteConfig(ctx context.Context, in *DeleteConfigRequest, opts ...grpc.CallOption) (*DeleteConfigResponse, error)
	FindLicense(ctx context.Context, in *FindLicenseRequest, opts ...grpc.CallOption) (*FindLicenseResponse, error)
	GetInfoAttributes(ctx context.Context, in *GetInfoAttributesRequest, opts ...grpc.CallOption) (RepositoryService_GetInfoAttributesClient, error)
	CalculateChecksum(ctx context.Context, in *CalculateChecksumRequest, opts ...grpc.CallOption) (*CalculateChecksumResponse, error)
	Cleanup(ctx context.Context, in *CleanupRequest, opts ...grpc.CallOption) (*CleanupResponse, error)
	GetSnapshot(ctx context.Context, in *GetSnapshotRequest, opts ...grpc.CallOption) (RepositoryService_GetSnapshotClient, error)
	CreateRepositoryFromSnapshot(ctx context.Context, in *CreateRepositoryFromSnapshotRequest, opts ...grpc.CallOption) (*CreateRepositoryFromSnapshotResponse, error)
	GetRawChanges(ctx context.Context, in *GetRawChangesRequest, opts ...grpc.CallOption) (RepositoryService_GetRawChangesClient, error)
	SearchFilesByContent(ctx context.Context, in *SearchFilesByContentRequest, opts ...grpc.CallOption) (RepositoryService_SearchFilesByContentClient, error)
	SearchFilesByName(ctx context.Context, in *SearchFilesByNameRequest, opts ...grpc.CallOption) (RepositoryService_SearchFilesByNameClient, error)
	RestoreCustomHooks(ctx context.Context, opts ...grpc.CallOption) (RepositoryService_RestoreCustomHooksClient, error)
	BackupCustomHooks(ctx context.Context, in *BackupCustomHooksRequest, opts ...grpc.CallOption) (RepositoryService_BackupCustomHooksClient, error)
	GetObjectDirectorySize(ctx context.Context, in *GetObjectDirectorySizeRequest, opts ...grpc.CallOption) (*GetObjectDirectorySizeResponse, error)
	CloneFromPool(ctx context.Context, in *CloneFromPoolRequest, opts ...grpc.CallOption) (*CloneFromPoolResponse, error)
	CloneFromPoolInternal(ctx context.Context, in *CloneFromPoolInternalRequest, opts ...grpc.CallOption) (*CloneFromPoolInternalResponse, error)
	// RemoveRepository will move the repository to `+gitaly/tmp/<relative_path>_removed` and
	// eventually remove it. This ensures that even on networked filesystems the
	// data is actually removed even if there's someone still handling the data.
	RemoveRepository(ctx context.Context, in *RemoveRepositoryRequest, opts ...grpc.CallOption) (*RemoveRepositoryResponse, error)
	RenameRepository(ctx context.Context, in *RenameRepositoryRequest, opts ...grpc.CallOption) (*RenameRepositoryResponse, error)
	ReplicateRepository(ctx context.Context, in *ReplicateRepositoryRequest, opts ...grpc.CallOption) (*ReplicateRepositoryResponse, error)
	OptimizeRepository(ctx context.Context, in *OptimizeRepositoryRequest, opts ...grpc.CallOption) (*OptimizeRepositoryResponse, error)
}

type repositoryServiceClient struct {
	cc *grpc.ClientConn
}

func NewRepositoryServiceClient(cc *grpc.ClientConn) RepositoryServiceClient {
	return &repositoryServiceClient{cc}
}

func (c *repositoryServiceClient) RepositoryExists(ctx context.Context, in *RepositoryExistsRequest, opts ...grpc.CallOption) (*RepositoryExistsResponse, error) {
	out := new(RepositoryExistsResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/RepositoryExists", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) RepackIncremental(ctx context.Context, in *RepackIncrementalRequest, opts ...grpc.CallOption) (*RepackIncrementalResponse, error) {
	out := new(RepackIncrementalResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/RepackIncremental", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) RepackFull(ctx context.Context, in *RepackFullRequest, opts ...grpc.CallOption) (*RepackFullResponse, error) {
	out := new(RepackFullResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/RepackFull", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) MidxRepack(ctx context.Context, in *MidxRepackRequest, opts ...grpc.CallOption) (*MidxRepackResponse, error) {
	out := new(MidxRepackResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/MidxRepack", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) GarbageCollect(ctx context.Context, in *GarbageCollectRequest, opts ...grpc.CallOption) (*GarbageCollectResponse, error) {
	out := new(GarbageCollectResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/GarbageCollect", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) WriteCommitGraph(ctx context.Context, in *WriteCommitGraphRequest, opts ...grpc.CallOption) (*WriteCommitGraphResponse, error) {
	out := new(WriteCommitGraphResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/WriteCommitGraph", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) RepositorySize(ctx context.Context, in *RepositorySizeRequest, opts ...grpc.CallOption) (*RepositorySizeResponse, error) {
	out := new(RepositorySizeResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/RepositorySize", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) ApplyGitattributes(ctx context.Context, in *ApplyGitattributesRequest, opts ...grpc.CallOption) (*ApplyGitattributesResponse, error) {
	out := new(ApplyGitattributesResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/ApplyGitattributes", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) FetchRemote(ctx context.Context, in *FetchRemoteRequest, opts ...grpc.CallOption) (*FetchRemoteResponse, error) {
	out := new(FetchRemoteResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/FetchRemote", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) CreateRepository(ctx context.Context, in *CreateRepositoryRequest, opts ...grpc.CallOption) (*CreateRepositoryResponse, error) {
	out := new(CreateRepositoryResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/CreateRepository", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) GetArchive(ctx context.Context, in *GetArchiveRequest, opts ...grpc.CallOption) (RepositoryService_GetArchiveClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[0], "/gitaly.RepositoryService/GetArchive", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceGetArchiveClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_GetArchiveClient interface {
	Recv() (*GetArchiveResponse, error)
	grpc.ClientStream
}

type repositoryServiceGetArchiveClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceGetArchiveClient) Recv() (*GetArchiveResponse, error) {
	m := new(GetArchiveResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) HasLocalBranches(ctx context.Context, in *HasLocalBranchesRequest, opts ...grpc.CallOption) (*HasLocalBranchesResponse, error) {
	out := new(HasLocalBranchesResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/HasLocalBranches", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) FetchSourceBranch(ctx context.Context, in *FetchSourceBranchRequest, opts ...grpc.CallOption) (*FetchSourceBranchResponse, error) {
	out := new(FetchSourceBranchResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/FetchSourceBranch", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) Fsck(ctx context.Context, in *FsckRequest, opts ...grpc.CallOption) (*FsckResponse, error) {
	out := new(FsckResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/Fsck", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) WriteRef(ctx context.Context, in *WriteRefRequest, opts ...grpc.CallOption) (*WriteRefResponse, error) {
	out := new(WriteRefResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/WriteRef", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) FindMergeBase(ctx context.Context, in *FindMergeBaseRequest, opts ...grpc.CallOption) (*FindMergeBaseResponse, error) {
	out := new(FindMergeBaseResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/FindMergeBase", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) CreateFork(ctx context.Context, in *CreateForkRequest, opts ...grpc.CallOption) (*CreateForkResponse, error) {
	out := new(CreateForkResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/CreateFork", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) IsRebaseInProgress(ctx context.Context, in *IsRebaseInProgressRequest, opts ...grpc.CallOption) (*IsRebaseInProgressResponse, error) {
	out := new(IsRebaseInProgressResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/IsRebaseInProgress", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) IsSquashInProgress(ctx context.Context, in *IsSquashInProgressRequest, opts ...grpc.CallOption) (*IsSquashInProgressResponse, error) {
	out := new(IsSquashInProgressResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/IsSquashInProgress", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) CreateRepositoryFromURL(ctx context.Context, in *CreateRepositoryFromURLRequest, opts ...grpc.CallOption) (*CreateRepositoryFromURLResponse, error) {
	out := new(CreateRepositoryFromURLResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/CreateRepositoryFromURL", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) CreateBundle(ctx context.Context, in *CreateBundleRequest, opts ...grpc.CallOption) (RepositoryService_CreateBundleClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[1], "/gitaly.RepositoryService/CreateBundle", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceCreateBundleClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_CreateBundleClient interface {
	Recv() (*CreateBundleResponse, error)
	grpc.ClientStream
}

type repositoryServiceCreateBundleClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceCreateBundleClient) Recv() (*CreateBundleResponse, error) {
	m := new(CreateBundleResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) CreateRepositoryFromBundle(ctx context.Context, opts ...grpc.CallOption) (RepositoryService_CreateRepositoryFromBundleClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[2], "/gitaly.RepositoryService/CreateRepositoryFromBundle", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceCreateRepositoryFromBundleClient{stream}
	return x, nil
}

type RepositoryService_CreateRepositoryFromBundleClient interface {
	Send(*CreateRepositoryFromBundleRequest) error
	CloseAndRecv() (*CreateRepositoryFromBundleResponse, error)
	grpc.ClientStream
}

type repositoryServiceCreateRepositoryFromBundleClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceCreateRepositoryFromBundleClient) Send(m *CreateRepositoryFromBundleRequest) error {
	return x.ClientStream.SendMsg(m)
}

func (x *repositoryServiceCreateRepositoryFromBundleClient) CloseAndRecv() (*CreateRepositoryFromBundleResponse, error) {
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	m := new(CreateRepositoryFromBundleResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) GetConfig(ctx context.Context, in *GetConfigRequest, opts ...grpc.CallOption) (RepositoryService_GetConfigClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[3], "/gitaly.RepositoryService/GetConfig", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceGetConfigClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_GetConfigClient interface {
	Recv() (*GetConfigResponse, error)
	grpc.ClientStream
}

type repositoryServiceGetConfigClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceGetConfigClient) Recv() (*GetConfigResponse, error) {
	m := new(GetConfigResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) SetConfig(ctx context.Context, in *SetConfigRequest, opts ...grpc.CallOption) (*SetConfigResponse, error) {
	out := new(SetConfigResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/SetConfig", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) DeleteConfig(ctx context.Context, in *DeleteConfigRequest, opts ...grpc.CallOption) (*DeleteConfigResponse, error) {
	out := new(DeleteConfigResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/DeleteConfig", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) FindLicense(ctx context.Context, in *FindLicenseRequest, opts ...grpc.CallOption) (*FindLicenseResponse, error) {
	out := new(FindLicenseResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/FindLicense", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) GetInfoAttributes(ctx context.Context, in *GetInfoAttributesRequest, opts ...grpc.CallOption) (RepositoryService_GetInfoAttributesClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[4], "/gitaly.RepositoryService/GetInfoAttributes", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceGetInfoAttributesClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_GetInfoAttributesClient interface {
	Recv() (*GetInfoAttributesResponse, error)
	grpc.ClientStream
}

type repositoryServiceGetInfoAttributesClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceGetInfoAttributesClient) Recv() (*GetInfoAttributesResponse, error) {
	m := new(GetInfoAttributesResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) CalculateChecksum(ctx context.Context, in *CalculateChecksumRequest, opts ...grpc.CallOption) (*CalculateChecksumResponse, error) {
	out := new(CalculateChecksumResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/CalculateChecksum", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) Cleanup(ctx context.Context, in *CleanupRequest, opts ...grpc.CallOption) (*CleanupResponse, error) {
	out := new(CleanupResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/Cleanup", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) GetSnapshot(ctx context.Context, in *GetSnapshotRequest, opts ...grpc.CallOption) (RepositoryService_GetSnapshotClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[5], "/gitaly.RepositoryService/GetSnapshot", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceGetSnapshotClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_GetSnapshotClient interface {
	Recv() (*GetSnapshotResponse, error)
	grpc.ClientStream
}

type repositoryServiceGetSnapshotClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceGetSnapshotClient) Recv() (*GetSnapshotResponse, error) {
	m := new(GetSnapshotResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) CreateRepositoryFromSnapshot(ctx context.Context, in *CreateRepositoryFromSnapshotRequest, opts ...grpc.CallOption) (*CreateRepositoryFromSnapshotResponse, error) {
	out := new(CreateRepositoryFromSnapshotResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/CreateRepositoryFromSnapshot", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) GetRawChanges(ctx context.Context, in *GetRawChangesRequest, opts ...grpc.CallOption) (RepositoryService_GetRawChangesClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[6], "/gitaly.RepositoryService/GetRawChanges", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceGetRawChangesClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_GetRawChangesClient interface {
	Recv() (*GetRawChangesResponse, error)
	grpc.ClientStream
}

type repositoryServiceGetRawChangesClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceGetRawChangesClient) Recv() (*GetRawChangesResponse, error) {
	m := new(GetRawChangesResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) SearchFilesByContent(ctx context.Context, in *SearchFilesByContentRequest, opts ...grpc.CallOption) (RepositoryService_SearchFilesByContentClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[7], "/gitaly.RepositoryService/SearchFilesByContent", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceSearchFilesByContentClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_SearchFilesByContentClient interface {
	Recv() (*SearchFilesByContentResponse, error)
	grpc.ClientStream
}

type repositoryServiceSearchFilesByContentClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceSearchFilesByContentClient) Recv() (*SearchFilesByContentResponse, error) {
	m := new(SearchFilesByContentResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) SearchFilesByName(ctx context.Context, in *SearchFilesByNameRequest, opts ...grpc.CallOption) (RepositoryService_SearchFilesByNameClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[8], "/gitaly.RepositoryService/SearchFilesByName", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceSearchFilesByNameClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_SearchFilesByNameClient interface {
	Recv() (*SearchFilesByNameResponse, error)
	grpc.ClientStream
}

type repositoryServiceSearchFilesByNameClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceSearchFilesByNameClient) Recv() (*SearchFilesByNameResponse, error) {
	m := new(SearchFilesByNameResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) RestoreCustomHooks(ctx context.Context, opts ...grpc.CallOption) (RepositoryService_RestoreCustomHooksClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[9], "/gitaly.RepositoryService/RestoreCustomHooks", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceRestoreCustomHooksClient{stream}
	return x, nil
}

type RepositoryService_RestoreCustomHooksClient interface {
	Send(*RestoreCustomHooksRequest) error
	CloseAndRecv() (*RestoreCustomHooksResponse, error)
	grpc.ClientStream
}

type repositoryServiceRestoreCustomHooksClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceRestoreCustomHooksClient) Send(m *RestoreCustomHooksRequest) error {
	return x.ClientStream.SendMsg(m)
}

func (x *repositoryServiceRestoreCustomHooksClient) CloseAndRecv() (*RestoreCustomHooksResponse, error) {
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	m := new(RestoreCustomHooksResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) BackupCustomHooks(ctx context.Context, in *BackupCustomHooksRequest, opts ...grpc.CallOption) (RepositoryService_BackupCustomHooksClient, error) {
	stream, err := c.cc.NewStream(ctx, &_RepositoryService_serviceDesc.Streams[10], "/gitaly.RepositoryService/BackupCustomHooks", opts...)
	if err != nil {
		return nil, err
	}
	x := &repositoryServiceBackupCustomHooksClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type RepositoryService_BackupCustomHooksClient interface {
	Recv() (*BackupCustomHooksResponse, error)
	grpc.ClientStream
}

type repositoryServiceBackupCustomHooksClient struct {
	grpc.ClientStream
}

func (x *repositoryServiceBackupCustomHooksClient) Recv() (*BackupCustomHooksResponse, error) {
	m := new(BackupCustomHooksResponse)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *repositoryServiceClient) GetObjectDirectorySize(ctx context.Context, in *GetObjectDirectorySizeRequest, opts ...grpc.CallOption) (*GetObjectDirectorySizeResponse, error) {
	out := new(GetObjectDirectorySizeResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/GetObjectDirectorySize", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) CloneFromPool(ctx context.Context, in *CloneFromPoolRequest, opts ...grpc.CallOption) (*CloneFromPoolResponse, error) {
	out := new(CloneFromPoolResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/CloneFromPool", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) CloneFromPoolInternal(ctx context.Context, in *CloneFromPoolInternalRequest, opts ...grpc.CallOption) (*CloneFromPoolInternalResponse, error) {
	out := new(CloneFromPoolInternalResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/CloneFromPoolInternal", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) RemoveRepository(ctx context.Context, in *RemoveRepositoryRequest, opts ...grpc.CallOption) (*RemoveRepositoryResponse, error) {
	out := new(RemoveRepositoryResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/RemoveRepository", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) RenameRepository(ctx context.Context, in *RenameRepositoryRequest, opts ...grpc.CallOption) (*RenameRepositoryResponse, error) {
	out := new(RenameRepositoryResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/RenameRepository", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) ReplicateRepository(ctx context.Context, in *ReplicateRepositoryRequest, opts ...grpc.CallOption) (*ReplicateRepositoryResponse, error) {
	out := new(ReplicateRepositoryResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/ReplicateRepository", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *repositoryServiceClient) OptimizeRepository(ctx context.Context, in *OptimizeRepositoryRequest, opts ...grpc.CallOption) (*OptimizeRepositoryResponse, error) {
	out := new(OptimizeRepositoryResponse)
	err := c.cc.Invoke(ctx, "/gitaly.RepositoryService/OptimizeRepository", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// RepositoryServiceServer is the server API for RepositoryService service.
type RepositoryServiceServer interface {
	RepositoryExists(context.Context, *RepositoryExistsRequest) (*RepositoryExistsResponse, error)
	RepackIncremental(context.Context, *RepackIncrementalRequest) (*RepackIncrementalResponse, error)
	RepackFull(context.Context, *RepackFullRequest) (*RepackFullResponse, error)
	MidxRepack(context.Context, *MidxRepackRequest) (*MidxRepackResponse, error)
	GarbageCollect(context.Context, *GarbageCollectRequest) (*GarbageCollectResponse, error)
	WriteCommitGraph(context.Context, *WriteCommitGraphRequest) (*WriteCommitGraphResponse, error)
	RepositorySize(context.Context, *RepositorySizeRequest) (*RepositorySizeResponse, error)
	ApplyGitattributes(context.Context, *ApplyGitattributesRequest) (*ApplyGitattributesResponse, error)
	// FetchRemote fetches references from a remote repository into the local
	// repository.
	FetchRemote(context.Context, *FetchRemoteRequest) (*FetchRemoteResponse, error)
	CreateRepository(context.Context, *CreateRepositoryRequest) (*CreateRepositoryResponse, error)
	GetArchive(*GetArchiveRequest, RepositoryService_GetArchiveServer) error
	HasLocalBranches(context.Context, *HasLocalBranchesRequest) (*HasLocalBranchesResponse, error)
	// FetchSourceBranch fetches a branch from a second (potentially remote)
	// repository into the given repository.
	FetchSourceBranch(context.Context, *FetchSourceBranchRequest) (*FetchSourceBranchResponse, error)
	Fsck(context.Context, *FsckRequest) (*FsckResponse, error)
	WriteRef(context.Context, *WriteRefRequest) (*WriteRefResponse, error)
	FindMergeBase(context.Context, *FindMergeBaseRequest) (*FindMergeBaseResponse, error)
	CreateFork(context.Context, *CreateForkRequest) (*CreateForkResponse, error)
	IsRebaseInProgress(context.Context, *IsRebaseInProgressRequest) (*IsRebaseInProgressResponse, error)
	IsSquashInProgress(context.Context, *IsSquashInProgressRequest) (*IsSquashInProgressResponse, error)
	CreateRepositoryFromURL(context.Context, *CreateRepositoryFromURLRequest) (*CreateRepositoryFromURLResponse, error)
	CreateBundle(*CreateBundleRequest, RepositoryService_CreateBundleServer) error
	CreateRepositoryFromBundle(RepositoryService_CreateRepositoryFromBundleServer) error
	// GetConfig reads the target repository's gitconfig and streams its contents
	// back. Returns a NotFound error in case no gitconfig was found.
	GetConfig(*GetConfigRequest, RepositoryService_GetConfigServer) error
	SetConfig(context.Context, *SetConfigRequest) (*SetConfigResponse, error)
	DeleteConfig(context.Context, *DeleteConfigRequest) (*DeleteConfigResponse, error)
	FindLicense(context.Context, *FindLicenseRequest) (*FindLicenseResponse, error)
	GetInfoAttributes(*GetInfoAttributesRequest, RepositoryService_GetInfoAttributesServer) error
	CalculateChecksum(context.Context, *CalculateChecksumRequest) (*CalculateChecksumResponse, error)
	Cleanup(context.Context, *CleanupRequest) (*CleanupResponse, error)
	GetSnapshot(*GetSnapshotRequest, RepositoryService_GetSnapshotServer) error
	CreateRepositoryFromSnapshot(context.Context, *CreateRepositoryFromSnapshotRequest) (*CreateRepositoryFromSnapshotResponse, error)
	GetRawChanges(*GetRawChangesRequest, RepositoryService_GetRawChangesServer) error
	SearchFilesByContent(*SearchFilesByContentRequest, RepositoryService_SearchFilesByContentServer) error
	SearchFilesByName(*SearchFilesByNameRequest, RepositoryService_SearchFilesByNameServer) error
	RestoreCustomHooks(RepositoryService_RestoreCustomHooksServer) error
	BackupCustomHooks(*BackupCustomHooksRequest, RepositoryService_BackupCustomHooksServer) error
	GetObjectDirectorySize(context.Context, *GetObjectDirectorySizeRequest) (*GetObjectDirectorySizeResponse, error)
	CloneFromPool(context.Context, *CloneFromPoolRequest) (*CloneFromPoolResponse, error)
	CloneFromPoolInternal(context.Context, *CloneFromPoolInternalRequest) (*CloneFromPoolInternalResponse, error)
	// RemoveRepository will move the repository to `+gitaly/tmp/<relative_path>_removed` and
	// eventually remove it. This ensures that even on networked filesystems the
	// data is actually removed even if there's someone still handling the data.
	RemoveRepository(context.Context, *RemoveRepositoryRequest) (*RemoveRepositoryResponse, error)
	RenameRepository(context.Context, *RenameRepositoryRequest) (*RenameRepositoryResponse, error)
	ReplicateRepository(context.Context, *ReplicateRepositoryRequest) (*ReplicateRepositoryResponse, error)
	OptimizeRepository(context.Context, *OptimizeRepositoryRequest) (*OptimizeRepositoryResponse, error)
}

// UnimplementedRepositoryServiceServer can be embedded to have forward compatible implementations.
type UnimplementedRepositoryServiceServer struct {
}

func (*UnimplementedRepositoryServiceServer) RepositoryExists(ctx context.Context, req *RepositoryExistsRequest) (*RepositoryExistsResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method RepositoryExists not implemented")
}
func (*UnimplementedRepositoryServiceServer) RepackIncremental(ctx context.Context, req *RepackIncrementalRequest) (*RepackIncrementalResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method RepackIncremental not implemented")
}
func (*UnimplementedRepositoryServiceServer) RepackFull(ctx context.Context, req *RepackFullRequest) (*RepackFullResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method RepackFull not implemented")
}
func (*UnimplementedRepositoryServiceServer) MidxRepack(ctx context.Context, req *MidxRepackRequest) (*MidxRepackResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method MidxRepack not implemented")
}
func (*UnimplementedRepositoryServiceServer) GarbageCollect(ctx context.Context, req *GarbageCollectRequest) (*GarbageCollectResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method GarbageCollect not implemented")
}
func (*UnimplementedRepositoryServiceServer) WriteCommitGraph(ctx context.Context, req *WriteCommitGraphRequest) (*WriteCommitGraphResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method WriteCommitGraph not implemented")
}
func (*UnimplementedRepositoryServiceServer) RepositorySize(ctx context.Context, req *RepositorySizeRequest) (*RepositorySizeResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method RepositorySize not implemented")
}
func (*UnimplementedRepositoryServiceServer) ApplyGitattributes(ctx context.Context, req *ApplyGitattributesRequest) (*ApplyGitattributesResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method ApplyGitattributes not implemented")
}
func (*UnimplementedRepositoryServiceServer) FetchRemote(ctx context.Context, req *FetchRemoteRequest) (*FetchRemoteResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method FetchRemote not implemented")
}
func (*UnimplementedRepositoryServiceServer) CreateRepository(ctx context.Context, req *CreateRepositoryRequest) (*CreateRepositoryResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method CreateRepository not implemented")
}
func (*UnimplementedRepositoryServiceServer) GetArchive(req *GetArchiveRequest, srv RepositoryService_GetArchiveServer) error {
	return status.Errorf(codes.Unimplemented, "method GetArchive not implemented")
}
func (*UnimplementedRepositoryServiceServer) HasLocalBranches(ctx context.Context, req *HasLocalBranchesRequest) (*HasLocalBranchesResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method HasLocalBranches not implemented")
}
func (*UnimplementedRepositoryServiceServer) FetchSourceBranch(ctx context.Context, req *FetchSourceBranchRequest) (*FetchSourceBranchResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method FetchSourceBranch not implemented")
}
func (*UnimplementedRepositoryServiceServer) Fsck(ctx context.Context, req *FsckRequest) (*FsckResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method Fsck not implemented")
}
func (*UnimplementedRepositoryServiceServer) WriteRef(ctx context.Context, req *WriteRefRequest) (*WriteRefResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method WriteRef not implemented")
}
func (*UnimplementedRepositoryServiceServer) FindMergeBase(ctx context.Context, req *FindMergeBaseRequest) (*FindMergeBaseResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method FindMergeBase not implemented")
}
func (*UnimplementedRepositoryServiceServer) CreateFork(ctx context.Context, req *CreateForkRequest) (*CreateForkResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method CreateFork not implemented")
}
func (*UnimplementedRepositoryServiceServer) IsRebaseInProgress(ctx context.Context, req *IsRebaseInProgressRequest) (*IsRebaseInProgressResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method IsRebaseInProgress not implemented")
}
func (*UnimplementedRepositoryServiceServer) IsSquashInProgress(ctx context.Context, req *IsSquashInProgressRequest) (*IsSquashInProgressResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method IsSquashInProgress not implemented")
}
func (*UnimplementedRepositoryServiceServer) CreateRepositoryFromURL(ctx context.Context, req *CreateRepositoryFromURLRequest) (*CreateRepositoryFromURLResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method CreateRepositoryFromURL not implemented")
}
func (*UnimplementedRepositoryServiceServer) CreateBundle(req *CreateBundleRequest, srv RepositoryService_CreateBundleServer) error {
	return status.Errorf(codes.Unimplemented, "method CreateBundle not implemented")
}
func (*UnimplementedRepositoryServiceServer) CreateRepositoryFromBundle(srv RepositoryService_CreateRepositoryFromBundleServer) error {
	return status.Errorf(codes.Unimplemented, "method CreateRepositoryFromBundle not implemented")
}
func (*UnimplementedRepositoryServiceServer) GetConfig(req *GetConfigRequest, srv RepositoryService_GetConfigServer) error {
	return status.Errorf(codes.Unimplemented, "method GetConfig not implemented")
}
func (*UnimplementedRepositoryServiceServer) SetConfig(ctx context.Context, req *SetConfigRequest) (*SetConfigResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method SetConfig not implemented")
}
func (*UnimplementedRepositoryServiceServer) DeleteConfig(ctx context.Context, req *DeleteConfigRequest) (*DeleteConfigResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method DeleteConfig not implemented")
}
func (*UnimplementedRepositoryServiceServer) FindLicense(ctx context.Context, req *FindLicenseRequest) (*FindLicenseResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method FindLicense not implemented")
}
func (*UnimplementedRepositoryServiceServer) GetInfoAttributes(req *GetInfoAttributesRequest, srv RepositoryService_GetInfoAttributesServer) error {
	return status.Errorf(codes.Unimplemented, "method GetInfoAttributes not implemented")
}
func (*UnimplementedRepositoryServiceServer) CalculateChecksum(ctx context.Context, req *CalculateChecksumRequest) (*CalculateChecksumResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method CalculateChecksum not implemented")
}
func (*UnimplementedRepositoryServiceServer) Cleanup(ctx context.Context, req *CleanupRequest) (*CleanupResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method Cleanup not implemented")
}
func (*UnimplementedRepositoryServiceServer) GetSnapshot(req *GetSnapshotRequest, srv RepositoryService_GetSnapshotServer) error {
	return status.Errorf(codes.Unimplemented, "method GetSnapshot not implemented")
}
func (*UnimplementedRepositoryServiceServer) CreateRepositoryFromSnapshot(ctx context.Context, req *CreateRepositoryFromSnapshotRequest) (*CreateRepositoryFromSnapshotResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method CreateRepositoryFromSnapshot not implemented")
}
func (*UnimplementedRepositoryServiceServer) GetRawChanges(req *GetRawChangesRequest, srv RepositoryService_GetRawChangesServer) error {
	return status.Errorf(codes.Unimplemented, "method GetRawChanges not implemented")
}
func (*UnimplementedRepositoryServiceServer) SearchFilesByContent(req *SearchFilesByContentRequest, srv RepositoryService_SearchFilesByContentServer) error {
	return status.Errorf(codes.Unimplemented, "method SearchFilesByContent not implemented")
}
func (*UnimplementedRepositoryServiceServer) SearchFilesByName(req *SearchFilesByNameRequest, srv RepositoryService_SearchFilesByNameServer) error {
	return status.Errorf(codes.Unimplemented, "method SearchFilesByName not implemented")
}
func (*UnimplementedRepositoryServiceServer) RestoreCustomHooks(srv RepositoryService_RestoreCustomHooksServer) error {
	return status.Errorf(codes.Unimplemented, "method RestoreCustomHooks not implemented")
}
func (*UnimplementedRepositoryServiceServer) BackupCustomHooks(req *BackupCustomHooksRequest, srv RepositoryService_BackupCustomHooksServer) error {
	return status.Errorf(codes.Unimplemented, "method BackupCustomHooks not implemented")
}
func (*UnimplementedRepositoryServiceServer) GetObjectDirectorySize(ctx context.Context, req *GetObjectDirectorySizeRequest) (*GetObjectDirectorySizeResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method GetObjectDirectorySize not implemented")
}
func (*UnimplementedRepositoryServiceServer) CloneFromPool(ctx context.Context, req *CloneFromPoolRequest) (*CloneFromPoolResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method CloneFromPool not implemented")
}
func (*UnimplementedRepositoryServiceServer) CloneFromPoolInternal(ctx context.Context, req *CloneFromPoolInternalRequest) (*CloneFromPoolInternalResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method CloneFromPoolInternal not implemented")
}
func (*UnimplementedRepositoryServiceServer) RemoveRepository(ctx context.Context, req *RemoveRepositoryRequest) (*RemoveRepositoryResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method RemoveRepository not implemented")
}
func (*UnimplementedRepositoryServiceServer) RenameRepository(ctx context.Context, req *RenameRepositoryRequest) (*RenameRepositoryResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method RenameRepository not implemented")
}
func (*UnimplementedRepositoryServiceServer) ReplicateRepository(ctx context.Context, req *ReplicateRepositoryRequest) (*ReplicateRepositoryResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method ReplicateRepository not implemented")
}
func (*UnimplementedRepositoryServiceServer) OptimizeRepository(ctx context.Context, req *OptimizeRepositoryRequest) (*OptimizeRepositoryResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method OptimizeRepository not implemented")
}

func RegisterRepositoryServiceServer(s *grpc.Server, srv RepositoryServiceServer) {
	s.RegisterService(&_RepositoryService_serviceDesc, srv)
}

func _RepositoryService_RepositoryExists_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(RepositoryExistsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).RepositoryExists(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/RepositoryExists",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).RepositoryExists(ctx, req.(*RepositoryExistsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_RepackIncremental_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(RepackIncrementalRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).RepackIncremental(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/RepackIncremental",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).RepackIncremental(ctx, req.(*RepackIncrementalRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_RepackFull_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(RepackFullRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).RepackFull(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/RepackFull",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).RepackFull(ctx, req.(*RepackFullRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_MidxRepack_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(MidxRepackRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).MidxRepack(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/MidxRepack",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).MidxRepack(ctx, req.(*MidxRepackRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_GarbageCollect_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GarbageCollectRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).GarbageCollect(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/GarbageCollect",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).GarbageCollect(ctx, req.(*GarbageCollectRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_WriteCommitGraph_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(WriteCommitGraphRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).WriteCommitGraph(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/WriteCommitGraph",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).WriteCommitGraph(ctx, req.(*WriteCommitGraphRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_RepositorySize_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(RepositorySizeRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).RepositorySize(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/RepositorySize",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).RepositorySize(ctx, req.(*RepositorySizeRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_ApplyGitattributes_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ApplyGitattributesRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).ApplyGitattributes(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/ApplyGitattributes",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).ApplyGitattributes(ctx, req.(*ApplyGitattributesRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_FetchRemote_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(FetchRemoteRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).FetchRemote(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/FetchRemote",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).FetchRemote(ctx, req.(*FetchRemoteRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_CreateRepository_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateRepositoryRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).CreateRepository(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/CreateRepository",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).CreateRepository(ctx, req.(*CreateRepositoryRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_GetArchive_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(GetArchiveRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).GetArchive(m, &repositoryServiceGetArchiveServer{stream})
}

type RepositoryService_GetArchiveServer interface {
	Send(*GetArchiveResponse) error
	grpc.ServerStream
}

type repositoryServiceGetArchiveServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceGetArchiveServer) Send(m *GetArchiveResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_HasLocalBranches_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(HasLocalBranchesRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).HasLocalBranches(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/HasLocalBranches",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).HasLocalBranches(ctx, req.(*HasLocalBranchesRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_FetchSourceBranch_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(FetchSourceBranchRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).FetchSourceBranch(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/FetchSourceBranch",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).FetchSourceBranch(ctx, req.(*FetchSourceBranchRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_Fsck_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(FsckRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).Fsck(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/Fsck",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).Fsck(ctx, req.(*FsckRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_WriteRef_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(WriteRefRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).WriteRef(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/WriteRef",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).WriteRef(ctx, req.(*WriteRefRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_FindMergeBase_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(FindMergeBaseRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).FindMergeBase(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/FindMergeBase",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).FindMergeBase(ctx, req.(*FindMergeBaseRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_CreateFork_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateForkRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).CreateFork(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/CreateFork",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).CreateFork(ctx, req.(*CreateForkRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_IsRebaseInProgress_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(IsRebaseInProgressRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).IsRebaseInProgress(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/IsRebaseInProgress",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).IsRebaseInProgress(ctx, req.(*IsRebaseInProgressRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_IsSquashInProgress_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(IsSquashInProgressRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).IsSquashInProgress(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/IsSquashInProgress",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).IsSquashInProgress(ctx, req.(*IsSquashInProgressRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_CreateRepositoryFromURL_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateRepositoryFromURLRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).CreateRepositoryFromURL(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/CreateRepositoryFromURL",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).CreateRepositoryFromURL(ctx, req.(*CreateRepositoryFromURLRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_CreateBundle_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(CreateBundleRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).CreateBundle(m, &repositoryServiceCreateBundleServer{stream})
}

type RepositoryService_CreateBundleServer interface {
	Send(*CreateBundleResponse) error
	grpc.ServerStream
}

type repositoryServiceCreateBundleServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceCreateBundleServer) Send(m *CreateBundleResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_CreateRepositoryFromBundle_Handler(srv interface{}, stream grpc.ServerStream) error {
	return srv.(RepositoryServiceServer).CreateRepositoryFromBundle(&repositoryServiceCreateRepositoryFromBundleServer{stream})
}

type RepositoryService_CreateRepositoryFromBundleServer interface {
	SendAndClose(*CreateRepositoryFromBundleResponse) error
	Recv() (*CreateRepositoryFromBundleRequest, error)
	grpc.ServerStream
}

type repositoryServiceCreateRepositoryFromBundleServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceCreateRepositoryFromBundleServer) SendAndClose(m *CreateRepositoryFromBundleResponse) error {
	return x.ServerStream.SendMsg(m)
}

func (x *repositoryServiceCreateRepositoryFromBundleServer) Recv() (*CreateRepositoryFromBundleRequest, error) {
	m := new(CreateRepositoryFromBundleRequest)
	if err := x.ServerStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func _RepositoryService_GetConfig_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(GetConfigRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).GetConfig(m, &repositoryServiceGetConfigServer{stream})
}

type RepositoryService_GetConfigServer interface {
	Send(*GetConfigResponse) error
	grpc.ServerStream
}

type repositoryServiceGetConfigServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceGetConfigServer) Send(m *GetConfigResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_SetConfig_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(SetConfigRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).SetConfig(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/SetConfig",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).SetConfig(ctx, req.(*SetConfigRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_DeleteConfig_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(DeleteConfigRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).DeleteConfig(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/DeleteConfig",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).DeleteConfig(ctx, req.(*DeleteConfigRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_FindLicense_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(FindLicenseRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).FindLicense(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/FindLicense",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).FindLicense(ctx, req.(*FindLicenseRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_GetInfoAttributes_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(GetInfoAttributesRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).GetInfoAttributes(m, &repositoryServiceGetInfoAttributesServer{stream})
}

type RepositoryService_GetInfoAttributesServer interface {
	Send(*GetInfoAttributesResponse) error
	grpc.ServerStream
}

type repositoryServiceGetInfoAttributesServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceGetInfoAttributesServer) Send(m *GetInfoAttributesResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_CalculateChecksum_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CalculateChecksumRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).CalculateChecksum(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/CalculateChecksum",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).CalculateChecksum(ctx, req.(*CalculateChecksumRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_Cleanup_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CleanupRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).Cleanup(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/Cleanup",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).Cleanup(ctx, req.(*CleanupRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_GetSnapshot_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(GetSnapshotRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).GetSnapshot(m, &repositoryServiceGetSnapshotServer{stream})
}

type RepositoryService_GetSnapshotServer interface {
	Send(*GetSnapshotResponse) error
	grpc.ServerStream
}

type repositoryServiceGetSnapshotServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceGetSnapshotServer) Send(m *GetSnapshotResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_CreateRepositoryFromSnapshot_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateRepositoryFromSnapshotRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).CreateRepositoryFromSnapshot(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/CreateRepositoryFromSnapshot",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).CreateRepositoryFromSnapshot(ctx, req.(*CreateRepositoryFromSnapshotRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_GetRawChanges_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(GetRawChangesRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).GetRawChanges(m, &repositoryServiceGetRawChangesServer{stream})
}

type RepositoryService_GetRawChangesServer interface {
	Send(*GetRawChangesResponse) error
	grpc.ServerStream
}

type repositoryServiceGetRawChangesServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceGetRawChangesServer) Send(m *GetRawChangesResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_SearchFilesByContent_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(SearchFilesByContentRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).SearchFilesByContent(m, &repositoryServiceSearchFilesByContentServer{stream})
}

type RepositoryService_SearchFilesByContentServer interface {
	Send(*SearchFilesByContentResponse) error
	grpc.ServerStream
}

type repositoryServiceSearchFilesByContentServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceSearchFilesByContentServer) Send(m *SearchFilesByContentResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_SearchFilesByName_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(SearchFilesByNameRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).SearchFilesByName(m, &repositoryServiceSearchFilesByNameServer{stream})
}

type RepositoryService_SearchFilesByNameServer interface {
	Send(*SearchFilesByNameResponse) error
	grpc.ServerStream
}

type repositoryServiceSearchFilesByNameServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceSearchFilesByNameServer) Send(m *SearchFilesByNameResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_RestoreCustomHooks_Handler(srv interface{}, stream grpc.ServerStream) error {
	return srv.(RepositoryServiceServer).RestoreCustomHooks(&repositoryServiceRestoreCustomHooksServer{stream})
}

type RepositoryService_RestoreCustomHooksServer interface {
	SendAndClose(*RestoreCustomHooksResponse) error
	Recv() (*RestoreCustomHooksRequest, error)
	grpc.ServerStream
}

type repositoryServiceRestoreCustomHooksServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceRestoreCustomHooksServer) SendAndClose(m *RestoreCustomHooksResponse) error {
	return x.ServerStream.SendMsg(m)
}

func (x *repositoryServiceRestoreCustomHooksServer) Recv() (*RestoreCustomHooksRequest, error) {
	m := new(RestoreCustomHooksRequest)
	if err := x.ServerStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func _RepositoryService_BackupCustomHooks_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(BackupCustomHooksRequest)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(RepositoryServiceServer).BackupCustomHooks(m, &repositoryServiceBackupCustomHooksServer{stream})
}

type RepositoryService_BackupCustomHooksServer interface {
	Send(*BackupCustomHooksResponse) error
	grpc.ServerStream
}

type repositoryServiceBackupCustomHooksServer struct {
	grpc.ServerStream
}

func (x *repositoryServiceBackupCustomHooksServer) Send(m *BackupCustomHooksResponse) error {
	return x.ServerStream.SendMsg(m)
}

func _RepositoryService_GetObjectDirectorySize_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetObjectDirectorySizeRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).GetObjectDirectorySize(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/GetObjectDirectorySize",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).GetObjectDirectorySize(ctx, req.(*GetObjectDirectorySizeRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_CloneFromPool_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CloneFromPoolRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).CloneFromPool(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/CloneFromPool",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).CloneFromPool(ctx, req.(*CloneFromPoolRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_CloneFromPoolInternal_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CloneFromPoolInternalRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).CloneFromPoolInternal(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/CloneFromPoolInternal",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).CloneFromPoolInternal(ctx, req.(*CloneFromPoolInternalRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_RemoveRepository_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(RemoveRepositoryRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).RemoveRepository(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/RemoveRepository",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).RemoveRepository(ctx, req.(*RemoveRepositoryRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_RenameRepository_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(RenameRepositoryRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).RenameRepository(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/RenameRepository",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).RenameRepository(ctx, req.(*RenameRepositoryRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_ReplicateRepository_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ReplicateRepositoryRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).ReplicateRepository(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/ReplicateRepository",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).ReplicateRepository(ctx, req.(*ReplicateRepositoryRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _RepositoryService_OptimizeRepository_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(OptimizeRepositoryRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(RepositoryServiceServer).OptimizeRepository(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/gitaly.RepositoryService/OptimizeRepository",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(RepositoryServiceServer).OptimizeRepository(ctx, req.(*OptimizeRepositoryRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _RepositoryService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "gitaly.RepositoryService",
	HandlerType: (*RepositoryServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RepositoryExists",
			Handler:    _RepositoryService_RepositoryExists_Handler,
		},
		{
			MethodName: "RepackIncremental",
			Handler:    _RepositoryService_RepackIncremental_Handler,
		},
		{
			MethodName: "RepackFull",
			Handler:    _RepositoryService_RepackFull_Handler,
		},
		{
			MethodName: "MidxRepack",
			Handler:    _RepositoryService_MidxRepack_Handler,
		},
		{
			MethodName: "GarbageCollect",
			Handler:    _RepositoryService_GarbageCollect_Handler,
		},
		{
			MethodName: "WriteCommitGraph",
			Handler:    _RepositoryService_WriteCommitGraph_Handler,
		},
		{
			MethodName: "RepositorySize",
			Handler:    _RepositoryService_RepositorySize_Handler,
		},
		{
			MethodName: "ApplyGitattributes",
			Handler:    _RepositoryService_ApplyGitattributes_Handler,
		},
		{
			MethodName: "FetchRemote",
			Handler:    _RepositoryService_FetchRemote_Handler,
		},
		{
			MethodName: "CreateRepository",
			Handler:    _RepositoryService_CreateRepository_Handler,
		},
		{
			MethodName: "HasLocalBranches",
			Handler:    _RepositoryService_HasLocalBranches_Handler,
		},
		{
			MethodName: "FetchSourceBranch",
			Handler:    _RepositoryService_FetchSourceBranch_Handler,
		},
		{
			MethodName: "Fsck",
			Handler:    _RepositoryService_Fsck_Handler,
		},
		{
			MethodName: "WriteRef",
			Handler:    _RepositoryService_WriteRef_Handler,
		},
		{
			MethodName: "FindMergeBase",
			Handler:    _RepositoryService_FindMergeBase_Handler,
		},
		{
			MethodName: "CreateFork",
			Handler:    _RepositoryService_CreateFork_Handler,
		},
		{
			MethodName: "IsRebaseInProgress",
			Handler:    _RepositoryService_IsRebaseInProgress_Handler,
		},
		{
			MethodName: "IsSquashInProgress",
			Handler:    _RepositoryService_IsSquashInProgress_Handler,
		},
		{
			MethodName: "CreateRepositoryFromURL",
			Handler:    _RepositoryService_CreateRepositoryFromURL_Handler,
		},
		{
			MethodName: "SetConfig",
			Handler:    _RepositoryService_SetConfig_Handler,
		},
		{
			MethodName: "DeleteConfig",
			Handler:    _RepositoryService_DeleteConfig_Handler,
		},
		{
			MethodName: "FindLicense",
			Handler:    _RepositoryService_FindLicense_Handler,
		},
		{
			MethodName: "CalculateChecksum",
			Handler:    _RepositoryService_CalculateChecksum_Handler,
		},
		{
			MethodName: "Cleanup",
			Handler:    _RepositoryService_Cleanup_Handler,
		},
		{
			MethodName: "CreateRepositoryFromSnapshot",
			Handler:    _RepositoryService_CreateRepositoryFromSnapshot_Handler,
		},
		{
			MethodName: "GetObjectDirectorySize",
			Handler:    _RepositoryService_GetObjectDirectorySize_Handler,
		},
		{
			MethodName: "CloneFromPool",
			Handler:    _RepositoryService_CloneFromPool_Handler,
		},
		{
			MethodName: "CloneFromPoolInternal",
			Handler:    _RepositoryService_CloneFromPoolInternal_Handler,
		},
		{
			MethodName: "RemoveRepository",
			Handler:    _RepositoryService_RemoveRepository_Handler,
		},
		{
			MethodName: "RenameRepository",
			Handler:    _RepositoryService_RenameRepository_Handler,
		},
		{
			MethodName: "ReplicateRepository",
			Handler:    _RepositoryService_ReplicateRepository_Handler,
		},
		{
			MethodName: "OptimizeRepository",
			Handler:    _RepositoryService_OptimizeRepository_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "GetArchive",
			Handler:       _RepositoryService_GetArchive_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "CreateBundle",
			Handler:       _RepositoryService_CreateBundle_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "CreateRepositoryFromBundle",
			Handler:       _RepositoryService_CreateRepositoryFromBundle_Handler,
			ClientStreams: true,
		},
		{
			StreamName:    "GetConfig",
			Handler:       _RepositoryService_GetConfig_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "GetInfoAttributes",
			Handler:       _RepositoryService_GetInfoAttributes_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "GetSnapshot",
			Handler:       _RepositoryService_GetSnapshot_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "GetRawChanges",
			Handler:       _RepositoryService_GetRawChanges_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "SearchFilesByContent",
			Handler:       _RepositoryService_SearchFilesByContent_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "SearchFilesByName",
			Handler:       _RepositoryService_SearchFilesByName_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "RestoreCustomHooks",
			Handler:       _RepositoryService_RestoreCustomHooks_Handler,
			ClientStreams: true,
		},
		{
			StreamName:    "BackupCustomHooks",
			Handler:       _RepositoryService_BackupCustomHooks_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "repository-service.proto",
}
